{
  "cells": [
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "# Amazing Altair with an even better theme\n",
        "\n",
        "Daniel Kapitan  \n",
        "2024-01-21\n",
        "\n",
        "I have been in love with Altair ever since I first ran into it. The\n",
        "logic, the structure, the syntax: it’s all just there and it helps me to\n",
        "get my work done. Paired with [Quarto](https://quarto.org) or\n",
        "[Streamlit](https://streamlit.io), I can create stunning pdf reports,\n",
        "interactive documents and single-page apps for my clients, all from one\n",
        "codebase. After attending a workshop by my fellow data viz afficianado\n",
        "[Sara Sprinkhuizen](https://www.thedatavisionlab.com/), I wanted to\n",
        "implement her tried-and-tested best practices for charts into an Altair.\n",
        "\n",
        "In this post, we will illustate how these improvements work for a\n",
        "handful of visualizations that are often used for exploratory data\n",
        "analysis. We will implement her design principles in an Altair theme,\n",
        "such that we can consistently generate better charts in our workflow.\n",
        "Let’s start and see how Altair’s default theme renders a scatterplot,\n",
        "bar chart and line chart."
      ],
      "id": "766f5955-1330-4eed-b1db-42b4024e94fb"
    },
    {
      "cell_type": "code",
      "execution_count": 1,
      "metadata": {},
      "outputs": [],
      "source": [
        "import altair as alt\n",
        "import ibis\n",
        "from vega_datasets import data\n",
        "\n",
        "\n",
        "ibis.options.interactive = True\n",
        "\n",
        "penguins = ibis.examples.penguins.fetch()\n",
        "stocks = data.stocks()\n",
        "wheat = data.wheat()"
      ],
      "id": "cell-2"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Scatterplot\n",
        "\n",
        "A scatterplot is one of the most commonly used visualizations. In this\n",
        "case we encode three values for the [Palmer penguins\n",
        "data](https://allisonhorst.github.io/palmerpenguins/): bill length\n",
        "vs. bill depth, per species. The only optimization we apply is to have\n",
        "the axis not go all the way to zero, so the charts is focused on the\n",
        "actual datapoints."
      ],
      "id": "618d1be4-3c1f-4f19-986b-dba30e416bf3"
    },
    {
      "cell_type": "code",
      "execution_count": 2,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-fd6e726be3cc4a27af43ed2a6032b259.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-fd6e726be3cc4a27af43ed2a6032b259.vega-embed details,\n",
              "  #altair-viz-fd6e726be3cc4a27af43ed2a6032b259.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-fd6e726be3cc4a27af43ed2a6032b259\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-fd6e726be3cc4a27af43ed2a6032b259\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-fd6e726be3cc4a27af43ed2a6032b259\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-b414165be0aeea8c687bc9462659f7b8\"}, \"mark\": {\"type\": \"circle\", \"size\": 60}, \"encoding\": {\"color\": {\"field\": \"species\", \"type\": \"nominal\"}, \"tooltip\": [{\"field\": \"species\", \"type\": \"nominal\"}, {\"field\": \"sex\", \"type\": \"nominal\"}, {\"field\": \"island\", \"type\": \"nominal\"}, {\"field\": \"bill_length_mm\", \"type\": \"quantitative\"}, {\"field\": \"bill_depth_mm\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"bill_length_mm\", \"scale\": {\"zero\": false}, \"type\": \"quantitative\"}, \"y\": {\"field\": \"bill_depth_mm\", \"scale\": {\"zero\": false}, \"type\": \"quantitative\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-b414165be0aeea8c687bc9462659f7b8\": [{\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.1, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 181, \"body_mass_g\": 3750, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.5, \"bill_depth_mm\": 17.4, \"flipper_length_mm\": 186, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 40.3, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 195, \"body_mass_g\": 3250, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": null, \"bill_depth_mm\": null, \"flipper_length_mm\": null, \"body_mass_g\": null, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.7, \"bill_depth_mm\": 19.3, \"flipper_length_mm\": 193, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.3, \"bill_depth_mm\": 20.6, \"flipper_length_mm\": 190, \"body_mass_g\": 3650, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.9, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 181, \"body_mass_g\": 3625, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.2, \"bill_depth_mm\": 19.6, \"flipper_length_mm\": 195, \"body_mass_g\": 4675, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 34.1, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 193, \"body_mass_g\": 3475, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.0, \"bill_depth_mm\": 20.2, \"flipper_length_mm\": 190, \"body_mass_g\": 4250, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 186, \"body_mass_g\": 3300, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 180, \"body_mass_g\": 3700, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 17.6, \"flipper_length_mm\": 182, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.6, \"bill_depth_mm\": 21.2, \"flipper_length_mm\": 191, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 34.6, \"bill_depth_mm\": 21.1, \"flipper_length_mm\": 198, \"body_mass_g\": 4400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.6, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 185, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.7, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 195, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.5, \"bill_depth_mm\": 20.7, \"flipper_length_mm\": 197, \"body_mass_g\": 4500, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 34.4, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 184, \"body_mass_g\": 3325, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 46.0, \"bill_depth_mm\": 21.5, \"flipper_length_mm\": 194, \"body_mass_g\": 4200, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 18.3, \"flipper_length_mm\": 174, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.7, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 180, \"body_mass_g\": 3600, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.9, \"bill_depth_mm\": 19.2, \"flipper_length_mm\": 189, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.2, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 185, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.8, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 180, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.3, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 187, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.6, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 183, \"body_mass_g\": 3550, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.5, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 187, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.9, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 172, \"body_mass_g\": 3150, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.5, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 180, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.5, \"bill_depth_mm\": 16.7, \"flipper_length_mm\": 178, \"body_mass_g\": 3250, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.2, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 178, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.5, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 188, \"body_mass_g\": 3300, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.9, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 184, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.4, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 195, \"body_mass_g\": 3325, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.2, \"bill_depth_mm\": 21.1, \"flipper_length_mm\": 196, \"body_mass_g\": 4150, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.8, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 190, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 42.2, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 180, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.6, \"bill_depth_mm\": 19.3, \"flipper_length_mm\": 181, \"body_mass_g\": 3300, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.8, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 184, \"body_mass_g\": 4650, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.5, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 182, \"body_mass_g\": 3150, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.8, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 195, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.0, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 186, \"body_mass_g\": 3100, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 44.1, \"bill_depth_mm\": 19.7, \"flipper_length_mm\": 196, \"body_mass_g\": 4400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.0, \"bill_depth_mm\": 16.9, \"flipper_length_mm\": 185, \"body_mass_g\": 3000, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 190, \"body_mass_g\": 4600, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 182, \"body_mass_g\": 3425, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.5, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 179, \"body_mass_g\": 2975, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.0, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 190, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 42.3, \"bill_depth_mm\": 21.2, \"flipper_length_mm\": 191, \"body_mass_g\": 4150, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 17.7, \"flipper_length_mm\": 186, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.1, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 188, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.0, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 190, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.0, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 200, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 34.5, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 187, \"body_mass_g\": 2900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.4, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 191, \"body_mass_g\": 3700, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.0, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 186, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.6, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 193, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 36.5, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 181, \"body_mass_g\": 2850, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.6, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 194, \"body_mass_g\": 3750, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.7, \"bill_depth_mm\": 16.9, \"flipper_length_mm\": 185, \"body_mass_g\": 3150, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.3, \"bill_depth_mm\": 21.1, \"flipper_length_mm\": 195, \"body_mass_g\": 4400, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.6, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 185, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 192, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 36.4, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 184, \"body_mass_g\": 2850, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.6, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 192, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.5, \"bill_depth_mm\": 16.2, \"flipper_length_mm\": 195, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 188, \"body_mass_g\": 4100, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.9, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 190, \"body_mass_g\": 3050, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.8, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 198, \"body_mass_g\": 4450, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 33.5, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 190, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.7, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 190, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 196, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 45.8, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 197, \"body_mass_g\": 4150, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.5, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 190, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.8, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 195, \"body_mass_g\": 4250, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 40.9, \"bill_depth_mm\": 16.8, \"flipper_length_mm\": 191, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.2, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 184, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.2, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 187, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.1, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 195, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 34.6, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 189, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.9, \"bill_depth_mm\": 17.6, \"flipper_length_mm\": 196, \"body_mass_g\": 4700, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.7, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 187, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.1, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 193, \"body_mass_g\": 4200, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.3, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 191, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.3, \"bill_depth_mm\": 20.3, \"flipper_length_mm\": 194, \"body_mass_g\": 3550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.3, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 190, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.9, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 189, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.3, \"bill_depth_mm\": 19.2, \"flipper_length_mm\": 189, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.9, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 190, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 35.7, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 202, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 205, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 34.0, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 185, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 186, \"body_mass_g\": 4450, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.2, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 187, \"body_mass_g\": 3300, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.8, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 208, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.1, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 190, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.3, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 196, \"body_mass_g\": 4350, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 33.1, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 178, \"body_mass_g\": 2900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 43.2, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 192, \"body_mass_g\": 4100, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.0, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 192, \"body_mass_g\": 3725, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.0, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 203, \"body_mass_g\": 4725, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.7, \"bill_depth_mm\": 16.0, \"flipper_length_mm\": 183, \"body_mass_g\": 3075, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 190, \"body_mass_g\": 4250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.9, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 193, \"body_mass_g\": 2925, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.7, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 184, \"body_mass_g\": 3550, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.6, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 199, \"body_mass_g\": 3750, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.2, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 190, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.1, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 181, \"body_mass_g\": 3175, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.2, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 197, \"body_mass_g\": 4775, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.1, \"bill_depth_mm\": 16.5, \"flipper_length_mm\": 198, \"body_mass_g\": 3825, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.6, \"bill_depth_mm\": 20.3, \"flipper_length_mm\": 191, \"body_mass_g\": 4600, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.7, \"bill_depth_mm\": 17.7, \"flipper_length_mm\": 193, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.2, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 197, \"body_mass_g\": 4275, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 20.7, \"flipper_length_mm\": 191, \"body_mass_g\": 3900, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.7, \"bill_depth_mm\": 18.3, \"flipper_length_mm\": 196, \"body_mass_g\": 4075, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.6, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 188, \"body_mass_g\": 2900, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.3, \"bill_depth_mm\": 20.5, \"flipper_length_mm\": 199, \"body_mass_g\": 3775, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.7, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 189, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 189, \"body_mass_g\": 3325, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.2, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 187, \"body_mass_g\": 3150, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.7, \"bill_depth_mm\": 19.8, \"flipper_length_mm\": 198, \"body_mass_g\": 3500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 40.2, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 176, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.4, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 202, \"body_mass_g\": 3875, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.2, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 186, \"body_mass_g\": 3050, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 40.6, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 199, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.8, \"bill_depth_mm\": 17.6, \"flipper_length_mm\": 191, \"body_mass_g\": 3275, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.5, \"bill_depth_mm\": 18.3, \"flipper_length_mm\": 195, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.0, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 191, \"body_mass_g\": 3050, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 44.1, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 210, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.5, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 190, \"body_mass_g\": 3325, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 43.1, \"bill_depth_mm\": 19.2, \"flipper_length_mm\": 197, \"body_mass_g\": 3500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.8, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 193, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.5, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 199, \"body_mass_g\": 4475, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.1, \"bill_depth_mm\": 17.6, \"flipper_length_mm\": 187, \"body_mass_g\": 3425, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 190, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 35.6, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 191, \"body_mass_g\": 3175, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.2, \"bill_depth_mm\": 20.1, \"flipper_length_mm\": 200, \"body_mass_g\": 3975, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.0, \"bill_depth_mm\": 16.5, \"flipper_length_mm\": 185, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.7, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 193, \"body_mass_g\": 4250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.2, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 193, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.6, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 187, \"body_mass_g\": 3475, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 32.1, \"bill_depth_mm\": 15.5, \"flipper_length_mm\": 188, \"body_mass_g\": 3050, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.7, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 190, \"body_mass_g\": 3725, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.3, \"bill_depth_mm\": 16.8, \"flipper_length_mm\": 192, \"body_mass_g\": 3000, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.0, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 185, \"body_mass_g\": 3650, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.2, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 190, \"body_mass_g\": 4250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.6, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 184, \"body_mass_g\": 3475, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.0, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 195, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 193, \"body_mass_g\": 3750, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.0, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 187, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.5, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 201, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.1, \"bill_depth_mm\": 13.2, \"flipper_length_mm\": 211, \"body_mass_g\": 4500, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 16.3, \"flipper_length_mm\": 230, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.7, \"bill_depth_mm\": 14.1, \"flipper_length_mm\": 210, \"body_mass_g\": 4450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 15.2, \"flipper_length_mm\": 218, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.6, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 215, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 13.5, \"flipper_length_mm\": 210, \"body_mass_g\": 4550, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.4, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 211, \"body_mass_g\": 4800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.7, \"bill_depth_mm\": 15.3, \"flipper_length_mm\": 219, \"body_mass_g\": 5200, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.3, \"bill_depth_mm\": 13.4, \"flipper_length_mm\": 209, \"body_mass_g\": 4400, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.8, \"bill_depth_mm\": 15.4, \"flipper_length_mm\": 215, \"body_mass_g\": 5150, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.9, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 214, \"body_mass_g\": 4650, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.0, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 216, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 214, \"body_mass_g\": 4650, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.4, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 213, \"body_mass_g\": 5850, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.8, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 210, \"body_mass_g\": 4200, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.3, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 217, \"body_mass_g\": 5850, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.0, \"bill_depth_mm\": 13.5, \"flipper_length_mm\": 210, \"body_mass_g\": 4150, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.2, \"bill_depth_mm\": 15.2, \"flipper_length_mm\": 221, \"body_mass_g\": 6300, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 209, \"body_mass_g\": 4800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.7, \"bill_depth_mm\": 15.1, \"flipper_length_mm\": 222, \"body_mass_g\": 5350, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.2, \"bill_depth_mm\": 14.3, \"flipper_length_mm\": 218, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.1, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 215, \"body_mass_g\": 5000, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 213, \"body_mass_g\": 4400, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.3, \"bill_depth_mm\": 15.8, \"flipper_length_mm\": 215, \"body_mass_g\": 5050, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.9, \"bill_depth_mm\": 13.1, \"flipper_length_mm\": 215, \"body_mass_g\": 5000, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.1, \"bill_depth_mm\": 15.1, \"flipper_length_mm\": 215, \"body_mass_g\": 5100, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.5, \"bill_depth_mm\": 14.3, \"flipper_length_mm\": 216, \"body_mass_g\": 4100, \"sex\": null, \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.8, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 215, \"body_mass_g\": 5650, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.2, \"bill_depth_mm\": 14.3, \"flipper_length_mm\": 210, \"body_mass_g\": 4600, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 15.3, \"flipper_length_mm\": 220, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.3, \"bill_depth_mm\": 15.3, \"flipper_length_mm\": 222, \"body_mass_g\": 5250, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.8, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 209, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.1, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 207, \"body_mass_g\": 5050, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 59.6, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 230, \"body_mass_g\": 6050, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.1, \"bill_depth_mm\": 14.8, \"flipper_length_mm\": 220, \"body_mass_g\": 5150, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.4, \"bill_depth_mm\": 16.3, \"flipper_length_mm\": 220, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.6, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 213, \"body_mass_g\": 4950, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.4, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 219, \"body_mass_g\": 5250, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.0, \"bill_depth_mm\": 13.6, \"flipper_length_mm\": 208, \"body_mass_g\": 4350, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.7, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 208, \"body_mass_g\": 5350, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.7, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 208, \"body_mass_g\": 3950, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.6, \"bill_depth_mm\": 16.0, \"flipper_length_mm\": 225, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.3, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 210, \"body_mass_g\": 4300, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.6, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 216, \"body_mass_g\": 4750, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 222, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.6, \"bill_depth_mm\": 13.9, \"flipper_length_mm\": 217, \"body_mass_g\": 4900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 13.9, \"flipper_length_mm\": 210, \"body_mass_g\": 4200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 225, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.9, \"bill_depth_mm\": 13.3, \"flipper_length_mm\": 213, \"body_mass_g\": 5100, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 15.8, \"flipper_length_mm\": 215, \"body_mass_g\": 5300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.6, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 210, \"body_mass_g\": 4850, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.5, \"bill_depth_mm\": 14.1, \"flipper_length_mm\": 220, \"body_mass_g\": 5300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.1, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 210, \"body_mass_g\": 4400, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.1, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 225, \"body_mass_g\": 5000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 217, \"body_mass_g\": 4900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.0, \"bill_depth_mm\": 15.4, \"flipper_length_mm\": 220, \"body_mass_g\": 5050, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.8, \"bill_depth_mm\": 13.9, \"flipper_length_mm\": 208, \"body_mass_g\": 4300, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 220, \"body_mass_g\": 5000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.2, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 208, \"body_mass_g\": 4450, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.4, \"bill_depth_mm\": 15.3, \"flipper_length_mm\": 224, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.3, \"bill_depth_mm\": 13.8, \"flipper_length_mm\": 208, \"body_mass_g\": 4200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 14.9, \"flipper_length_mm\": 221, \"body_mass_g\": 5300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.7, \"bill_depth_mm\": 13.9, \"flipper_length_mm\": 214, \"body_mass_g\": 4400, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 54.3, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 231, \"body_mass_g\": 5650, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.8, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 219, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.8, \"bill_depth_mm\": 16.8, \"flipper_length_mm\": 230, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 214, \"body_mass_g\": 4650, \"sex\": null, \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.5, \"bill_depth_mm\": 16.2, \"flipper_length_mm\": 229, \"body_mass_g\": 5800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.5, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 220, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.7, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 223, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.7, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 216, \"body_mass_g\": 4750, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.4, \"bill_depth_mm\": 15.6, \"flipper_length_mm\": 221, \"body_mass_g\": 5000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.2, \"bill_depth_mm\": 15.6, \"flipper_length_mm\": 221, \"body_mass_g\": 5100, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 14.8, \"flipper_length_mm\": 217, \"body_mass_g\": 5200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.4, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 216, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.6, \"bill_depth_mm\": 16.0, \"flipper_length_mm\": 230, \"body_mass_g\": 5800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.5, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 209, \"body_mass_g\": 4600, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 51.1, \"bill_depth_mm\": 16.3, \"flipper_length_mm\": 220, \"body_mass_g\": 6000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 13.8, \"flipper_length_mm\": 215, \"body_mass_g\": 4750, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 16.4, \"flipper_length_mm\": 223, \"body_mass_g\": 5950, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.1, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 212, \"body_mass_g\": 4625, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 52.5, \"bill_depth_mm\": 15.6, \"flipper_length_mm\": 221, \"body_mass_g\": 5450, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.4, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 212, \"body_mass_g\": 4725, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 224, \"body_mass_g\": 5350, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.9, \"bill_depth_mm\": 13.8, \"flipper_length_mm\": 212, \"body_mass_g\": 4750, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.8, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 228, \"body_mass_g\": 5600, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.4, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 218, \"body_mass_g\": 4600, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 51.3, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 218, \"body_mass_g\": 5300, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.5, \"bill_depth_mm\": 14.0, \"flipper_length_mm\": 212, \"body_mass_g\": 4875, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 52.1, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 230, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.5, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 218, \"body_mass_g\": 4950, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 52.2, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 228, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 212, \"body_mass_g\": 4750, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.5, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 224, \"body_mass_g\": 5650, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.5, \"bill_depth_mm\": 14.7, \"flipper_length_mm\": 214, \"body_mass_g\": 4850, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.8, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 226, \"body_mass_g\": 5200, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.4, \"bill_depth_mm\": 15.8, \"flipper_length_mm\": 216, \"body_mass_g\": 4925, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.9, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 222, \"body_mass_g\": 4875, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.4, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 203, \"body_mass_g\": 4625, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 51.1, \"bill_depth_mm\": 16.5, \"flipper_length_mm\": 225, \"body_mass_g\": 5250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.5, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 219, \"body_mass_g\": 4850, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 55.9, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 228, \"body_mass_g\": 5600, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.2, \"bill_depth_mm\": 15.5, \"flipper_length_mm\": 215, \"body_mass_g\": 4975, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.1, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 228, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.3, \"bill_depth_mm\": 13.8, \"flipper_length_mm\": 216, \"body_mass_g\": 4725, \"sex\": null, \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.8, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 215, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.7, \"bill_depth_mm\": 14.7, \"flipper_length_mm\": 210, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 53.4, \"bill_depth_mm\": 15.8, \"flipper_length_mm\": 219, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.3, \"bill_depth_mm\": 14.0, \"flipper_length_mm\": 208, \"body_mass_g\": 4575, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.1, \"bill_depth_mm\": 15.1, \"flipper_length_mm\": 209, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 15.2, \"flipper_length_mm\": 216, \"body_mass_g\": 5000, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.8, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 229, \"body_mass_g\": 5950, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.5, \"bill_depth_mm\": 15.2, \"flipper_length_mm\": 213, \"body_mass_g\": 4650, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 51.5, \"bill_depth_mm\": 16.3, \"flipper_length_mm\": 230, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 14.1, \"flipper_length_mm\": 217, \"body_mass_g\": 4375, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 55.1, \"bill_depth_mm\": 16.0, \"flipper_length_mm\": 230, \"body_mass_g\": 5850, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.5, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 217, \"body_mass_g\": 4875, \"sex\": null, \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.8, \"bill_depth_mm\": 16.2, \"flipper_length_mm\": 222, \"body_mass_g\": 6000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.2, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 214, \"body_mass_g\": 4925, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": null, \"bill_depth_mm\": null, \"flipper_length_mm\": null, \"body_mass_g\": null, \"sex\": null, \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.8, \"bill_depth_mm\": 14.3, \"flipper_length_mm\": 215, \"body_mass_g\": 4850, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.4, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 222, \"body_mass_g\": 5750, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 14.8, \"flipper_length_mm\": 212, \"body_mass_g\": 5200, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.9, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 213, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 192, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 196, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.3, \"bill_depth_mm\": 19.2, \"flipper_length_mm\": 193, \"body_mass_g\": 3650, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.4, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 188, \"body_mass_g\": 3525, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.7, \"bill_depth_mm\": 19.8, \"flipper_length_mm\": 197, \"body_mass_g\": 3725, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 198, \"body_mass_g\": 3950, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.1, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 178, \"body_mass_g\": 3250, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.3, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 197, \"body_mass_g\": 3750, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.0, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 195, \"body_mass_g\": 4150, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.3, \"bill_depth_mm\": 19.9, \"flipper_length_mm\": 198, \"body_mass_g\": 3700, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.6, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 193, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.7, \"bill_depth_mm\": 20.3, \"flipper_length_mm\": 194, \"body_mass_g\": 3775, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 47.0, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 185, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.0, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 201, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.9, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 190, \"body_mass_g\": 3575, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 19.6, \"flipper_length_mm\": 201, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.3, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 197, \"body_mass_g\": 3300, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 58.0, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 181, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.4, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 190, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.2, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 195, \"body_mass_g\": 4400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 42.4, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 181, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 48.5, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 191, \"body_mass_g\": 3400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 43.2, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 187, \"body_mass_g\": 2900, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.6, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 193, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.7, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 195, \"body_mass_g\": 3300, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.0, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 197, \"body_mass_g\": 4150, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 200, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.5, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 200, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.4, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 191, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.8, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 205, \"body_mass_g\": 4550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 40.9, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 187, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 54.2, \"bill_depth_mm\": 20.8, \"flipper_length_mm\": 201, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 42.5, \"bill_depth_mm\": 16.7, \"flipper_length_mm\": 187, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.0, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 203, \"body_mass_g\": 4100, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.7, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 195, \"body_mass_g\": 3600, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 47.5, \"bill_depth_mm\": 16.8, \"flipper_length_mm\": 199, \"body_mass_g\": 3900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 47.6, \"bill_depth_mm\": 18.3, \"flipper_length_mm\": 195, \"body_mass_g\": 3850, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.0, \"bill_depth_mm\": 20.7, \"flipper_length_mm\": 210, \"body_mass_g\": 4800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.9, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 192, \"body_mass_g\": 2700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 53.5, \"bill_depth_mm\": 19.9, \"flipper_length_mm\": 205, \"body_mass_g\": 4500, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.0, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 210, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 187, \"body_mass_g\": 3650, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.9, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 196, \"body_mass_g\": 3550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 196, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.9, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 196, \"body_mass_g\": 3675, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.8, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 201, \"body_mass_g\": 4450, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.1, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 190, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.0, \"bill_depth_mm\": 19.6, \"flipper_length_mm\": 212, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.5, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 187, \"body_mass_g\": 3250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.8, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 198, \"body_mass_g\": 3675, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 48.1, \"bill_depth_mm\": 16.4, \"flipper_length_mm\": 199, \"body_mass_g\": 3325, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.4, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 201, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.7, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 193, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.7, \"bill_depth_mm\": 19.7, \"flipper_length_mm\": 203, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 42.5, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 187, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.2, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 197, \"body_mass_g\": 3450, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 191, \"body_mass_g\": 3250, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.3, \"bill_depth_mm\": 19.9, \"flipper_length_mm\": 203, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.2, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 202, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.6, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 194, \"body_mass_g\": 3525, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.9, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 206, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.8, \"bill_depth_mm\": 16.5, \"flipper_length_mm\": 189, \"body_mass_g\": 3650, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.7, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 195, \"body_mass_g\": 3650, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 55.8, \"bill_depth_mm\": 19.8, \"flipper_length_mm\": 207, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 43.5, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 202, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.6, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 193, \"body_mass_g\": 3775, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.8, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 210, \"body_mass_g\": 4100, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.2, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 198, \"body_mass_g\": 3775, \"sex\": \"female\", \"year\": 2009}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "scatterplot = (\n",
        "    alt.Chart(penguins)\n",
        "    .mark_circle(size=60)\n",
        "    .encode(\n",
        "        x=alt.X(\"bill_length_mm:Q\", scale=alt.Scale(zero=False)),\n",
        "        y=alt.Y(\"bill_depth_mm:Q\", scale=alt.Scale(zero=False)),\n",
        "        color=alt.Color(\"species\"),\n",
        "        tooltip=[\"species\", \"sex\", \"island\", \"bill_length_mm:Q\", \"bill_depth_mm:Q\"],\n",
        "    )\n",
        ")\n",
        "scatterplot"
      ],
      "id": "cell-4"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Bar chart\n",
        "\n",
        "Next up is the trusty ol’ bar chart, which we demonstrate using the\n",
        "wheat dataset. This chart is challenging because it spans two and a half\n",
        "centuries of yearly data, leading to a wide chart with the default\n",
        "settings. Did you turn your head to read the year labels on the x-axis?\n",
        "Or to figure out that the y-axis title reads `wheat`? Surely there must\n",
        "be a better way."
      ],
      "id": "009c710d-5fa3-4fa7-934d-3c053170cff2"
    },
    {
      "cell_type": "code",
      "execution_count": 3,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-01f31f052bae451ba5be95ad96342eaf.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-01f31f052bae451ba5be95ad96342eaf.vega-embed details,\n",
              "  #altair-viz-01f31f052bae451ba5be95ad96342eaf.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-01f31f052bae451ba5be95ad96342eaf\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-01f31f052bae451ba5be95ad96342eaf\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-01f31f052bae451ba5be95ad96342eaf\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-76d1ce26ea5761007c35827e1564d86c\"}, \"mark\": {\"type\": \"bar\"}, \"encoding\": {\"tooltip\": [{\"field\": \"year\", \"type\": \"ordinal\"}, {\"field\": \"wheat\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"year\", \"type\": \"ordinal\"}, \"y\": {\"field\": \"wheat\", \"type\": \"quantitative\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-76d1ce26ea5761007c35827e1564d86c\": [{\"year\": 1565, \"wheat\": 41.0, \"wages\": 5.0}, {\"year\": 1570, \"wheat\": 45.0, \"wages\": 5.05}, {\"year\": 1575, \"wheat\": 42.0, \"wages\": 5.08}, {\"year\": 1580, \"wheat\": 49.0, \"wages\": 5.12}, {\"year\": 1585, \"wheat\": 41.5, \"wages\": 5.15}, {\"year\": 1590, \"wheat\": 47.0, \"wages\": 5.25}, {\"year\": 1595, \"wheat\": 64.0, \"wages\": 5.54}, {\"year\": 1600, \"wheat\": 27.0, \"wages\": 5.61}, {\"year\": 1605, \"wheat\": 33.0, \"wages\": 5.69}, {\"year\": 1610, \"wheat\": 32.0, \"wages\": 5.78}, {\"year\": 1615, \"wheat\": 33.0, \"wages\": 5.94}, {\"year\": 1620, \"wheat\": 35.0, \"wages\": 6.01}, {\"year\": 1625, \"wheat\": 33.0, \"wages\": 6.12}, {\"year\": 1630, \"wheat\": 45.0, \"wages\": 6.22}, {\"year\": 1635, \"wheat\": 33.0, \"wages\": 6.3}, {\"year\": 1640, \"wheat\": 39.0, \"wages\": 6.37}, {\"year\": 1645, \"wheat\": 53.0, \"wages\": 6.45}, {\"year\": 1650, \"wheat\": 42.0, \"wages\": 6.5}, {\"year\": 1655, \"wheat\": 40.5, \"wages\": 6.6}, {\"year\": 1660, \"wheat\": 46.5, \"wages\": 6.75}, {\"year\": 1665, \"wheat\": 32.0, \"wages\": 6.8}, {\"year\": 1670, \"wheat\": 37.0, \"wages\": 6.9}, {\"year\": 1675, \"wheat\": 43.0, \"wages\": 7.0}, {\"year\": 1680, \"wheat\": 35.0, \"wages\": 7.3}, {\"year\": 1685, \"wheat\": 27.0, \"wages\": 7.6}, {\"year\": 1690, \"wheat\": 40.0, \"wages\": 8.0}, {\"year\": 1695, \"wheat\": 50.0, \"wages\": 8.5}, {\"year\": 1700, \"wheat\": 30.0, \"wages\": 9.0}, {\"year\": 1705, \"wheat\": 32.0, \"wages\": 10.0}, {\"year\": 1710, \"wheat\": 44.0, \"wages\": 11.0}, {\"year\": 1715, \"wheat\": 33.0, \"wages\": 11.75}, {\"year\": 1720, \"wheat\": 29.0, \"wages\": 12.5}, {\"year\": 1725, \"wheat\": 39.0, \"wages\": 13.0}, {\"year\": 1730, \"wheat\": 26.0, \"wages\": 13.3}, {\"year\": 1735, \"wheat\": 32.0, \"wages\": 13.6}, {\"year\": 1740, \"wheat\": 27.0, \"wages\": 14.0}, {\"year\": 1745, \"wheat\": 27.5, \"wages\": 14.5}, {\"year\": 1750, \"wheat\": 31.0, \"wages\": 15.0}, {\"year\": 1755, \"wheat\": 35.5, \"wages\": 15.7}, {\"year\": 1760, \"wheat\": 31.0, \"wages\": 16.5}, {\"year\": 1765, \"wheat\": 43.0, \"wages\": 17.6}, {\"year\": 1770, \"wheat\": 47.0, \"wages\": 18.5}, {\"year\": 1775, \"wheat\": 44.0, \"wages\": 19.5}, {\"year\": 1780, \"wheat\": 46.0, \"wages\": 21.0}, {\"year\": 1785, \"wheat\": 42.0, \"wages\": 23.0}, {\"year\": 1790, \"wheat\": 47.5, \"wages\": 25.5}, {\"year\": 1795, \"wheat\": 76.0, \"wages\": 27.5}, {\"year\": 1800, \"wheat\": 79.0, \"wages\": 28.5}, {\"year\": 1805, \"wheat\": 81.0, \"wages\": 29.5}, {\"year\": 1810, \"wheat\": 99.0, \"wages\": 30.0}, {\"year\": 1815, \"wheat\": 78.0, \"wages\": null}, {\"year\": 1820, \"wheat\": 54.0, \"wages\": null}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "barchart = (\n",
        "    alt.Chart(wheat)\n",
        "    .mark_bar()\n",
        "    .encode(x=\"year:O\", y=\"wheat:Q\", tooltip=[\"year:O\", \"wheat:Q\"])\n",
        ")\n",
        "barchart"
      ],
      "id": "cell-6"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Line chart\n",
        "\n",
        "A line chart with a legend, in this case showing stock prices of a\n",
        "handful of tech companies, is also something we use on a regular basis.\n",
        "Did you even notice the effort you have to put in to lookup the color of\n",
        "the line in the legend? I actually had a hard time distinguishing Amazon\n",
        "and Google, as the red and orange are very alike to my eyes."
      ],
      "id": "4147e857-4c44-4a6f-8091-19a3490f0fb3"
    },
    {
      "cell_type": "code",
      "execution_count": 4,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-28b5ddbb9d0d4f64bca6aa775c2ad92d.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-28b5ddbb9d0d4f64bca6aa775c2ad92d.vega-embed details,\n",
              "  #altair-viz-28b5ddbb9d0d4f64bca6aa775c2ad92d.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-28b5ddbb9d0d4f64bca6aa775c2ad92d\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-28b5ddbb9d0d4f64bca6aa775c2ad92d\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-28b5ddbb9d0d4f64bca6aa775c2ad92d\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"config\": {\"view\": {\"continuousWidth\": 300, \"continuousHeight\": 300}}, \"data\": {\"name\": \"data-96e857a61c6b623bafe23440d582a500\"}, \"mark\": {\"type\": \"line\"}, \"encoding\": {\"color\": {\"field\": \"symbol\", \"type\": \"nominal\"}, \"tooltip\": [{\"field\": \"date\", \"type\": \"temporal\"}, {\"field\": \"price\", \"type\": \"quantitative\"}], \"x\": {\"axis\": {\"title\": \"date\"}, \"field\": \"date\", \"type\": \"temporal\"}, \"y\": {\"axis\": {\"title\": \"price\"}, \"field\": \"price\", \"type\": \"quantitative\"}}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-96e857a61c6b623bafe23440d582a500\": [{\"symbol\": \"MSFT\", \"date\": \"2000-01-01T00:00:00\", \"price\": 39.81}, {\"symbol\": \"MSFT\", \"date\": \"2000-02-01T00:00:00\", \"price\": 36.35}, {\"symbol\": \"MSFT\", \"date\": \"2000-03-01T00:00:00\", \"price\": 43.22}, {\"symbol\": \"MSFT\", \"date\": \"2000-04-01T00:00:00\", \"price\": 28.37}, {\"symbol\": \"MSFT\", \"date\": \"2000-05-01T00:00:00\", \"price\": 25.45}, {\"symbol\": \"MSFT\", \"date\": \"2000-06-01T00:00:00\", \"price\": 32.54}, {\"symbol\": \"MSFT\", \"date\": \"2000-07-01T00:00:00\", \"price\": 28.4}, {\"symbol\": \"MSFT\", \"date\": \"2000-08-01T00:00:00\", \"price\": 28.4}, {\"symbol\": \"MSFT\", \"date\": \"2000-09-01T00:00:00\", \"price\": 24.53}, {\"symbol\": \"MSFT\", \"date\": \"2000-10-01T00:00:00\", \"price\": 28.02}, {\"symbol\": \"MSFT\", \"date\": \"2000-11-01T00:00:00\", \"price\": 23.34}, {\"symbol\": \"MSFT\", \"date\": \"2000-12-01T00:00:00\", \"price\": 17.65}, {\"symbol\": \"MSFT\", \"date\": \"2001-01-01T00:00:00\", \"price\": 24.84}, {\"symbol\": \"MSFT\", \"date\": \"2001-02-01T00:00:00\", \"price\": 24.0}, {\"symbol\": \"MSFT\", \"date\": \"2001-03-01T00:00:00\", \"price\": 22.25}, {\"symbol\": \"MSFT\", \"date\": \"2001-04-01T00:00:00\", \"price\": 27.56}, {\"symbol\": \"MSFT\", \"date\": \"2001-05-01T00:00:00\", \"price\": 28.14}, {\"symbol\": \"MSFT\", \"date\": \"2001-06-01T00:00:00\", \"price\": 29.7}, {\"symbol\": \"MSFT\", \"date\": \"2001-07-01T00:00:00\", \"price\": 26.93}, {\"symbol\": \"MSFT\", \"date\": \"2001-08-01T00:00:00\", \"price\": 23.21}, {\"symbol\": \"MSFT\", \"date\": \"2001-09-01T00:00:00\", \"price\": 20.82}, {\"symbol\": \"MSFT\", \"date\": \"2001-10-01T00:00:00\", \"price\": 23.65}, {\"symbol\": \"MSFT\", \"date\": \"2001-11-01T00:00:00\", \"price\": 26.12}, {\"symbol\": \"MSFT\", \"date\": \"2001-12-01T00:00:00\", \"price\": 26.95}, {\"symbol\": \"MSFT\", \"date\": \"2002-01-01T00:00:00\", \"price\": 25.92}, {\"symbol\": \"MSFT\", \"date\": \"2002-02-01T00:00:00\", \"price\": 23.73}, {\"symbol\": \"MSFT\", \"date\": \"2002-03-01T00:00:00\", \"price\": 24.53}, {\"symbol\": \"MSFT\", \"date\": \"2002-04-01T00:00:00\", \"price\": 21.26}, {\"symbol\": \"MSFT\", \"date\": \"2002-05-01T00:00:00\", \"price\": 20.71}, {\"symbol\": \"MSFT\", \"date\": \"2002-06-01T00:00:00\", \"price\": 22.25}, {\"symbol\": \"MSFT\", \"date\": \"2002-07-01T00:00:00\", \"price\": 19.52}, {\"symbol\": \"MSFT\", \"date\": \"2002-08-01T00:00:00\", \"price\": 19.97}, {\"symbol\": \"MSFT\", \"date\": \"2002-09-01T00:00:00\", \"price\": 17.79}, {\"symbol\": \"MSFT\", \"date\": \"2002-10-01T00:00:00\", \"price\": 21.75}, {\"symbol\": \"MSFT\", \"date\": \"2002-11-01T00:00:00\", \"price\": 23.46}, {\"symbol\": \"MSFT\", \"date\": \"2002-12-01T00:00:00\", \"price\": 21.03}, {\"symbol\": \"MSFT\", \"date\": \"2003-01-01T00:00:00\", \"price\": 19.31}, {\"symbol\": \"MSFT\", \"date\": \"2003-02-01T00:00:00\", \"price\": 19.34}, {\"symbol\": \"MSFT\", \"date\": \"2003-03-01T00:00:00\", \"price\": 19.76}, {\"symbol\": \"MSFT\", \"date\": \"2003-04-01T00:00:00\", \"price\": 20.87}, {\"symbol\": \"MSFT\", \"date\": \"2003-05-01T00:00:00\", \"price\": 20.09}, {\"symbol\": \"MSFT\", \"date\": \"2003-06-01T00:00:00\", \"price\": 20.93}, {\"symbol\": \"MSFT\", \"date\": \"2003-07-01T00:00:00\", \"price\": 21.56}, {\"symbol\": \"MSFT\", \"date\": \"2003-08-01T00:00:00\", \"price\": 21.65}, {\"symbol\": \"MSFT\", \"date\": \"2003-09-01T00:00:00\", \"price\": 22.69}, {\"symbol\": \"MSFT\", \"date\": \"2003-10-01T00:00:00\", \"price\": 21.45}, {\"symbol\": \"MSFT\", \"date\": \"2003-11-01T00:00:00\", \"price\": 21.1}, {\"symbol\": \"MSFT\", \"date\": \"2003-12-01T00:00:00\", \"price\": 22.46}, {\"symbol\": \"MSFT\", \"date\": \"2004-01-01T00:00:00\", \"price\": 22.69}, {\"symbol\": \"MSFT\", \"date\": \"2004-02-01T00:00:00\", \"price\": 21.77}, {\"symbol\": \"MSFT\", \"date\": \"2004-03-01T00:00:00\", \"price\": 20.46}, {\"symbol\": \"MSFT\", \"date\": \"2004-04-01T00:00:00\", \"price\": 21.45}, {\"symbol\": \"MSFT\", \"date\": \"2004-05-01T00:00:00\", \"price\": 21.53}, {\"symbol\": \"MSFT\", \"date\": \"2004-06-01T00:00:00\", \"price\": 23.44}, {\"symbol\": \"MSFT\", \"date\": \"2004-07-01T00:00:00\", \"price\": 23.38}, {\"symbol\": \"MSFT\", \"date\": \"2004-08-01T00:00:00\", \"price\": 22.47}, {\"symbol\": \"MSFT\", \"date\": \"2004-09-01T00:00:00\", \"price\": 22.76}, {\"symbol\": \"MSFT\", \"date\": \"2004-10-01T00:00:00\", \"price\": 23.02}, {\"symbol\": \"MSFT\", \"date\": \"2004-11-01T00:00:00\", \"price\": 24.6}, {\"symbol\": \"MSFT\", \"date\": \"2004-12-01T00:00:00\", \"price\": 24.52}, {\"symbol\": \"MSFT\", \"date\": \"2005-01-01T00:00:00\", \"price\": 24.11}, {\"symbol\": \"MSFT\", \"date\": \"2005-02-01T00:00:00\", \"price\": 23.15}, {\"symbol\": \"MSFT\", \"date\": \"2005-03-01T00:00:00\", \"price\": 22.24}, {\"symbol\": \"MSFT\", \"date\": \"2005-04-01T00:00:00\", \"price\": 23.28}, {\"symbol\": \"MSFT\", \"date\": \"2005-05-01T00:00:00\", \"price\": 23.82}, {\"symbol\": \"MSFT\", \"date\": \"2005-06-01T00:00:00\", \"price\": 22.93}, {\"symbol\": \"MSFT\", \"date\": \"2005-07-01T00:00:00\", \"price\": 23.64}, {\"symbol\": \"MSFT\", \"date\": \"2005-08-01T00:00:00\", \"price\": 25.35}, {\"symbol\": \"MSFT\", \"date\": \"2005-09-01T00:00:00\", \"price\": 23.83}, {\"symbol\": \"MSFT\", \"date\": \"2005-10-01T00:00:00\", \"price\": 23.8}, {\"symbol\": \"MSFT\", \"date\": \"2005-11-01T00:00:00\", \"price\": 25.71}, {\"symbol\": \"MSFT\", \"date\": \"2005-12-01T00:00:00\", \"price\": 24.29}, {\"symbol\": \"MSFT\", \"date\": \"2006-01-01T00:00:00\", \"price\": 26.14}, {\"symbol\": \"MSFT\", \"date\": \"2006-02-01T00:00:00\", \"price\": 25.04}, {\"symbol\": \"MSFT\", \"date\": \"2006-03-01T00:00:00\", \"price\": 25.36}, {\"symbol\": \"MSFT\", \"date\": \"2006-04-01T00:00:00\", \"price\": 22.5}, {\"symbol\": \"MSFT\", \"date\": \"2006-05-01T00:00:00\", \"price\": 21.19}, {\"symbol\": \"MSFT\", \"date\": \"2006-06-01T00:00:00\", \"price\": 21.8}, {\"symbol\": \"MSFT\", \"date\": \"2006-07-01T00:00:00\", \"price\": 22.51}, {\"symbol\": \"MSFT\", \"date\": \"2006-08-01T00:00:00\", \"price\": 24.13}, {\"symbol\": \"MSFT\", \"date\": \"2006-09-01T00:00:00\", \"price\": 25.68}, {\"symbol\": \"MSFT\", \"date\": \"2006-10-01T00:00:00\", \"price\": 26.96}, {\"symbol\": \"MSFT\", \"date\": \"2006-11-01T00:00:00\", \"price\": 27.66}, {\"symbol\": \"MSFT\", \"date\": \"2006-12-01T00:00:00\", \"price\": 28.13}, {\"symbol\": \"MSFT\", \"date\": \"2007-01-01T00:00:00\", \"price\": 29.07}, {\"symbol\": \"MSFT\", \"date\": \"2007-02-01T00:00:00\", \"price\": 26.63}, {\"symbol\": \"MSFT\", \"date\": \"2007-03-01T00:00:00\", \"price\": 26.35}, {\"symbol\": \"MSFT\", \"date\": \"2007-04-01T00:00:00\", \"price\": 28.3}, {\"symbol\": \"MSFT\", \"date\": \"2007-05-01T00:00:00\", \"price\": 29.11}, {\"symbol\": \"MSFT\", \"date\": \"2007-06-01T00:00:00\", \"price\": 27.95}, {\"symbol\": \"MSFT\", \"date\": \"2007-07-01T00:00:00\", \"price\": 27.5}, {\"symbol\": \"MSFT\", \"date\": \"2007-08-01T00:00:00\", \"price\": 27.34}, {\"symbol\": \"MSFT\", \"date\": \"2007-09-01T00:00:00\", \"price\": 28.04}, {\"symbol\": \"MSFT\", \"date\": \"2007-10-01T00:00:00\", \"price\": 35.03}, {\"symbol\": \"MSFT\", \"date\": \"2007-11-01T00:00:00\", \"price\": 32.09}, {\"symbol\": \"MSFT\", \"date\": \"2007-12-01T00:00:00\", \"price\": 34.0}, {\"symbol\": \"MSFT\", \"date\": \"2008-01-01T00:00:00\", \"price\": 31.13}, {\"symbol\": \"MSFT\", \"date\": \"2008-02-01T00:00:00\", \"price\": 26.07}, {\"symbol\": \"MSFT\", \"date\": \"2008-03-01T00:00:00\", \"price\": 27.21}, {\"symbol\": \"MSFT\", \"date\": \"2008-04-01T00:00:00\", \"price\": 27.34}, {\"symbol\": \"MSFT\", \"date\": \"2008-05-01T00:00:00\", \"price\": 27.25}, {\"symbol\": \"MSFT\", \"date\": \"2008-06-01T00:00:00\", \"price\": 26.47}, {\"symbol\": \"MSFT\", \"date\": \"2008-07-01T00:00:00\", \"price\": 24.75}, {\"symbol\": \"MSFT\", \"date\": \"2008-08-01T00:00:00\", \"price\": 26.36}, {\"symbol\": \"MSFT\", \"date\": \"2008-09-01T00:00:00\", \"price\": 25.78}, {\"symbol\": \"MSFT\", \"date\": \"2008-10-01T00:00:00\", \"price\": 21.57}, {\"symbol\": \"MSFT\", \"date\": \"2008-11-01T00:00:00\", \"price\": 19.66}, {\"symbol\": \"MSFT\", \"date\": \"2008-12-01T00:00:00\", \"price\": 18.91}, {\"symbol\": \"MSFT\", \"date\": \"2009-01-01T00:00:00\", \"price\": 16.63}, {\"symbol\": \"MSFT\", \"date\": \"2009-02-01T00:00:00\", \"price\": 15.81}, {\"symbol\": \"MSFT\", \"date\": \"2009-03-01T00:00:00\", \"price\": 17.99}, {\"symbol\": \"MSFT\", \"date\": \"2009-04-01T00:00:00\", \"price\": 19.84}, {\"symbol\": \"MSFT\", \"date\": \"2009-05-01T00:00:00\", \"price\": 20.59}, {\"symbol\": \"MSFT\", \"date\": \"2009-06-01T00:00:00\", \"price\": 23.42}, {\"symbol\": \"MSFT\", \"date\": \"2009-07-01T00:00:00\", \"price\": 23.18}, {\"symbol\": \"MSFT\", \"date\": \"2009-08-01T00:00:00\", \"price\": 24.43}, {\"symbol\": \"MSFT\", \"date\": \"2009-09-01T00:00:00\", \"price\": 25.49}, {\"symbol\": \"MSFT\", \"date\": \"2009-10-01T00:00:00\", \"price\": 27.48}, {\"symbol\": \"MSFT\", \"date\": \"2009-11-01T00:00:00\", \"price\": 29.27}, {\"symbol\": \"MSFT\", \"date\": \"2009-12-01T00:00:00\", \"price\": 30.34}, {\"symbol\": \"MSFT\", \"date\": \"2010-01-01T00:00:00\", \"price\": 28.05}, {\"symbol\": \"MSFT\", \"date\": \"2010-02-01T00:00:00\", \"price\": 28.67}, {\"symbol\": \"MSFT\", \"date\": \"2010-03-01T00:00:00\", \"price\": 28.8}, {\"symbol\": \"AMZN\", \"date\": \"2000-01-01T00:00:00\", \"price\": 64.56}, {\"symbol\": \"AMZN\", \"date\": \"2000-02-01T00:00:00\", \"price\": 68.87}, {\"symbol\": \"AMZN\", \"date\": \"2000-03-01T00:00:00\", \"price\": 67.0}, {\"symbol\": \"AMZN\", \"date\": \"2000-04-01T00:00:00\", \"price\": 55.19}, {\"symbol\": \"AMZN\", \"date\": \"2000-05-01T00:00:00\", \"price\": 48.31}, {\"symbol\": \"AMZN\", \"date\": \"2000-06-01T00:00:00\", \"price\": 36.31}, {\"symbol\": \"AMZN\", \"date\": \"2000-07-01T00:00:00\", \"price\": 30.12}, {\"symbol\": \"AMZN\", \"date\": \"2000-08-01T00:00:00\", \"price\": 41.5}, {\"symbol\": \"AMZN\", \"date\": \"2000-09-01T00:00:00\", \"price\": 38.44}, {\"symbol\": \"AMZN\", \"date\": \"2000-10-01T00:00:00\", \"price\": 36.62}, {\"symbol\": \"AMZN\", \"date\": \"2000-11-01T00:00:00\", \"price\": 24.69}, {\"symbol\": \"AMZN\", \"date\": \"2000-12-01T00:00:00\", \"price\": 15.56}, {\"symbol\": \"AMZN\", \"date\": \"2001-01-01T00:00:00\", \"price\": 17.31}, {\"symbol\": \"AMZN\", \"date\": \"2001-02-01T00:00:00\", \"price\": 10.19}, {\"symbol\": \"AMZN\", \"date\": \"2001-03-01T00:00:00\", \"price\": 10.23}, {\"symbol\": \"AMZN\", \"date\": \"2001-04-01T00:00:00\", \"price\": 15.78}, {\"symbol\": \"AMZN\", \"date\": \"2001-05-01T00:00:00\", \"price\": 16.69}, {\"symbol\": \"AMZN\", \"date\": \"2001-06-01T00:00:00\", \"price\": 14.15}, {\"symbol\": \"AMZN\", \"date\": \"2001-07-01T00:00:00\", \"price\": 12.49}, {\"symbol\": \"AMZN\", \"date\": \"2001-08-01T00:00:00\", \"price\": 8.94}, {\"symbol\": \"AMZN\", \"date\": \"2001-09-01T00:00:00\", \"price\": 5.97}, {\"symbol\": \"AMZN\", \"date\": \"2001-10-01T00:00:00\", \"price\": 6.98}, {\"symbol\": \"AMZN\", \"date\": \"2001-11-01T00:00:00\", \"price\": 11.32}, {\"symbol\": \"AMZN\", \"date\": \"2001-12-01T00:00:00\", \"price\": 10.82}, {\"symbol\": \"AMZN\", \"date\": \"2002-01-01T00:00:00\", \"price\": 14.19}, {\"symbol\": \"AMZN\", \"date\": \"2002-02-01T00:00:00\", \"price\": 14.1}, {\"symbol\": \"AMZN\", \"date\": \"2002-03-01T00:00:00\", \"price\": 14.3}, {\"symbol\": \"AMZN\", \"date\": \"2002-04-01T00:00:00\", \"price\": 16.69}, {\"symbol\": \"AMZN\", \"date\": \"2002-05-01T00:00:00\", \"price\": 18.23}, {\"symbol\": \"AMZN\", \"date\": \"2002-06-01T00:00:00\", \"price\": 16.25}, {\"symbol\": \"AMZN\", \"date\": \"2002-07-01T00:00:00\", \"price\": 14.45}, {\"symbol\": \"AMZN\", \"date\": \"2002-08-01T00:00:00\", \"price\": 14.94}, {\"symbol\": \"AMZN\", \"date\": \"2002-09-01T00:00:00\", \"price\": 15.93}, {\"symbol\": \"AMZN\", \"date\": \"2002-10-01T00:00:00\", \"price\": 19.36}, {\"symbol\": \"AMZN\", \"date\": \"2002-11-01T00:00:00\", \"price\": 23.35}, {\"symbol\": \"AMZN\", \"date\": \"2002-12-01T00:00:00\", \"price\": 18.89}, {\"symbol\": \"AMZN\", \"date\": \"2003-01-01T00:00:00\", \"price\": 21.85}, {\"symbol\": \"AMZN\", \"date\": \"2003-02-01T00:00:00\", \"price\": 22.01}, {\"symbol\": \"AMZN\", \"date\": \"2003-03-01T00:00:00\", \"price\": 26.03}, {\"symbol\": \"AMZN\", \"date\": \"2003-04-01T00:00:00\", \"price\": 28.69}, {\"symbol\": \"AMZN\", \"date\": \"2003-05-01T00:00:00\", \"price\": 35.89}, {\"symbol\": \"AMZN\", \"date\": \"2003-06-01T00:00:00\", \"price\": 36.32}, {\"symbol\": \"AMZN\", \"date\": \"2003-07-01T00:00:00\", \"price\": 41.64}, {\"symbol\": \"AMZN\", \"date\": \"2003-08-01T00:00:00\", \"price\": 46.32}, {\"symbol\": \"AMZN\", \"date\": \"2003-09-01T00:00:00\", \"price\": 48.43}, {\"symbol\": \"AMZN\", \"date\": \"2003-10-01T00:00:00\", \"price\": 54.43}, {\"symbol\": \"AMZN\", \"date\": \"2003-11-01T00:00:00\", \"price\": 53.97}, {\"symbol\": \"AMZN\", \"date\": \"2003-12-01T00:00:00\", \"price\": 52.62}, {\"symbol\": \"AMZN\", \"date\": \"2004-01-01T00:00:00\", \"price\": 50.4}, {\"symbol\": \"AMZN\", \"date\": \"2004-02-01T00:00:00\", \"price\": 43.01}, {\"symbol\": \"AMZN\", \"date\": \"2004-03-01T00:00:00\", \"price\": 43.28}, {\"symbol\": \"AMZN\", \"date\": \"2004-04-01T00:00:00\", \"price\": 43.6}, {\"symbol\": \"AMZN\", \"date\": \"2004-05-01T00:00:00\", \"price\": 48.5}, {\"symbol\": \"AMZN\", \"date\": \"2004-06-01T00:00:00\", \"price\": 54.4}, {\"symbol\": \"AMZN\", \"date\": \"2004-07-01T00:00:00\", \"price\": 38.92}, {\"symbol\": \"AMZN\", \"date\": \"2004-08-01T00:00:00\", \"price\": 38.14}, {\"symbol\": \"AMZN\", \"date\": \"2004-09-01T00:00:00\", \"price\": 40.86}, {\"symbol\": \"AMZN\", \"date\": \"2004-10-01T00:00:00\", \"price\": 34.13}, {\"symbol\": \"AMZN\", \"date\": \"2004-11-01T00:00:00\", \"price\": 39.68}, {\"symbol\": \"AMZN\", \"date\": \"2004-12-01T00:00:00\", \"price\": 44.29}, {\"symbol\": \"AMZN\", \"date\": \"2005-01-01T00:00:00\", \"price\": 43.22}, {\"symbol\": \"AMZN\", \"date\": \"2005-02-01T00:00:00\", \"price\": 35.18}, {\"symbol\": \"AMZN\", \"date\": \"2005-03-01T00:00:00\", \"price\": 34.27}, {\"symbol\": \"AMZN\", \"date\": \"2005-04-01T00:00:00\", \"price\": 32.36}, {\"symbol\": \"AMZN\", \"date\": \"2005-05-01T00:00:00\", \"price\": 35.51}, {\"symbol\": \"AMZN\", \"date\": \"2005-06-01T00:00:00\", \"price\": 33.09}, {\"symbol\": \"AMZN\", \"date\": \"2005-07-01T00:00:00\", \"price\": 45.15}, {\"symbol\": \"AMZN\", \"date\": \"2005-08-01T00:00:00\", \"price\": 42.7}, {\"symbol\": \"AMZN\", \"date\": \"2005-09-01T00:00:00\", \"price\": 45.3}, {\"symbol\": \"AMZN\", \"date\": \"2005-10-01T00:00:00\", \"price\": 39.86}, {\"symbol\": \"AMZN\", \"date\": \"2005-11-01T00:00:00\", \"price\": 48.46}, {\"symbol\": \"AMZN\", \"date\": \"2005-12-01T00:00:00\", \"price\": 47.15}, {\"symbol\": \"AMZN\", \"date\": \"2006-01-01T00:00:00\", \"price\": 44.82}, {\"symbol\": \"AMZN\", \"date\": \"2006-02-01T00:00:00\", \"price\": 37.44}, {\"symbol\": \"AMZN\", \"date\": \"2006-03-01T00:00:00\", \"price\": 36.53}, {\"symbol\": \"AMZN\", \"date\": \"2006-04-01T00:00:00\", \"price\": 35.21}, {\"symbol\": \"AMZN\", \"date\": \"2006-05-01T00:00:00\", \"price\": 34.61}, {\"symbol\": \"AMZN\", \"date\": \"2006-06-01T00:00:00\", \"price\": 38.68}, {\"symbol\": \"AMZN\", \"date\": \"2006-07-01T00:00:00\", \"price\": 26.89}, {\"symbol\": \"AMZN\", \"date\": \"2006-08-01T00:00:00\", \"price\": 30.83}, {\"symbol\": \"AMZN\", \"date\": \"2006-09-01T00:00:00\", \"price\": 32.12}, {\"symbol\": \"AMZN\", \"date\": \"2006-10-01T00:00:00\", \"price\": 38.09}, {\"symbol\": \"AMZN\", \"date\": \"2006-11-01T00:00:00\", \"price\": 40.34}, {\"symbol\": \"AMZN\", \"date\": \"2006-12-01T00:00:00\", \"price\": 39.46}, {\"symbol\": \"AMZN\", \"date\": \"2007-01-01T00:00:00\", \"price\": 37.67}, {\"symbol\": \"AMZN\", \"date\": \"2007-02-01T00:00:00\", \"price\": 39.14}, {\"symbol\": \"AMZN\", \"date\": \"2007-03-01T00:00:00\", \"price\": 39.79}, {\"symbol\": \"AMZN\", \"date\": \"2007-04-01T00:00:00\", \"price\": 61.33}, {\"symbol\": \"AMZN\", \"date\": \"2007-05-01T00:00:00\", \"price\": 69.14}, {\"symbol\": \"AMZN\", \"date\": \"2007-06-01T00:00:00\", \"price\": 68.41}, {\"symbol\": \"AMZN\", \"date\": \"2007-07-01T00:00:00\", \"price\": 78.54}, {\"symbol\": \"AMZN\", \"date\": \"2007-08-01T00:00:00\", \"price\": 79.91}, {\"symbol\": \"AMZN\", \"date\": \"2007-09-01T00:00:00\", \"price\": 93.15}, {\"symbol\": \"AMZN\", \"date\": \"2007-10-01T00:00:00\", \"price\": 89.15}, {\"symbol\": \"AMZN\", \"date\": \"2007-11-01T00:00:00\", \"price\": 90.56}, {\"symbol\": \"AMZN\", \"date\": \"2007-12-01T00:00:00\", \"price\": 92.64}, {\"symbol\": \"AMZN\", \"date\": \"2008-01-01T00:00:00\", \"price\": 77.7}, {\"symbol\": \"AMZN\", \"date\": \"2008-02-01T00:00:00\", \"price\": 64.47}, {\"symbol\": \"AMZN\", \"date\": \"2008-03-01T00:00:00\", \"price\": 71.3}, {\"symbol\": \"AMZN\", \"date\": \"2008-04-01T00:00:00\", \"price\": 78.63}, {\"symbol\": \"AMZN\", \"date\": \"2008-05-01T00:00:00\", \"price\": 81.62}, {\"symbol\": \"AMZN\", \"date\": \"2008-06-01T00:00:00\", \"price\": 73.33}, {\"symbol\": \"AMZN\", \"date\": \"2008-07-01T00:00:00\", \"price\": 76.34}, {\"symbol\": \"AMZN\", \"date\": \"2008-08-01T00:00:00\", \"price\": 80.81}, {\"symbol\": \"AMZN\", \"date\": \"2008-09-01T00:00:00\", \"price\": 72.76}, {\"symbol\": \"AMZN\", \"date\": \"2008-10-01T00:00:00\", \"price\": 57.24}, {\"symbol\": \"AMZN\", \"date\": \"2008-11-01T00:00:00\", \"price\": 42.7}, {\"symbol\": \"AMZN\", \"date\": \"2008-12-01T00:00:00\", \"price\": 51.28}, {\"symbol\": \"AMZN\", \"date\": \"2009-01-01T00:00:00\", \"price\": 58.82}, {\"symbol\": \"AMZN\", \"date\": \"2009-02-01T00:00:00\", \"price\": 64.79}, {\"symbol\": \"AMZN\", \"date\": \"2009-03-01T00:00:00\", \"price\": 73.44}, {\"symbol\": \"AMZN\", \"date\": \"2009-04-01T00:00:00\", \"price\": 80.52}, {\"symbol\": \"AMZN\", \"date\": \"2009-05-01T00:00:00\", \"price\": 77.99}, {\"symbol\": \"AMZN\", \"date\": \"2009-06-01T00:00:00\", \"price\": 83.66}, {\"symbol\": \"AMZN\", \"date\": \"2009-07-01T00:00:00\", \"price\": 85.76}, {\"symbol\": \"AMZN\", \"date\": \"2009-08-01T00:00:00\", \"price\": 81.19}, {\"symbol\": \"AMZN\", \"date\": \"2009-09-01T00:00:00\", \"price\": 93.36}, {\"symbol\": \"AMZN\", \"date\": \"2009-10-01T00:00:00\", \"price\": 118.81}, {\"symbol\": \"AMZN\", \"date\": \"2009-11-01T00:00:00\", \"price\": 135.91}, {\"symbol\": \"AMZN\", \"date\": \"2009-12-01T00:00:00\", \"price\": 134.52}, {\"symbol\": \"AMZN\", \"date\": \"2010-01-01T00:00:00\", \"price\": 125.41}, {\"symbol\": \"AMZN\", \"date\": \"2010-02-01T00:00:00\", \"price\": 118.4}, {\"symbol\": \"AMZN\", \"date\": \"2010-03-01T00:00:00\", \"price\": 128.82}, {\"symbol\": \"IBM\", \"date\": \"2000-01-01T00:00:00\", \"price\": 100.52}, {\"symbol\": \"IBM\", \"date\": \"2000-02-01T00:00:00\", \"price\": 92.11}, {\"symbol\": \"IBM\", \"date\": \"2000-03-01T00:00:00\", \"price\": 106.11}, {\"symbol\": \"IBM\", \"date\": \"2000-04-01T00:00:00\", \"price\": 99.95}, {\"symbol\": \"IBM\", \"date\": \"2000-05-01T00:00:00\", \"price\": 96.31}, {\"symbol\": \"IBM\", \"date\": \"2000-06-01T00:00:00\", \"price\": 98.33}, {\"symbol\": \"IBM\", \"date\": \"2000-07-01T00:00:00\", \"price\": 100.74}, {\"symbol\": \"IBM\", \"date\": \"2000-08-01T00:00:00\", \"price\": 118.62}, {\"symbol\": \"IBM\", \"date\": \"2000-09-01T00:00:00\", \"price\": 101.19}, {\"symbol\": \"IBM\", \"date\": \"2000-10-01T00:00:00\", \"price\": 88.5}, {\"symbol\": \"IBM\", \"date\": \"2000-11-01T00:00:00\", \"price\": 84.12}, {\"symbol\": \"IBM\", \"date\": \"2000-12-01T00:00:00\", \"price\": 76.47}, {\"symbol\": \"IBM\", \"date\": \"2001-01-01T00:00:00\", \"price\": 100.76}, {\"symbol\": \"IBM\", \"date\": \"2001-02-01T00:00:00\", \"price\": 89.98}, {\"symbol\": \"IBM\", \"date\": \"2001-03-01T00:00:00\", \"price\": 86.63}, {\"symbol\": \"IBM\", \"date\": \"2001-04-01T00:00:00\", \"price\": 103.7}, {\"symbol\": \"IBM\", \"date\": \"2001-05-01T00:00:00\", \"price\": 100.82}, {\"symbol\": \"IBM\", \"date\": \"2001-06-01T00:00:00\", \"price\": 102.35}, {\"symbol\": \"IBM\", \"date\": \"2001-07-01T00:00:00\", \"price\": 94.87}, {\"symbol\": \"IBM\", \"date\": \"2001-08-01T00:00:00\", \"price\": 90.25}, {\"symbol\": \"IBM\", \"date\": \"2001-09-01T00:00:00\", \"price\": 82.82}, {\"symbol\": \"IBM\", \"date\": \"2001-10-01T00:00:00\", \"price\": 97.58}, {\"symbol\": \"IBM\", \"date\": \"2001-11-01T00:00:00\", \"price\": 104.5}, {\"symbol\": \"IBM\", \"date\": \"2001-12-01T00:00:00\", \"price\": 109.36}, {\"symbol\": \"IBM\", \"date\": \"2002-01-01T00:00:00\", \"price\": 97.54}, {\"symbol\": \"IBM\", \"date\": \"2002-02-01T00:00:00\", \"price\": 88.82}, {\"symbol\": \"IBM\", \"date\": \"2002-03-01T00:00:00\", \"price\": 94.15}, {\"symbol\": \"IBM\", \"date\": \"2002-04-01T00:00:00\", \"price\": 75.82}, {\"symbol\": \"IBM\", \"date\": \"2002-05-01T00:00:00\", \"price\": 72.97}, {\"symbol\": \"IBM\", \"date\": \"2002-06-01T00:00:00\", \"price\": 65.31}, {\"symbol\": \"IBM\", \"date\": \"2002-07-01T00:00:00\", \"price\": 63.86}, {\"symbol\": \"IBM\", \"date\": \"2002-08-01T00:00:00\", \"price\": 68.52}, {\"symbol\": \"IBM\", \"date\": \"2002-09-01T00:00:00\", \"price\": 53.01}, {\"symbol\": \"IBM\", \"date\": \"2002-10-01T00:00:00\", \"price\": 71.76}, {\"symbol\": \"IBM\", \"date\": \"2002-11-01T00:00:00\", \"price\": 79.16}, {\"symbol\": \"IBM\", \"date\": \"2002-12-01T00:00:00\", \"price\": 70.58}, {\"symbol\": \"IBM\", \"date\": \"2003-01-01T00:00:00\", \"price\": 71.22}, {\"symbol\": \"IBM\", \"date\": \"2003-02-01T00:00:00\", \"price\": 71.13}, {\"symbol\": \"IBM\", \"date\": \"2003-03-01T00:00:00\", \"price\": 71.57}, {\"symbol\": \"IBM\", \"date\": \"2003-04-01T00:00:00\", \"price\": 77.47}, {\"symbol\": \"IBM\", \"date\": \"2003-05-01T00:00:00\", \"price\": 80.48}, {\"symbol\": \"IBM\", \"date\": \"2003-06-01T00:00:00\", \"price\": 75.42}, {\"symbol\": \"IBM\", \"date\": \"2003-07-01T00:00:00\", \"price\": 74.28}, {\"symbol\": \"IBM\", \"date\": \"2003-08-01T00:00:00\", \"price\": 75.12}, {\"symbol\": \"IBM\", \"date\": \"2003-09-01T00:00:00\", \"price\": 80.91}, {\"symbol\": \"IBM\", \"date\": \"2003-10-01T00:00:00\", \"price\": 81.96}, {\"symbol\": \"IBM\", \"date\": \"2003-11-01T00:00:00\", \"price\": 83.08}, {\"symbol\": \"IBM\", \"date\": \"2003-12-01T00:00:00\", \"price\": 85.05}, {\"symbol\": \"IBM\", \"date\": \"2004-01-01T00:00:00\", \"price\": 91.06}, {\"symbol\": \"IBM\", \"date\": \"2004-02-01T00:00:00\", \"price\": 88.7}, {\"symbol\": \"IBM\", \"date\": \"2004-03-01T00:00:00\", \"price\": 84.41}, {\"symbol\": \"IBM\", \"date\": \"2004-04-01T00:00:00\", \"price\": 81.04}, {\"symbol\": \"IBM\", \"date\": \"2004-05-01T00:00:00\", \"price\": 81.59}, {\"symbol\": \"IBM\", \"date\": \"2004-06-01T00:00:00\", \"price\": 81.19}, {\"symbol\": \"IBM\", \"date\": \"2004-07-01T00:00:00\", \"price\": 80.19}, {\"symbol\": \"IBM\", \"date\": \"2004-08-01T00:00:00\", \"price\": 78.17}, {\"symbol\": \"IBM\", \"date\": \"2004-09-01T00:00:00\", \"price\": 79.13}, {\"symbol\": \"IBM\", \"date\": \"2004-10-01T00:00:00\", \"price\": 82.84}, {\"symbol\": \"IBM\", \"date\": \"2004-11-01T00:00:00\", \"price\": 87.15}, {\"symbol\": \"IBM\", \"date\": \"2004-12-01T00:00:00\", \"price\": 91.16}, {\"symbol\": \"IBM\", \"date\": \"2005-01-01T00:00:00\", \"price\": 86.39}, {\"symbol\": \"IBM\", \"date\": \"2005-02-01T00:00:00\", \"price\": 85.78}, {\"symbol\": \"IBM\", \"date\": \"2005-03-01T00:00:00\", \"price\": 84.66}, {\"symbol\": \"IBM\", \"date\": \"2005-04-01T00:00:00\", \"price\": 70.77}, {\"symbol\": \"IBM\", \"date\": \"2005-05-01T00:00:00\", \"price\": 70.18}, {\"symbol\": \"IBM\", \"date\": \"2005-06-01T00:00:00\", \"price\": 68.93}, {\"symbol\": \"IBM\", \"date\": \"2005-07-01T00:00:00\", \"price\": 77.53}, {\"symbol\": \"IBM\", \"date\": \"2005-08-01T00:00:00\", \"price\": 75.07}, {\"symbol\": \"IBM\", \"date\": \"2005-09-01T00:00:00\", \"price\": 74.7}, {\"symbol\": \"IBM\", \"date\": \"2005-10-01T00:00:00\", \"price\": 76.25}, {\"symbol\": \"IBM\", \"date\": \"2005-11-01T00:00:00\", \"price\": 82.98}, {\"symbol\": \"IBM\", \"date\": \"2005-12-01T00:00:00\", \"price\": 76.73}, {\"symbol\": \"IBM\", \"date\": \"2006-01-01T00:00:00\", \"price\": 75.89}, {\"symbol\": \"IBM\", \"date\": \"2006-02-01T00:00:00\", \"price\": 75.09}, {\"symbol\": \"IBM\", \"date\": \"2006-03-01T00:00:00\", \"price\": 77.17}, {\"symbol\": \"IBM\", \"date\": \"2006-04-01T00:00:00\", \"price\": 77.05}, {\"symbol\": \"IBM\", \"date\": \"2006-05-01T00:00:00\", \"price\": 75.04}, {\"symbol\": \"IBM\", \"date\": \"2006-06-01T00:00:00\", \"price\": 72.15}, {\"symbol\": \"IBM\", \"date\": \"2006-07-01T00:00:00\", \"price\": 72.7}, {\"symbol\": \"IBM\", \"date\": \"2006-08-01T00:00:00\", \"price\": 76.35}, {\"symbol\": \"IBM\", \"date\": \"2006-09-01T00:00:00\", \"price\": 77.26}, {\"symbol\": \"IBM\", \"date\": \"2006-10-01T00:00:00\", \"price\": 87.06}, {\"symbol\": \"IBM\", \"date\": \"2006-11-01T00:00:00\", \"price\": 86.95}, {\"symbol\": \"IBM\", \"date\": \"2006-12-01T00:00:00\", \"price\": 91.9}, {\"symbol\": \"IBM\", \"date\": \"2007-01-01T00:00:00\", \"price\": 93.79}, {\"symbol\": \"IBM\", \"date\": \"2007-02-01T00:00:00\", \"price\": 88.18}, {\"symbol\": \"IBM\", \"date\": \"2007-03-01T00:00:00\", \"price\": 89.44}, {\"symbol\": \"IBM\", \"date\": \"2007-04-01T00:00:00\", \"price\": 96.98}, {\"symbol\": \"IBM\", \"date\": \"2007-05-01T00:00:00\", \"price\": 101.54}, {\"symbol\": \"IBM\", \"date\": \"2007-06-01T00:00:00\", \"price\": 100.25}, {\"symbol\": \"IBM\", \"date\": \"2007-07-01T00:00:00\", \"price\": 105.4}, {\"symbol\": \"IBM\", \"date\": \"2007-08-01T00:00:00\", \"price\": 111.54}, {\"symbol\": \"IBM\", \"date\": \"2007-09-01T00:00:00\", \"price\": 112.6}, {\"symbol\": \"IBM\", \"date\": \"2007-10-01T00:00:00\", \"price\": 111.0}, {\"symbol\": \"IBM\", \"date\": \"2007-11-01T00:00:00\", \"price\": 100.9}, {\"symbol\": \"IBM\", \"date\": \"2007-12-01T00:00:00\", \"price\": 103.7}, {\"symbol\": \"IBM\", \"date\": \"2008-01-01T00:00:00\", \"price\": 102.75}, {\"symbol\": \"IBM\", \"date\": \"2008-02-01T00:00:00\", \"price\": 109.64}, {\"symbol\": \"IBM\", \"date\": \"2008-03-01T00:00:00\", \"price\": 110.87}, {\"symbol\": \"IBM\", \"date\": \"2008-04-01T00:00:00\", \"price\": 116.23}, {\"symbol\": \"IBM\", \"date\": \"2008-05-01T00:00:00\", \"price\": 125.14}, {\"symbol\": \"IBM\", \"date\": \"2008-06-01T00:00:00\", \"price\": 114.6}, {\"symbol\": \"IBM\", \"date\": \"2008-07-01T00:00:00\", \"price\": 123.74}, {\"symbol\": \"IBM\", \"date\": \"2008-08-01T00:00:00\", \"price\": 118.16}, {\"symbol\": \"IBM\", \"date\": \"2008-09-01T00:00:00\", \"price\": 113.53}, {\"symbol\": \"IBM\", \"date\": \"2008-10-01T00:00:00\", \"price\": 90.24}, {\"symbol\": \"IBM\", \"date\": \"2008-11-01T00:00:00\", \"price\": 79.65}, {\"symbol\": \"IBM\", \"date\": \"2008-12-01T00:00:00\", \"price\": 82.15}, {\"symbol\": \"IBM\", \"date\": \"2009-01-01T00:00:00\", \"price\": 89.46}, {\"symbol\": \"IBM\", \"date\": \"2009-02-01T00:00:00\", \"price\": 90.32}, {\"symbol\": \"IBM\", \"date\": \"2009-03-01T00:00:00\", \"price\": 95.09}, {\"symbol\": \"IBM\", \"date\": \"2009-04-01T00:00:00\", \"price\": 101.29}, {\"symbol\": \"IBM\", \"date\": \"2009-05-01T00:00:00\", \"price\": 104.85}, {\"symbol\": \"IBM\", \"date\": \"2009-06-01T00:00:00\", \"price\": 103.01}, {\"symbol\": \"IBM\", \"date\": \"2009-07-01T00:00:00\", \"price\": 116.34}, {\"symbol\": \"IBM\", \"date\": \"2009-08-01T00:00:00\", \"price\": 117.0}, {\"symbol\": \"IBM\", \"date\": \"2009-09-01T00:00:00\", \"price\": 118.55}, {\"symbol\": \"IBM\", \"date\": \"2009-10-01T00:00:00\", \"price\": 119.54}, {\"symbol\": \"IBM\", \"date\": \"2009-11-01T00:00:00\", \"price\": 125.79}, {\"symbol\": \"IBM\", \"date\": \"2009-12-01T00:00:00\", \"price\": 130.32}, {\"symbol\": \"IBM\", \"date\": \"2010-01-01T00:00:00\", \"price\": 121.85}, {\"symbol\": \"IBM\", \"date\": \"2010-02-01T00:00:00\", \"price\": 127.16}, {\"symbol\": \"IBM\", \"date\": \"2010-03-01T00:00:00\", \"price\": 125.55}, {\"symbol\": \"GOOG\", \"date\": \"2004-08-01T00:00:00\", \"price\": 102.37}, {\"symbol\": \"GOOG\", \"date\": \"2004-09-01T00:00:00\", \"price\": 129.6}, {\"symbol\": \"GOOG\", \"date\": \"2004-10-01T00:00:00\", \"price\": 190.64}, {\"symbol\": \"GOOG\", \"date\": \"2004-11-01T00:00:00\", \"price\": 181.98}, {\"symbol\": \"GOOG\", \"date\": \"2004-12-01T00:00:00\", \"price\": 192.79}, {\"symbol\": \"GOOG\", \"date\": \"2005-01-01T00:00:00\", \"price\": 195.62}, {\"symbol\": \"GOOG\", \"date\": \"2005-02-01T00:00:00\", \"price\": 187.99}, {\"symbol\": \"GOOG\", \"date\": \"2005-03-01T00:00:00\", \"price\": 180.51}, {\"symbol\": \"GOOG\", \"date\": \"2005-04-01T00:00:00\", \"price\": 220.0}, {\"symbol\": \"GOOG\", \"date\": \"2005-05-01T00:00:00\", \"price\": 277.27}, {\"symbol\": \"GOOG\", \"date\": \"2005-06-01T00:00:00\", \"price\": 294.15}, {\"symbol\": \"GOOG\", \"date\": \"2005-07-01T00:00:00\", \"price\": 287.76}, {\"symbol\": \"GOOG\", \"date\": \"2005-08-01T00:00:00\", \"price\": 286.0}, {\"symbol\": \"GOOG\", \"date\": \"2005-09-01T00:00:00\", \"price\": 316.46}, {\"symbol\": \"GOOG\", \"date\": \"2005-10-01T00:00:00\", \"price\": 372.14}, {\"symbol\": \"GOOG\", \"date\": \"2005-11-01T00:00:00\", \"price\": 404.91}, {\"symbol\": \"GOOG\", \"date\": \"2005-12-01T00:00:00\", \"price\": 414.86}, {\"symbol\": \"GOOG\", \"date\": \"2006-01-01T00:00:00\", \"price\": 432.66}, {\"symbol\": \"GOOG\", \"date\": \"2006-02-01T00:00:00\", \"price\": 362.62}, {\"symbol\": \"GOOG\", \"date\": \"2006-03-01T00:00:00\", \"price\": 390.0}, {\"symbol\": \"GOOG\", \"date\": \"2006-04-01T00:00:00\", \"price\": 417.94}, {\"symbol\": \"GOOG\", \"date\": \"2006-05-01T00:00:00\", \"price\": 371.82}, {\"symbol\": \"GOOG\", \"date\": \"2006-06-01T00:00:00\", \"price\": 419.33}, {\"symbol\": \"GOOG\", \"date\": \"2006-07-01T00:00:00\", \"price\": 386.6}, {\"symbol\": \"GOOG\", \"date\": \"2006-08-01T00:00:00\", \"price\": 378.53}, {\"symbol\": \"GOOG\", \"date\": \"2006-09-01T00:00:00\", \"price\": 401.9}, {\"symbol\": \"GOOG\", \"date\": \"2006-10-01T00:00:00\", \"price\": 476.39}, {\"symbol\": \"GOOG\", \"date\": \"2006-11-01T00:00:00\", \"price\": 484.81}, {\"symbol\": \"GOOG\", \"date\": \"2006-12-01T00:00:00\", \"price\": 460.48}, {\"symbol\": \"GOOG\", \"date\": \"2007-01-01T00:00:00\", \"price\": 501.5}, {\"symbol\": \"GOOG\", \"date\": \"2007-02-01T00:00:00\", \"price\": 449.45}, {\"symbol\": \"GOOG\", \"date\": \"2007-03-01T00:00:00\", \"price\": 458.16}, {\"symbol\": \"GOOG\", \"date\": \"2007-04-01T00:00:00\", \"price\": 471.38}, {\"symbol\": \"GOOG\", \"date\": \"2007-05-01T00:00:00\", \"price\": 497.91}, {\"symbol\": \"GOOG\", \"date\": \"2007-06-01T00:00:00\", \"price\": 522.7}, {\"symbol\": \"GOOG\", \"date\": \"2007-07-01T00:00:00\", \"price\": 510.0}, {\"symbol\": \"GOOG\", \"date\": \"2007-08-01T00:00:00\", \"price\": 515.25}, {\"symbol\": \"GOOG\", \"date\": \"2007-09-01T00:00:00\", \"price\": 567.27}, {\"symbol\": \"GOOG\", \"date\": \"2007-10-01T00:00:00\", \"price\": 707.0}, {\"symbol\": \"GOOG\", \"date\": \"2007-11-01T00:00:00\", \"price\": 693.0}, {\"symbol\": \"GOOG\", \"date\": \"2007-12-01T00:00:00\", \"price\": 691.48}, {\"symbol\": \"GOOG\", \"date\": \"2008-01-01T00:00:00\", \"price\": 564.3}, {\"symbol\": \"GOOG\", \"date\": \"2008-02-01T00:00:00\", \"price\": 471.18}, {\"symbol\": \"GOOG\", \"date\": \"2008-03-01T00:00:00\", \"price\": 440.47}, {\"symbol\": \"GOOG\", \"date\": \"2008-04-01T00:00:00\", \"price\": 574.29}, {\"symbol\": \"GOOG\", \"date\": \"2008-05-01T00:00:00\", \"price\": 585.8}, {\"symbol\": \"GOOG\", \"date\": \"2008-06-01T00:00:00\", \"price\": 526.42}, {\"symbol\": \"GOOG\", \"date\": \"2008-07-01T00:00:00\", \"price\": 473.75}, {\"symbol\": \"GOOG\", \"date\": \"2008-08-01T00:00:00\", \"price\": 463.29}, {\"symbol\": \"GOOG\", \"date\": \"2008-09-01T00:00:00\", \"price\": 400.52}, {\"symbol\": \"GOOG\", \"date\": \"2008-10-01T00:00:00\", \"price\": 359.36}, {\"symbol\": \"GOOG\", \"date\": \"2008-11-01T00:00:00\", \"price\": 292.96}, {\"symbol\": \"GOOG\", \"date\": \"2008-12-01T00:00:00\", \"price\": 307.65}, {\"symbol\": \"GOOG\", \"date\": \"2009-01-01T00:00:00\", \"price\": 338.53}, {\"symbol\": \"GOOG\", \"date\": \"2009-02-01T00:00:00\", \"price\": 337.99}, {\"symbol\": \"GOOG\", \"date\": \"2009-03-01T00:00:00\", \"price\": 348.06}, {\"symbol\": \"GOOG\", \"date\": \"2009-04-01T00:00:00\", \"price\": 395.97}, {\"symbol\": \"GOOG\", \"date\": \"2009-05-01T00:00:00\", \"price\": 417.23}, {\"symbol\": \"GOOG\", \"date\": \"2009-06-01T00:00:00\", \"price\": 421.59}, {\"symbol\": \"GOOG\", \"date\": \"2009-07-01T00:00:00\", \"price\": 443.05}, {\"symbol\": \"GOOG\", \"date\": \"2009-08-01T00:00:00\", \"price\": 461.67}, {\"symbol\": \"GOOG\", \"date\": \"2009-09-01T00:00:00\", \"price\": 495.85}, {\"symbol\": \"GOOG\", \"date\": \"2009-10-01T00:00:00\", \"price\": 536.12}, {\"symbol\": \"GOOG\", \"date\": \"2009-11-01T00:00:00\", \"price\": 583.0}, {\"symbol\": \"GOOG\", \"date\": \"2009-12-01T00:00:00\", \"price\": 619.98}, {\"symbol\": \"GOOG\", \"date\": \"2010-01-01T00:00:00\", \"price\": 529.94}, {\"symbol\": \"GOOG\", \"date\": \"2010-02-01T00:00:00\", \"price\": 526.8}, {\"symbol\": \"GOOG\", \"date\": \"2010-03-01T00:00:00\", \"price\": 560.19}, {\"symbol\": \"AAPL\", \"date\": \"2000-01-01T00:00:00\", \"price\": 25.94}, {\"symbol\": \"AAPL\", \"date\": \"2000-02-01T00:00:00\", \"price\": 28.66}, {\"symbol\": \"AAPL\", \"date\": \"2000-03-01T00:00:00\", \"price\": 33.95}, {\"symbol\": \"AAPL\", \"date\": \"2000-04-01T00:00:00\", \"price\": 31.01}, {\"symbol\": \"AAPL\", \"date\": \"2000-05-01T00:00:00\", \"price\": 21.0}, {\"symbol\": \"AAPL\", \"date\": \"2000-06-01T00:00:00\", \"price\": 26.19}, {\"symbol\": \"AAPL\", \"date\": \"2000-07-01T00:00:00\", \"price\": 25.41}, {\"symbol\": \"AAPL\", \"date\": \"2000-08-01T00:00:00\", \"price\": 30.47}, {\"symbol\": \"AAPL\", \"date\": \"2000-09-01T00:00:00\", \"price\": 12.88}, {\"symbol\": \"AAPL\", \"date\": \"2000-10-01T00:00:00\", \"price\": 9.78}, {\"symbol\": \"AAPL\", \"date\": \"2000-11-01T00:00:00\", \"price\": 8.25}, {\"symbol\": \"AAPL\", \"date\": \"2000-12-01T00:00:00\", \"price\": 7.44}, {\"symbol\": \"AAPL\", \"date\": \"2001-01-01T00:00:00\", \"price\": 10.81}, {\"symbol\": \"AAPL\", \"date\": \"2001-02-01T00:00:00\", \"price\": 9.12}, {\"symbol\": \"AAPL\", \"date\": \"2001-03-01T00:00:00\", \"price\": 11.03}, {\"symbol\": \"AAPL\", \"date\": \"2001-04-01T00:00:00\", \"price\": 12.74}, {\"symbol\": \"AAPL\", \"date\": \"2001-05-01T00:00:00\", \"price\": 9.98}, {\"symbol\": \"AAPL\", \"date\": \"2001-06-01T00:00:00\", \"price\": 11.62}, {\"symbol\": \"AAPL\", \"date\": \"2001-07-01T00:00:00\", \"price\": 9.4}, {\"symbol\": \"AAPL\", \"date\": \"2001-08-01T00:00:00\", \"price\": 9.27}, {\"symbol\": \"AAPL\", \"date\": \"2001-09-01T00:00:00\", \"price\": 7.76}, {\"symbol\": \"AAPL\", \"date\": \"2001-10-01T00:00:00\", \"price\": 8.78}, {\"symbol\": \"AAPL\", \"date\": \"2001-11-01T00:00:00\", \"price\": 10.65}, {\"symbol\": \"AAPL\", \"date\": \"2001-12-01T00:00:00\", \"price\": 10.95}, {\"symbol\": \"AAPL\", \"date\": \"2002-01-01T00:00:00\", \"price\": 12.36}, {\"symbol\": \"AAPL\", \"date\": \"2002-02-01T00:00:00\", \"price\": 10.85}, {\"symbol\": \"AAPL\", \"date\": \"2002-03-01T00:00:00\", \"price\": 11.84}, {\"symbol\": \"AAPL\", \"date\": \"2002-04-01T00:00:00\", \"price\": 12.14}, {\"symbol\": \"AAPL\", \"date\": \"2002-05-01T00:00:00\", \"price\": 11.65}, {\"symbol\": \"AAPL\", \"date\": \"2002-06-01T00:00:00\", \"price\": 8.86}, {\"symbol\": \"AAPL\", \"date\": \"2002-07-01T00:00:00\", \"price\": 7.63}, {\"symbol\": \"AAPL\", \"date\": \"2002-08-01T00:00:00\", \"price\": 7.38}, {\"symbol\": \"AAPL\", \"date\": \"2002-09-01T00:00:00\", \"price\": 7.25}, {\"symbol\": \"AAPL\", \"date\": \"2002-10-01T00:00:00\", \"price\": 8.03}, {\"symbol\": \"AAPL\", \"date\": \"2002-11-01T00:00:00\", \"price\": 7.75}, {\"symbol\": \"AAPL\", \"date\": \"2002-12-01T00:00:00\", \"price\": 7.16}, {\"symbol\": \"AAPL\", \"date\": \"2003-01-01T00:00:00\", \"price\": 7.18}, {\"symbol\": \"AAPL\", \"date\": \"2003-02-01T00:00:00\", \"price\": 7.51}, {\"symbol\": \"AAPL\", \"date\": \"2003-03-01T00:00:00\", \"price\": 7.07}, {\"symbol\": \"AAPL\", \"date\": \"2003-04-01T00:00:00\", \"price\": 7.11}, {\"symbol\": \"AAPL\", \"date\": \"2003-05-01T00:00:00\", \"price\": 8.98}, {\"symbol\": \"AAPL\", \"date\": \"2003-06-01T00:00:00\", \"price\": 9.53}, {\"symbol\": \"AAPL\", \"date\": \"2003-07-01T00:00:00\", \"price\": 10.54}, {\"symbol\": \"AAPL\", \"date\": \"2003-08-01T00:00:00\", \"price\": 11.31}, {\"symbol\": \"AAPL\", \"date\": \"2003-09-01T00:00:00\", \"price\": 10.36}, {\"symbol\": \"AAPL\", \"date\": \"2003-10-01T00:00:00\", \"price\": 11.44}, {\"symbol\": \"AAPL\", \"date\": \"2003-11-01T00:00:00\", \"price\": 10.45}, {\"symbol\": \"AAPL\", \"date\": \"2003-12-01T00:00:00\", \"price\": 10.69}, {\"symbol\": \"AAPL\", \"date\": \"2004-01-01T00:00:00\", \"price\": 11.28}, {\"symbol\": \"AAPL\", \"date\": \"2004-02-01T00:00:00\", \"price\": 11.96}, {\"symbol\": \"AAPL\", \"date\": \"2004-03-01T00:00:00\", \"price\": 13.52}, {\"symbol\": \"AAPL\", \"date\": \"2004-04-01T00:00:00\", \"price\": 12.89}, {\"symbol\": \"AAPL\", \"date\": \"2004-05-01T00:00:00\", \"price\": 14.03}, {\"symbol\": \"AAPL\", \"date\": \"2004-06-01T00:00:00\", \"price\": 16.27}, {\"symbol\": \"AAPL\", \"date\": \"2004-07-01T00:00:00\", \"price\": 16.17}, {\"symbol\": \"AAPL\", \"date\": \"2004-08-01T00:00:00\", \"price\": 17.25}, {\"symbol\": \"AAPL\", \"date\": \"2004-09-01T00:00:00\", \"price\": 19.38}, {\"symbol\": \"AAPL\", \"date\": \"2004-10-01T00:00:00\", \"price\": 26.2}, {\"symbol\": \"AAPL\", \"date\": \"2004-11-01T00:00:00\", \"price\": 33.53}, {\"symbol\": \"AAPL\", \"date\": \"2004-12-01T00:00:00\", \"price\": 32.2}, {\"symbol\": \"AAPL\", \"date\": \"2005-01-01T00:00:00\", \"price\": 38.45}, {\"symbol\": \"AAPL\", \"date\": \"2005-02-01T00:00:00\", \"price\": 44.86}, {\"symbol\": \"AAPL\", \"date\": \"2005-03-01T00:00:00\", \"price\": 41.67}, {\"symbol\": \"AAPL\", \"date\": \"2005-04-01T00:00:00\", \"price\": 36.06}, {\"symbol\": \"AAPL\", \"date\": \"2005-05-01T00:00:00\", \"price\": 39.76}, {\"symbol\": \"AAPL\", \"date\": \"2005-06-01T00:00:00\", \"price\": 36.81}, {\"symbol\": \"AAPL\", \"date\": \"2005-07-01T00:00:00\", \"price\": 42.65}, {\"symbol\": \"AAPL\", \"date\": \"2005-08-01T00:00:00\", \"price\": 46.89}, {\"symbol\": \"AAPL\", \"date\": \"2005-09-01T00:00:00\", \"price\": 53.61}, {\"symbol\": \"AAPL\", \"date\": \"2005-10-01T00:00:00\", \"price\": 57.59}, {\"symbol\": \"AAPL\", \"date\": \"2005-11-01T00:00:00\", \"price\": 67.82}, {\"symbol\": \"AAPL\", \"date\": \"2005-12-01T00:00:00\", \"price\": 71.89}, {\"symbol\": \"AAPL\", \"date\": \"2006-01-01T00:00:00\", \"price\": 75.51}, {\"symbol\": \"AAPL\", \"date\": \"2006-02-01T00:00:00\", \"price\": 68.49}, {\"symbol\": \"AAPL\", \"date\": \"2006-03-01T00:00:00\", \"price\": 62.72}, {\"symbol\": \"AAPL\", \"date\": \"2006-04-01T00:00:00\", \"price\": 70.39}, {\"symbol\": \"AAPL\", \"date\": \"2006-05-01T00:00:00\", \"price\": 59.77}, {\"symbol\": \"AAPL\", \"date\": \"2006-06-01T00:00:00\", \"price\": 57.27}, {\"symbol\": \"AAPL\", \"date\": \"2006-07-01T00:00:00\", \"price\": 67.96}, {\"symbol\": \"AAPL\", \"date\": \"2006-08-01T00:00:00\", \"price\": 67.85}, {\"symbol\": \"AAPL\", \"date\": \"2006-09-01T00:00:00\", \"price\": 76.98}, {\"symbol\": \"AAPL\", \"date\": \"2006-10-01T00:00:00\", \"price\": 81.08}, {\"symbol\": \"AAPL\", \"date\": \"2006-11-01T00:00:00\", \"price\": 91.66}, {\"symbol\": \"AAPL\", \"date\": \"2006-12-01T00:00:00\", \"price\": 84.84}, {\"symbol\": \"AAPL\", \"date\": \"2007-01-01T00:00:00\", \"price\": 85.73}, {\"symbol\": \"AAPL\", \"date\": \"2007-02-01T00:00:00\", \"price\": 84.61}, {\"symbol\": \"AAPL\", \"date\": \"2007-03-01T00:00:00\", \"price\": 92.91}, {\"symbol\": \"AAPL\", \"date\": \"2007-04-01T00:00:00\", \"price\": 99.8}, {\"symbol\": \"AAPL\", \"date\": \"2007-05-01T00:00:00\", \"price\": 121.19}, {\"symbol\": \"AAPL\", \"date\": \"2007-06-01T00:00:00\", \"price\": 122.04}, {\"symbol\": \"AAPL\", \"date\": \"2007-07-01T00:00:00\", \"price\": 131.76}, {\"symbol\": \"AAPL\", \"date\": \"2007-08-01T00:00:00\", \"price\": 138.48}, {\"symbol\": \"AAPL\", \"date\": \"2007-09-01T00:00:00\", \"price\": 153.47}, {\"symbol\": \"AAPL\", \"date\": \"2007-10-01T00:00:00\", \"price\": 189.95}, {\"symbol\": \"AAPL\", \"date\": \"2007-11-01T00:00:00\", \"price\": 182.22}, {\"symbol\": \"AAPL\", \"date\": \"2007-12-01T00:00:00\", \"price\": 198.08}, {\"symbol\": \"AAPL\", \"date\": \"2008-01-01T00:00:00\", \"price\": 135.36}, {\"symbol\": \"AAPL\", \"date\": \"2008-02-01T00:00:00\", \"price\": 125.02}, {\"symbol\": \"AAPL\", \"date\": \"2008-03-01T00:00:00\", \"price\": 143.5}, {\"symbol\": \"AAPL\", \"date\": \"2008-04-01T00:00:00\", \"price\": 173.95}, {\"symbol\": \"AAPL\", \"date\": \"2008-05-01T00:00:00\", \"price\": 188.75}, {\"symbol\": \"AAPL\", \"date\": \"2008-06-01T00:00:00\", \"price\": 167.44}, {\"symbol\": \"AAPL\", \"date\": \"2008-07-01T00:00:00\", \"price\": 158.95}, {\"symbol\": \"AAPL\", \"date\": \"2008-08-01T00:00:00\", \"price\": 169.53}, {\"symbol\": \"AAPL\", \"date\": \"2008-09-01T00:00:00\", \"price\": 113.66}, {\"symbol\": \"AAPL\", \"date\": \"2008-10-01T00:00:00\", \"price\": 107.59}, {\"symbol\": \"AAPL\", \"date\": \"2008-11-01T00:00:00\", \"price\": 92.67}, {\"symbol\": \"AAPL\", \"date\": \"2008-12-01T00:00:00\", \"price\": 85.35}, {\"symbol\": \"AAPL\", \"date\": \"2009-01-01T00:00:00\", \"price\": 90.13}, {\"symbol\": \"AAPL\", \"date\": \"2009-02-01T00:00:00\", \"price\": 89.31}, {\"symbol\": \"AAPL\", \"date\": \"2009-03-01T00:00:00\", \"price\": 105.12}, {\"symbol\": \"AAPL\", \"date\": \"2009-04-01T00:00:00\", \"price\": 125.83}, {\"symbol\": \"AAPL\", \"date\": \"2009-05-01T00:00:00\", \"price\": 135.81}, {\"symbol\": \"AAPL\", \"date\": \"2009-06-01T00:00:00\", \"price\": 142.43}, {\"symbol\": \"AAPL\", \"date\": \"2009-07-01T00:00:00\", \"price\": 163.39}, {\"symbol\": \"AAPL\", \"date\": \"2009-08-01T00:00:00\", \"price\": 168.21}, {\"symbol\": \"AAPL\", \"date\": \"2009-09-01T00:00:00\", \"price\": 185.35}, {\"symbol\": \"AAPL\", \"date\": \"2009-10-01T00:00:00\", \"price\": 188.5}, {\"symbol\": \"AAPL\", \"date\": \"2009-11-01T00:00:00\", \"price\": 199.91}, {\"symbol\": \"AAPL\", \"date\": \"2009-12-01T00:00:00\", \"price\": 210.73}, {\"symbol\": \"AAPL\", \"date\": \"2010-01-01T00:00:00\", \"price\": 192.06}, {\"symbol\": \"AAPL\", \"date\": \"2010-02-01T00:00:00\", \"price\": 204.62}, {\"symbol\": \"AAPL\", \"date\": \"2010-03-01T00:00:00\", \"price\": 223.02}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "chart = alt.Chart(stocks).encode(color=alt.Color(\"symbol\"))\n",
        "line = chart.mark_line().encode(\n",
        "    x=alt.X(\"date:T\", axis=alt.Axis(title=\"date\")),\n",
        "    y=alt.Y(\"price:Q\", axis=alt.Axis(title=\"price\")),\n",
        "    tooltip=[\"date\", \"price\"],\n",
        ")\n",
        "line"
      ],
      "id": "cell-8"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "## Some simple but sensible design principles\n",
        "\n",
        "Sara’s main points for improving the standard layout of charts basically\n",
        "boil down to the following princples:\n",
        "\n",
        "-   **use informative action titles and subtitles**: much like effective\n",
        "    presentations, using so-called [action\n",
        "    titles](https://slideworks.io/resources/how-to-write-action-titles-like-mckinsey)\n",
        "    will greatly increase the impact of your data visualization.\n",
        "    Formulated as a short, simple sentence, action titles should ideally\n",
        "    be the main takeaway or ‘so what’ of the chart, and – if done right\n",
        "    – allows the audience to only read the title to understand the\n",
        "    primary message of the visual.\n",
        "-   **less is more**: before minimalism became all the rage in design,\n",
        "    Edward Tufte coined the principle of [maximizing the data-to-ink\n",
        "    ratio](https://infovis-wiki.net/wiki/Data-Ink_Ratio). Charts are\n",
        "    easier to read by removing unnecessary clutter. So get rid of\n",
        "    gridlines, background colors and the like.\n",
        "-   **keep it horizontal**: text is easier to read when it is\n",
        "    horizontally aligned. So straighten up those rotated x-axis labels\n",
        "    and y-axis titles\n",
        "-   **lose the legends**: having to lookup colors increases the\n",
        "    cognitive load of reading a chart. Use annotations instead.\n",
        "\n",
        "All these principles can be readily implemented in Altair. Sergio\n",
        "Sánchez in fact captured the first three principles when implementing\n",
        "the Urban Institute styleguide (shown below) as [an Altair\n",
        "theme](https://towardsdatascience.com/consistently-beautiful-visualizations-with-altair-themes-c7f9f889602).\n",
        "\n",
        "![](attachment:images/urban-institute-styleguide.webp)\n",
        "\n",
        "Building on his work, we created our on theme called **Okabe Ito**, in\n",
        "honour of their work in defining [colorblind-safe color\n",
        "palettes](https://thenode.biologists.com/data-visualization-with-flying-colors/research/).\n",
        "Not only is it functional, but I really like the muted colors, too.\n",
        "Below is a visual from their [original\n",
        "paper](https://jfly.uni-koeln.de/color/) that also shows how different\n",
        "types of colorblindness (protan, deutan, tritan) results in different\n",
        "perception of the colors.\n",
        "\n",
        "![](attachment:images/otabe-ito-pallete.jpg)\n",
        "\n",
        "To use this template, download\n",
        "[okabe-ito-theme.py](../resources/okabe-ito-theme.py), put it in the\n",
        "same folder as your notebook and at the following two cells.\n",
        "\n",
        "To register the template as an Altair theme:"
      ],
      "attachments": {
        "images/otabe-ito-pallete.jpg": {
          "image/jpeg": "/9j/4AAQSkZJRgABAgEAzQDNAAD/4QEuRXhpZgAATU0AKgAAAAgABwESAAMAAAABAAEAAAEaAAUA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\nsVdirsVdirsVdirsVdirsVdirsVdirsVdir/AP/Z\n"
        },
        "images/urban-institute-styleguide.webp": {
          "image/webp": "UklGRsinAQBXRUJQVlA4WAoAAAAIAAAAdwUAuwMAVlA4IOimAQDQqwSdASp4BbwDPm02lkikIyUh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\nAAEAAAB4BQAAA6AEAAEAAAC8AwAAAAAAAA==\n"
        }
      },
      "id": "df26369e-77e3-4e2b-89c9-6cd0d525690e"
    },
    {
      "cell_type": "code",
      "execution_count": 5,
      "metadata": {},
      "outputs": [],
      "source": [
        "%run ../resources/okabe-ito-theme.py"
      ],
      "id": "cell-11"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "To download the fonts used in the template:"
      ],
      "id": "5f350642-28ec-47c6-bafa-852ed6478e72"
    },
    {
      "cell_type": "code",
      "execution_count": 6,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "<style>\n",
              "@import url('https://fonts.googleapis.com/css?family=Lato');\n",
              "</style>"
            ]
          }
        }
      ],
      "source": [
        "%%html\n",
        "<style>\n",
        "@import url('https://fonts.googleapis.com/css?family=Lato');\n",
        "</style>"
      ],
      "id": "cell-13"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "Let’s see how this changes the charts.\n",
        "\n",
        "### Adding titles\n",
        "\n",
        "The theme automatically has been configured to improve the data-to-ink\n",
        "ratio and align all texts horizontally. Adding action titles can be done\n",
        "using\n",
        "[`alt.TitleParams`](https://altair-viz.github.io/user_guide/customization.html#adjusting-the-title),\n",
        "with which you can not only add a title, but also add multiple subtitles\n",
        "lines which you pass as a list."
      ],
      "id": "a022ea27-341f-401b-9f96-0e3c4864d5ed"
    },
    {
      "cell_type": "code",
      "execution_count": 7,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-0502798926cc46dfa849d27592dc85ae.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-0502798926cc46dfa849d27592dc85ae.vega-embed details,\n",
              "  #altair-viz-0502798926cc46dfa849d27592dc85ae.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-0502798926cc46dfa849d27592dc85ae\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-0502798926cc46dfa849d27592dc85ae\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-0502798926cc46dfa849d27592dc85ae\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"width\": 685, \"height\": 380, \"config\": {\"title\": {\"anchor\": \"start\", \"dy\": -15, \"fontSize\": 18, \"font\": \"Lato\", \"fontColor\": \"#000000\"}, \"axisX\": {\"domain\": true, \"domainColor\": \"#000000\", \"domainWidth\": 1, \"grid\": false, \"labelFontSize\": 12, \"labelFont\": \"Lato\", \"labelAngle\": 0, \"labelOverlap\": \"parity\", \"tickColor\": \"#000000\", \"tickSize\": 5, \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\"}, \"axisY\": {\"domain\": false, \"grid\": true, \"gridColor\": \"#DEDDDD\", \"gridWidth\": 1, \"labelFontSize\": 12, \"labelFont\": \"Lato\", \"labelPadding\": 8, \"ticks\": false, \"titleAlign\": \"left\", \"titleAnchor\": \"start\", \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\", \"titleAngle\": 0, \"titleY\": -15}, \"background\": \"#FFFFFF\", \"legend\": {\"labelFontSize\": 12, \"labelFont\": \"Lato\", \"symbolSize\": 100, \"symbolType\": \"square\", \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\", \"title\": \"\", \"orient\": \"top-left\", \"offset\": 0}, \"view\": {\"stroke\": \"transparent\"}, \"range\": {\"category\": [\"#E69F00\", \"#56B4E9\", \"#009E73\", \"#F0E442\", \"#0072B2\", \"#D55E00\", \"#CC79A7\", \"#000000\"], \"diverging\": [\"#cfe8f3\", \"#a2d4ec\", \"#73bfe2\", \"#46abdb\", \"#1696d2\", \"#12719e\"]}, \"area\": {\"fill\": \"#0072B2\"}, \"line\": {\"color\": \"#0072B2\", \"stroke\": \"#0072B2\", \"strokewidth\": 5}, \"trail\": {\"color\": \"#0072B2\", \"stroke\": \"#0072B2\", \"strokeWidth\": 0, \"size\": 1}, \"path\": {\"stroke\": \"#0072B2\", \"strokeWidth\": 0.5}, \"point\": {\"filled\": true}, \"text\": {\"font\": \"Lato\", \"color\": \"#0072B2\", \"fontSize\": 11, \"align\": \"right\", \"fontWeight\": 400, \"size\": 11}, \"bar\": {\"fill\": \"#0072B2\", \"stroke\": false}}, \"data\": {\"name\": \"data-b414165be0aeea8c687bc9462659f7b8\"}, \"mark\": {\"type\": \"circle\", \"size\": 60}, \"encoding\": {\"color\": {\"field\": \"species\", \"type\": \"nominal\"}, \"tooltip\": [{\"field\": \"species\", \"type\": \"nominal\"}, {\"field\": \"sex\", \"type\": \"nominal\"}, {\"field\": \"island\", \"type\": \"nominal\"}, {\"field\": \"bill_length_mm\", \"type\": \"quantitative\"}, {\"field\": \"bill_depth_mm\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"bill_length_mm\", \"scale\": {\"zero\": false}, \"type\": \"quantitative\"}, \"y\": {\"field\": \"bill_depth_mm\", \"scale\": {\"zero\": false}, \"type\": \"quantitative\"}}, \"title\": {\"text\": \"Bill length vs. bill depth\", \"subtitle\": [\"Did you spot Simpson's Paradox?\"]}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-b414165be0aeea8c687bc9462659f7b8\": [{\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.1, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 181, \"body_mass_g\": 3750, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.5, \"bill_depth_mm\": 17.4, \"flipper_length_mm\": 186, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 40.3, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 195, \"body_mass_g\": 3250, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": null, \"bill_depth_mm\": null, \"flipper_length_mm\": null, \"body_mass_g\": null, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.7, \"bill_depth_mm\": 19.3, \"flipper_length_mm\": 193, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.3, \"bill_depth_mm\": 20.6, \"flipper_length_mm\": 190, \"body_mass_g\": 3650, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.9, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 181, \"body_mass_g\": 3625, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.2, \"bill_depth_mm\": 19.6, \"flipper_length_mm\": 195, \"body_mass_g\": 4675, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 34.1, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 193, \"body_mass_g\": 3475, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.0, \"bill_depth_mm\": 20.2, \"flipper_length_mm\": 190, \"body_mass_g\": 4250, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 186, \"body_mass_g\": 3300, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 180, \"body_mass_g\": 3700, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 17.6, \"flipper_length_mm\": 182, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.6, \"bill_depth_mm\": 21.2, \"flipper_length_mm\": 191, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 34.6, \"bill_depth_mm\": 21.1, \"flipper_length_mm\": 198, \"body_mass_g\": 4400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.6, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 185, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.7, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 195, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.5, \"bill_depth_mm\": 20.7, \"flipper_length_mm\": 197, \"body_mass_g\": 4500, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 34.4, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 184, \"body_mass_g\": 3325, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 46.0, \"bill_depth_mm\": 21.5, \"flipper_length_mm\": 194, \"body_mass_g\": 4200, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 18.3, \"flipper_length_mm\": 174, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.7, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 180, \"body_mass_g\": 3600, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.9, \"bill_depth_mm\": 19.2, \"flipper_length_mm\": 189, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.2, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 185, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.8, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 180, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.3, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 187, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.6, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 183, \"body_mass_g\": 3550, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.5, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 187, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.9, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 172, \"body_mass_g\": 3150, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.5, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 180, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.5, \"bill_depth_mm\": 16.7, \"flipper_length_mm\": 178, \"body_mass_g\": 3250, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.2, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 178, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.5, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 188, \"body_mass_g\": 3300, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.9, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 184, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.4, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 195, \"body_mass_g\": 3325, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.2, \"bill_depth_mm\": 21.1, \"flipper_length_mm\": 196, \"body_mass_g\": 4150, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.8, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 190, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 42.2, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 180, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.6, \"bill_depth_mm\": 19.3, \"flipper_length_mm\": 181, \"body_mass_g\": 3300, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.8, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 184, \"body_mass_g\": 4650, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.5, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 182, \"body_mass_g\": 3150, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.8, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 195, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.0, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 186, \"body_mass_g\": 3100, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 44.1, \"bill_depth_mm\": 19.7, \"flipper_length_mm\": 196, \"body_mass_g\": 4400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.0, \"bill_depth_mm\": 16.9, \"flipper_length_mm\": 185, \"body_mass_g\": 3000, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 190, \"body_mass_g\": 4600, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 182, \"body_mass_g\": 3425, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.5, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 179, \"body_mass_g\": 2975, \"sex\": null, \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.0, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 190, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 42.3, \"bill_depth_mm\": 21.2, \"flipper_length_mm\": 191, \"body_mass_g\": 4150, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 17.7, \"flipper_length_mm\": 186, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.1, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 188, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.0, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 190, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.0, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 200, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 34.5, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 187, \"body_mass_g\": 2900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.4, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 191, \"body_mass_g\": 3700, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.0, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 186, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.6, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 193, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 36.5, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 181, \"body_mass_g\": 2850, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.6, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 194, \"body_mass_g\": 3750, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.7, \"bill_depth_mm\": 16.9, \"flipper_length_mm\": 185, \"body_mass_g\": 3150, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.3, \"bill_depth_mm\": 21.1, \"flipper_length_mm\": 195, \"body_mass_g\": 4400, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.6, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 185, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 192, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 36.4, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 184, \"body_mass_g\": 2850, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.6, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 192, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.5, \"bill_depth_mm\": 16.2, \"flipper_length_mm\": 195, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 188, \"body_mass_g\": 4100, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.9, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 190, \"body_mass_g\": 3050, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.8, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 198, \"body_mass_g\": 4450, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 33.5, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 190, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.7, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 190, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 196, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 45.8, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 197, \"body_mass_g\": 4150, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.5, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 190, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.8, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 195, \"body_mass_g\": 4250, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 40.9, \"bill_depth_mm\": 16.8, \"flipper_length_mm\": 191, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.2, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 184, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.2, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 187, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.1, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 195, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 34.6, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 189, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 42.9, \"bill_depth_mm\": 17.6, \"flipper_length_mm\": 196, \"body_mass_g\": 4700, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.7, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 187, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.1, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 193, \"body_mass_g\": 4200, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.3, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 191, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.3, \"bill_depth_mm\": 20.3, \"flipper_length_mm\": 194, \"body_mass_g\": 3550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.3, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 190, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.9, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 189, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.3, \"bill_depth_mm\": 19.2, \"flipper_length_mm\": 189, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.9, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 190, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 35.7, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 202, \"body_mass_g\": 3550, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 205, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 34.0, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 185, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 186, \"body_mass_g\": 4450, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.2, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 187, \"body_mass_g\": 3300, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.8, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 208, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.1, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 190, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.3, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 196, \"body_mass_g\": 4350, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 33.1, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 178, \"body_mass_g\": 2900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 43.2, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 192, \"body_mass_g\": 4100, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 35.0, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 192, \"body_mass_g\": 3725, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.0, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 203, \"body_mass_g\": 4725, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.7, \"bill_depth_mm\": 16.0, \"flipper_length_mm\": 183, \"body_mass_g\": 3075, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 190, \"body_mass_g\": 4250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 37.9, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 193, \"body_mass_g\": 2925, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.7, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 184, \"body_mass_g\": 3550, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.6, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 199, \"body_mass_g\": 3750, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.2, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 190, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.1, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 181, \"body_mass_g\": 3175, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.2, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 197, \"body_mass_g\": 4775, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 38.1, \"bill_depth_mm\": 16.5, \"flipper_length_mm\": 198, \"body_mass_g\": 3825, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.6, \"bill_depth_mm\": 20.3, \"flipper_length_mm\": 191, \"body_mass_g\": 4600, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.7, \"bill_depth_mm\": 17.7, \"flipper_length_mm\": 193, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.2, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 197, \"body_mass_g\": 4275, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 39.6, \"bill_depth_mm\": 20.7, \"flipper_length_mm\": 191, \"body_mass_g\": 3900, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.7, \"bill_depth_mm\": 18.3, \"flipper_length_mm\": 196, \"body_mass_g\": 4075, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.6, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 188, \"body_mass_g\": 2900, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.3, \"bill_depth_mm\": 20.5, \"flipper_length_mm\": 199, \"body_mass_g\": 3775, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.7, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 189, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 189, \"body_mass_g\": 3325, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 36.2, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 187, \"body_mass_g\": 3150, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 37.7, \"bill_depth_mm\": 19.8, \"flipper_length_mm\": 198, \"body_mass_g\": 3500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 40.2, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 176, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.4, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 202, \"body_mass_g\": 3875, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 35.2, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 186, \"body_mass_g\": 3050, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 40.6, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 199, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.8, \"bill_depth_mm\": 17.6, \"flipper_length_mm\": 191, \"body_mass_g\": 3275, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 41.5, \"bill_depth_mm\": 18.3, \"flipper_length_mm\": 195, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 39.0, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 191, \"body_mass_g\": 3050, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 44.1, \"bill_depth_mm\": 18.0, \"flipper_length_mm\": 210, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 38.5, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 190, \"body_mass_g\": 3325, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Torgersen\", \"bill_length_mm\": 43.1, \"bill_depth_mm\": 19.2, \"flipper_length_mm\": 197, \"body_mass_g\": 3500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.8, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 193, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.5, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 199, \"body_mass_g\": 4475, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 38.1, \"bill_depth_mm\": 17.6, \"flipper_length_mm\": 187, \"body_mass_g\": 3425, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.1, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 190, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 35.6, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 191, \"body_mass_g\": 3175, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.2, \"bill_depth_mm\": 20.1, \"flipper_length_mm\": 200, \"body_mass_g\": 3975, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.0, \"bill_depth_mm\": 16.5, \"flipper_length_mm\": 185, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.7, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 193, \"body_mass_g\": 4250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.2, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 193, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.6, \"bill_depth_mm\": 17.2, \"flipper_length_mm\": 187, \"body_mass_g\": 3475, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 32.1, \"bill_depth_mm\": 15.5, \"flipper_length_mm\": 188, \"body_mass_g\": 3050, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 40.7, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 190, \"body_mass_g\": 3725, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.3, \"bill_depth_mm\": 16.8, \"flipper_length_mm\": 192, \"body_mass_g\": 3000, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.0, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 185, \"body_mass_g\": 3650, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 39.2, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 190, \"body_mass_g\": 4250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.6, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 184, \"body_mass_g\": 3475, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.0, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 195, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 37.8, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 193, \"body_mass_g\": 3750, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 36.0, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 187, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Adelie\", \"island\": \"Dream\", \"bill_length_mm\": 41.5, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 201, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.1, \"bill_depth_mm\": 13.2, \"flipper_length_mm\": 211, \"body_mass_g\": 4500, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 16.3, \"flipper_length_mm\": 230, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.7, \"bill_depth_mm\": 14.1, \"flipper_length_mm\": 210, \"body_mass_g\": 4450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 15.2, \"flipper_length_mm\": 218, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.6, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 215, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 13.5, \"flipper_length_mm\": 210, \"body_mass_g\": 4550, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.4, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 211, \"body_mass_g\": 4800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.7, \"bill_depth_mm\": 15.3, \"flipper_length_mm\": 219, \"body_mass_g\": 5200, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.3, \"bill_depth_mm\": 13.4, \"flipper_length_mm\": 209, \"body_mass_g\": 4400, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.8, \"bill_depth_mm\": 15.4, \"flipper_length_mm\": 215, \"body_mass_g\": 5150, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 40.9, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 214, \"body_mass_g\": 4650, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.0, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 216, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 214, \"body_mass_g\": 4650, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.4, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 213, \"body_mass_g\": 5850, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.8, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 210, \"body_mass_g\": 4200, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.3, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 217, \"body_mass_g\": 5850, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.0, \"bill_depth_mm\": 13.5, \"flipper_length_mm\": 210, \"body_mass_g\": 4150, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.2, \"bill_depth_mm\": 15.2, \"flipper_length_mm\": 221, \"body_mass_g\": 6300, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 209, \"body_mass_g\": 4800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.7, \"bill_depth_mm\": 15.1, \"flipper_length_mm\": 222, \"body_mass_g\": 5350, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.2, \"bill_depth_mm\": 14.3, \"flipper_length_mm\": 218, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.1, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 215, \"body_mass_g\": 5000, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 213, \"body_mass_g\": 4400, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.3, \"bill_depth_mm\": 15.8, \"flipper_length_mm\": 215, \"body_mass_g\": 5050, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.9, \"bill_depth_mm\": 13.1, \"flipper_length_mm\": 215, \"body_mass_g\": 5000, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.1, \"bill_depth_mm\": 15.1, \"flipper_length_mm\": 215, \"body_mass_g\": 5100, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.5, \"bill_depth_mm\": 14.3, \"flipper_length_mm\": 216, \"body_mass_g\": 4100, \"sex\": null, \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.8, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 215, \"body_mass_g\": 5650, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.2, \"bill_depth_mm\": 14.3, \"flipper_length_mm\": 210, \"body_mass_g\": 4600, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 15.3, \"flipper_length_mm\": 220, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.3, \"bill_depth_mm\": 15.3, \"flipper_length_mm\": 222, \"body_mass_g\": 5250, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.8, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 209, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.1, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 207, \"body_mass_g\": 5050, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 59.6, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 230, \"body_mass_g\": 6050, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.1, \"bill_depth_mm\": 14.8, \"flipper_length_mm\": 220, \"body_mass_g\": 5150, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.4, \"bill_depth_mm\": 16.3, \"flipper_length_mm\": 220, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.6, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 213, \"body_mass_g\": 4950, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.4, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 219, \"body_mass_g\": 5250, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.0, \"bill_depth_mm\": 13.6, \"flipper_length_mm\": 208, \"body_mass_g\": 4350, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.7, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 208, \"body_mass_g\": 5350, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 42.7, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 208, \"body_mass_g\": 3950, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.6, \"bill_depth_mm\": 16.0, \"flipper_length_mm\": 225, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.3, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 210, \"body_mass_g\": 4300, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.6, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 216, \"body_mass_g\": 4750, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 222, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.6, \"bill_depth_mm\": 13.9, \"flipper_length_mm\": 217, \"body_mass_g\": 4900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 13.9, \"flipper_length_mm\": 210, \"body_mass_g\": 4200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 225, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.9, \"bill_depth_mm\": 13.3, \"flipper_length_mm\": 213, \"body_mass_g\": 5100, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 15.8, \"flipper_length_mm\": 215, \"body_mass_g\": 5300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.6, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 210, \"body_mass_g\": 4850, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.5, \"bill_depth_mm\": 14.1, \"flipper_length_mm\": 220, \"body_mass_g\": 5300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.1, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 210, \"body_mass_g\": 4400, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.1, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 225, \"body_mass_g\": 5000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 217, \"body_mass_g\": 4900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.0, \"bill_depth_mm\": 15.4, \"flipper_length_mm\": 220, \"body_mass_g\": 5050, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.8, \"bill_depth_mm\": 13.9, \"flipper_length_mm\": 208, \"body_mass_g\": 4300, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 220, \"body_mass_g\": 5000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.2, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 208, \"body_mass_g\": 4450, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.4, \"bill_depth_mm\": 15.3, \"flipper_length_mm\": 224, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.3, \"bill_depth_mm\": 13.8, \"flipper_length_mm\": 208, \"body_mass_g\": 4200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 14.9, \"flipper_length_mm\": 221, \"body_mass_g\": 5300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.7, \"bill_depth_mm\": 13.9, \"flipper_length_mm\": 214, \"body_mass_g\": 4400, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 54.3, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 231, \"body_mass_g\": 5650, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.8, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 219, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.8, \"bill_depth_mm\": 16.8, \"flipper_length_mm\": 230, \"body_mass_g\": 5700, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 214, \"body_mass_g\": 4650, \"sex\": null, \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.5, \"bill_depth_mm\": 16.2, \"flipper_length_mm\": 229, \"body_mass_g\": 5800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.5, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 220, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.7, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 223, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.7, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 216, \"body_mass_g\": 4750, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.4, \"bill_depth_mm\": 15.6, \"flipper_length_mm\": 221, \"body_mass_g\": 5000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.2, \"bill_depth_mm\": 15.6, \"flipper_length_mm\": 221, \"body_mass_g\": 5100, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 14.8, \"flipper_length_mm\": 217, \"body_mass_g\": 5200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.4, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 216, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.6, \"bill_depth_mm\": 16.0, \"flipper_length_mm\": 230, \"body_mass_g\": 5800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.5, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 209, \"body_mass_g\": 4600, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 51.1, \"bill_depth_mm\": 16.3, \"flipper_length_mm\": 220, \"body_mass_g\": 6000, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 13.8, \"flipper_length_mm\": 215, \"body_mass_g\": 4750, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 16.4, \"flipper_length_mm\": 223, \"body_mass_g\": 5950, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.1, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 212, \"body_mass_g\": 4625, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 52.5, \"bill_depth_mm\": 15.6, \"flipper_length_mm\": 221, \"body_mass_g\": 5450, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.4, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 212, \"body_mass_g\": 4725, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 224, \"body_mass_g\": 5350, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.9, \"bill_depth_mm\": 13.8, \"flipper_length_mm\": 212, \"body_mass_g\": 4750, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.8, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 228, \"body_mass_g\": 5600, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.4, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 218, \"body_mass_g\": 4600, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 51.3, \"bill_depth_mm\": 14.2, \"flipper_length_mm\": 218, \"body_mass_g\": 5300, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.5, \"bill_depth_mm\": 14.0, \"flipper_length_mm\": 212, \"body_mass_g\": 4875, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 52.1, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 230, \"body_mass_g\": 5550, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.5, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 218, \"body_mass_g\": 4950, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 52.2, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 228, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 14.5, \"flipper_length_mm\": 212, \"body_mass_g\": 4750, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.5, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 224, \"body_mass_g\": 5650, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.5, \"bill_depth_mm\": 14.7, \"flipper_length_mm\": 214, \"body_mass_g\": 4850, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.8, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 226, \"body_mass_g\": 5200, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.4, \"bill_depth_mm\": 15.8, \"flipper_length_mm\": 216, \"body_mass_g\": 4925, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.9, \"bill_depth_mm\": 14.6, \"flipper_length_mm\": 222, \"body_mass_g\": 4875, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.4, \"bill_depth_mm\": 14.4, \"flipper_length_mm\": 203, \"body_mass_g\": 4625, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 51.1, \"bill_depth_mm\": 16.5, \"flipper_length_mm\": 225, \"body_mass_g\": 5250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.5, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 219, \"body_mass_g\": 4850, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 55.9, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 228, \"body_mass_g\": 5600, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.2, \"bill_depth_mm\": 15.5, \"flipper_length_mm\": 215, \"body_mass_g\": 4975, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.1, \"bill_depth_mm\": 15.0, \"flipper_length_mm\": 228, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.3, \"bill_depth_mm\": 13.8, \"flipper_length_mm\": 216, \"body_mass_g\": 4725, \"sex\": null, \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.8, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 215, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 41.7, \"bill_depth_mm\": 14.7, \"flipper_length_mm\": 210, \"body_mass_g\": 4700, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 53.4, \"bill_depth_mm\": 15.8, \"flipper_length_mm\": 219, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.3, \"bill_depth_mm\": 14.0, \"flipper_length_mm\": 208, \"body_mass_g\": 4575, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.1, \"bill_depth_mm\": 15.1, \"flipper_length_mm\": 209, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 15.2, \"flipper_length_mm\": 216, \"body_mass_g\": 5000, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.8, \"bill_depth_mm\": 15.9, \"flipper_length_mm\": 229, \"body_mass_g\": 5950, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 43.5, \"bill_depth_mm\": 15.2, \"flipper_length_mm\": 213, \"body_mass_g\": 4650, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 51.5, \"bill_depth_mm\": 16.3, \"flipper_length_mm\": 230, \"body_mass_g\": 5500, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 14.1, \"flipper_length_mm\": 217, \"body_mass_g\": 4375, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 55.1, \"bill_depth_mm\": 16.0, \"flipper_length_mm\": 230, \"body_mass_g\": 5850, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 44.5, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 217, \"body_mass_g\": 4875, \"sex\": null, \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 48.8, \"bill_depth_mm\": 16.2, \"flipper_length_mm\": 222, \"body_mass_g\": 6000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 47.2, \"bill_depth_mm\": 13.7, \"flipper_length_mm\": 214, \"body_mass_g\": 4925, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": null, \"bill_depth_mm\": null, \"flipper_length_mm\": null, \"body_mass_g\": null, \"sex\": null, \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 46.8, \"bill_depth_mm\": 14.3, \"flipper_length_mm\": 215, \"body_mass_g\": 4850, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 50.4, \"bill_depth_mm\": 15.7, \"flipper_length_mm\": 222, \"body_mass_g\": 5750, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 14.8, \"flipper_length_mm\": 212, \"body_mass_g\": 5200, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Gentoo\", \"island\": \"Biscoe\", \"bill_length_mm\": 49.9, \"bill_depth_mm\": 16.1, \"flipper_length_mm\": 213, \"body_mass_g\": 5400, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.5, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 192, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.0, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 196, \"body_mass_g\": 3900, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.3, \"bill_depth_mm\": 19.2, \"flipper_length_mm\": 193, \"body_mass_g\": 3650, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.4, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 188, \"body_mass_g\": 3525, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.7, \"bill_depth_mm\": 19.8, \"flipper_length_mm\": 197, \"body_mass_g\": 3725, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 198, \"body_mass_g\": 3950, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.1, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 178, \"body_mass_g\": 3250, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.3, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 197, \"body_mass_g\": 3750, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.0, \"bill_depth_mm\": 18.9, \"flipper_length_mm\": 195, \"body_mass_g\": 4150, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.3, \"bill_depth_mm\": 19.9, \"flipper_length_mm\": 198, \"body_mass_g\": 3700, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.6, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 193, \"body_mass_g\": 3800, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.7, \"bill_depth_mm\": 20.3, \"flipper_length_mm\": 194, \"body_mass_g\": 3775, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 47.0, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 185, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.0, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 201, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.9, \"bill_depth_mm\": 17.1, \"flipper_length_mm\": 190, \"body_mass_g\": 3575, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 19.6, \"flipper_length_mm\": 201, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.3, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 197, \"body_mass_g\": 3300, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 58.0, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 181, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.4, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 190, \"body_mass_g\": 3450, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.2, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 195, \"body_mass_g\": 4400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 42.4, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 181, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 48.5, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 191, \"body_mass_g\": 3400, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 43.2, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 187, \"body_mass_g\": 2900, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.6, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 193, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.7, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 195, \"body_mass_g\": 3300, \"sex\": \"female\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.0, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 197, \"body_mass_g\": 4150, \"sex\": \"male\", \"year\": 2007}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.5, \"bill_depth_mm\": 18.4, \"flipper_length_mm\": 200, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.5, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 200, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.4, \"bill_depth_mm\": 17.8, \"flipper_length_mm\": 191, \"body_mass_g\": 3700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.8, \"bill_depth_mm\": 20.0, \"flipper_length_mm\": 205, \"body_mass_g\": 4550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 40.9, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 187, \"body_mass_g\": 3200, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 54.2, \"bill_depth_mm\": 20.8, \"flipper_length_mm\": 201, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 42.5, \"bill_depth_mm\": 16.7, \"flipper_length_mm\": 187, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.0, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 203, \"body_mass_g\": 4100, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.7, \"bill_depth_mm\": 18.6, \"flipper_length_mm\": 195, \"body_mass_g\": 3600, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 47.5, \"bill_depth_mm\": 16.8, \"flipper_length_mm\": 199, \"body_mass_g\": 3900, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 47.6, \"bill_depth_mm\": 18.3, \"flipper_length_mm\": 195, \"body_mass_g\": 3850, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.0, \"bill_depth_mm\": 20.7, \"flipper_length_mm\": 210, \"body_mass_g\": 4800, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.9, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 192, \"body_mass_g\": 2700, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 53.5, \"bill_depth_mm\": 19.9, \"flipper_length_mm\": 205, \"body_mass_g\": 4500, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.0, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 210, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.2, \"bill_depth_mm\": 17.5, \"flipper_length_mm\": 187, \"body_mass_g\": 3650, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.9, \"bill_depth_mm\": 19.1, \"flipper_length_mm\": 196, \"body_mass_g\": 3550, \"sex\": \"male\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.5, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 196, \"body_mass_g\": 3500, \"sex\": \"female\", \"year\": 2008}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.9, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 196, \"body_mass_g\": 3675, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.8, \"bill_depth_mm\": 18.5, \"flipper_length_mm\": 201, \"body_mass_g\": 4450, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.1, \"bill_depth_mm\": 17.9, \"flipper_length_mm\": 190, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.0, \"bill_depth_mm\": 19.6, \"flipper_length_mm\": 212, \"body_mass_g\": 4300, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.5, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 187, \"body_mass_g\": 3250, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.8, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 198, \"body_mass_g\": 3675, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 48.1, \"bill_depth_mm\": 16.4, \"flipper_length_mm\": 199, \"body_mass_g\": 3325, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.4, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 201, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.7, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 193, \"body_mass_g\": 3600, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.7, \"bill_depth_mm\": 19.7, \"flipper_length_mm\": 203, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 42.5, \"bill_depth_mm\": 17.3, \"flipper_length_mm\": 187, \"body_mass_g\": 3350, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 52.2, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 197, \"body_mass_g\": 3450, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.2, \"bill_depth_mm\": 16.6, \"flipper_length_mm\": 191, \"body_mass_g\": 3250, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.3, \"bill_depth_mm\": 19.9, \"flipper_length_mm\": 203, \"body_mass_g\": 4050, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.2, \"bill_depth_mm\": 18.8, \"flipper_length_mm\": 202, \"body_mass_g\": 3800, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.6, \"bill_depth_mm\": 19.4, \"flipper_length_mm\": 194, \"body_mass_g\": 3525, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 51.9, \"bill_depth_mm\": 19.5, \"flipper_length_mm\": 206, \"body_mass_g\": 3950, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 46.8, \"bill_depth_mm\": 16.5, \"flipper_length_mm\": 189, \"body_mass_g\": 3650, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 45.7, \"bill_depth_mm\": 17.0, \"flipper_length_mm\": 195, \"body_mass_g\": 3650, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 55.8, \"bill_depth_mm\": 19.8, \"flipper_length_mm\": 207, \"body_mass_g\": 4000, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 43.5, \"bill_depth_mm\": 18.1, \"flipper_length_mm\": 202, \"body_mass_g\": 3400, \"sex\": \"female\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 49.6, \"bill_depth_mm\": 18.2, \"flipper_length_mm\": 193, \"body_mass_g\": 3775, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.8, \"bill_depth_mm\": 19.0, \"flipper_length_mm\": 210, \"body_mass_g\": 4100, \"sex\": \"male\", \"year\": 2009}, {\"species\": \"Chinstrap\", \"island\": \"Dream\", \"bill_length_mm\": 50.2, \"bill_depth_mm\": 18.7, \"flipper_length_mm\": 198, \"body_mass_g\": 3775, \"sex\": \"female\", \"year\": 2009}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "(\n",
        "    scatterplot.properties(\n",
        "        title=alt.TitleParams(\n",
        "            \"Bill length vs. bill depth\", subtitle=[\"Did you spot Simpson's Paradox?\"]\n",
        "        )\n",
        "    )\n",
        ")"
      ],
      "id": "cell-15"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### Everything horizontal\n",
        "\n",
        "The effect of aligning all text horizontally is a significant\n",
        "improvement on the bar chart, which is now much easier to read. Adding a\n",
        "two-line subtitle make the action title even more compelling. Using\n",
        "`alt.mark_text()` we can easily add footnotes as well, in this case to\n",
        "provide references to the claim."
      ],
      "id": "6201cc6d-bedd-489d-9a4f-f5577124abd7"
    },
    {
      "cell_type": "code",
      "execution_count": 8,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-9930d27af9d344439297ed30d8f25b75.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-9930d27af9d344439297ed30d8f25b75.vega-embed details,\n",
              "  #altair-viz-9930d27af9d344439297ed30d8f25b75.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-9930d27af9d344439297ed30d8f25b75\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-9930d27af9d344439297ed30d8f25b75\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-9930d27af9d344439297ed30d8f25b75\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"width\": 685, \"height\": 380, \"config\": {\"title\": {\"anchor\": \"start\", \"dy\": -15, \"fontSize\": 18, \"font\": \"Lato\", \"fontColor\": \"#000000\"}, \"axisX\": {\"domain\": true, \"domainColor\": \"#000000\", \"domainWidth\": 1, \"grid\": false, \"labelFontSize\": 12, \"labelFont\": \"Lato\", \"labelAngle\": 0, \"labelOverlap\": \"parity\", \"tickColor\": \"#000000\", \"tickSize\": 5, \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\"}, \"axisY\": {\"domain\": false, \"grid\": true, \"gridColor\": \"#DEDDDD\", \"gridWidth\": 1, \"labelFontSize\": 12, \"labelFont\": \"Lato\", \"labelPadding\": 8, \"ticks\": false, \"titleAlign\": \"left\", \"titleAnchor\": \"start\", \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\", \"titleAngle\": 0, \"titleY\": -15}, \"background\": \"#FFFFFF\", \"legend\": {\"labelFontSize\": 12, \"labelFont\": \"Lato\", \"symbolSize\": 100, \"symbolType\": \"square\", \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\", \"title\": \"\", \"orient\": \"top-left\", \"offset\": 0}, \"view\": {\"stroke\": \"transparent\"}, \"range\": {\"category\": [\"#E69F00\", \"#56B4E9\", \"#009E73\", \"#F0E442\", \"#0072B2\", \"#D55E00\", \"#CC79A7\", \"#000000\"], \"diverging\": [\"#cfe8f3\", \"#a2d4ec\", \"#73bfe2\", \"#46abdb\", \"#1696d2\", \"#12719e\"]}, \"area\": {\"fill\": \"#0072B2\"}, \"line\": {\"color\": \"#0072B2\", \"stroke\": \"#0072B2\", \"strokewidth\": 5}, \"trail\": {\"color\": \"#0072B2\", \"stroke\": \"#0072B2\", \"strokeWidth\": 0, \"size\": 1}, \"path\": {\"stroke\": \"#0072B2\", \"strokeWidth\": 0.5}, \"point\": {\"filled\": true}, \"text\": {\"font\": \"Lato\", \"color\": \"#0072B2\", \"fontSize\": 11, \"align\": \"right\", \"fontWeight\": 400, \"size\": 11}, \"bar\": {\"fill\": \"#0072B2\", \"stroke\": false}}, \"layer\": [{\"mark\": {\"type\": \"bar\"}, \"encoding\": {\"tooltip\": [{\"field\": \"year\", \"type\": \"ordinal\"}, {\"field\": \"wheat\", \"type\": \"quantitative\"}], \"x\": {\"field\": \"year\", \"type\": \"ordinal\"}, \"y\": {\"field\": \"wheat\", \"type\": \"quantitative\"}}}, {\"mark\": {\"type\": \"text\", \"align\": \"left\", \"color\": \"#000000\", \"dy\": 60, \"text\": \"*Source: https://en.wikipedia.org/wiki/British_Agricultural_Revolution\", \"x\": 0, \"y\": \"height\"}}], \"data\": {\"name\": \"data-76d1ce26ea5761007c35827e1564d86c\"}, \"title\": {\"text\": \"What's Up With Wheat\", \"subtitle\": [\"An example of the impact of the agricultural revolution\", \"Productivity increased through mechanization*\"]}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-76d1ce26ea5761007c35827e1564d86c\": [{\"year\": 1565, \"wheat\": 41.0, \"wages\": 5.0}, {\"year\": 1570, \"wheat\": 45.0, \"wages\": 5.05}, {\"year\": 1575, \"wheat\": 42.0, \"wages\": 5.08}, {\"year\": 1580, \"wheat\": 49.0, \"wages\": 5.12}, {\"year\": 1585, \"wheat\": 41.5, \"wages\": 5.15}, {\"year\": 1590, \"wheat\": 47.0, \"wages\": 5.25}, {\"year\": 1595, \"wheat\": 64.0, \"wages\": 5.54}, {\"year\": 1600, \"wheat\": 27.0, \"wages\": 5.61}, {\"year\": 1605, \"wheat\": 33.0, \"wages\": 5.69}, {\"year\": 1610, \"wheat\": 32.0, \"wages\": 5.78}, {\"year\": 1615, \"wheat\": 33.0, \"wages\": 5.94}, {\"year\": 1620, \"wheat\": 35.0, \"wages\": 6.01}, {\"year\": 1625, \"wheat\": 33.0, \"wages\": 6.12}, {\"year\": 1630, \"wheat\": 45.0, \"wages\": 6.22}, {\"year\": 1635, \"wheat\": 33.0, \"wages\": 6.3}, {\"year\": 1640, \"wheat\": 39.0, \"wages\": 6.37}, {\"year\": 1645, \"wheat\": 53.0, \"wages\": 6.45}, {\"year\": 1650, \"wheat\": 42.0, \"wages\": 6.5}, {\"year\": 1655, \"wheat\": 40.5, \"wages\": 6.6}, {\"year\": 1660, \"wheat\": 46.5, \"wages\": 6.75}, {\"year\": 1665, \"wheat\": 32.0, \"wages\": 6.8}, {\"year\": 1670, \"wheat\": 37.0, \"wages\": 6.9}, {\"year\": 1675, \"wheat\": 43.0, \"wages\": 7.0}, {\"year\": 1680, \"wheat\": 35.0, \"wages\": 7.3}, {\"year\": 1685, \"wheat\": 27.0, \"wages\": 7.6}, {\"year\": 1690, \"wheat\": 40.0, \"wages\": 8.0}, {\"year\": 1695, \"wheat\": 50.0, \"wages\": 8.5}, {\"year\": 1700, \"wheat\": 30.0, \"wages\": 9.0}, {\"year\": 1705, \"wheat\": 32.0, \"wages\": 10.0}, {\"year\": 1710, \"wheat\": 44.0, \"wages\": 11.0}, {\"year\": 1715, \"wheat\": 33.0, \"wages\": 11.75}, {\"year\": 1720, \"wheat\": 29.0, \"wages\": 12.5}, {\"year\": 1725, \"wheat\": 39.0, \"wages\": 13.0}, {\"year\": 1730, \"wheat\": 26.0, \"wages\": 13.3}, {\"year\": 1735, \"wheat\": 32.0, \"wages\": 13.6}, {\"year\": 1740, \"wheat\": 27.0, \"wages\": 14.0}, {\"year\": 1745, \"wheat\": 27.5, \"wages\": 14.5}, {\"year\": 1750, \"wheat\": 31.0, \"wages\": 15.0}, {\"year\": 1755, \"wheat\": 35.5, \"wages\": 15.7}, {\"year\": 1760, \"wheat\": 31.0, \"wages\": 16.5}, {\"year\": 1765, \"wheat\": 43.0, \"wages\": 17.6}, {\"year\": 1770, \"wheat\": 47.0, \"wages\": 18.5}, {\"year\": 1775, \"wheat\": 44.0, \"wages\": 19.5}, {\"year\": 1780, \"wheat\": 46.0, \"wages\": 21.0}, {\"year\": 1785, \"wheat\": 42.0, \"wages\": 23.0}, {\"year\": 1790, \"wheat\": 47.5, \"wages\": 25.5}, {\"year\": 1795, \"wheat\": 76.0, \"wages\": 27.5}, {\"year\": 1800, \"wheat\": 79.0, \"wages\": 28.5}, {\"year\": 1805, \"wheat\": 81.0, \"wages\": 29.5}, {\"year\": 1810, \"wheat\": 99.0, \"wages\": 30.0}, {\"year\": 1815, \"wheat\": 78.0, \"wages\": null}, {\"year\": 1820, \"wheat\": 54.0, \"wages\": null}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "footnote = alt.Chart(wheat).mark_text(\n",
        "    text=\"*Source: https://en.wikipedia.org/wiki/British_Agricultural_Revolution\",\n",
        "    color=\"#000000\",\n",
        "    x=0,\n",
        "    y=\"height\",\n",
        "    dy=60,\n",
        "    align=\"left\",\n",
        ")\n",
        "\n",
        "alt.layer(barchart, footnote).properties(\n",
        "    title=alt.TitleParams(\n",
        "        \"What's Up With Wheat\",\n",
        "        subtitle=[\n",
        "            \"An example of the impact of the agricultural revolution\",\n",
        "            \"Productivity increased through mechanization*\",\n",
        "        ],\n",
        "    ),\n",
        ")"
      ],
      "id": "cell-17"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "### Lose the legends\n",
        "\n",
        "Although legends are fine for exploratory data analysis, where you don’t\n",
        "want to spend too much time tweaking your charts, for explanatory data\n",
        "analysis we want to make it as easy on the reader as possible.\n",
        "Unforunately, I couldn’t find a way to add annotations (instead of a\n",
        "legend) using Altair’s theming engine. Here’s a first shot by\n",
        "implementing it manually."
      ],
      "id": "89c03621-6497-44c4-ba53-e8ed29d28839"
    },
    {
      "cell_type": "code",
      "execution_count": 9,
      "metadata": {},
      "outputs": [
        {
          "output_type": "display_data",
          "metadata": {},
          "data": {
            "text/html": [
              "\n",
              "<style>\n",
              "  #altair-viz-b28b96ea177a4feba0cba7beb310b2ec.vega-embed {\n",
              "    width: 100%;\n",
              "    display: flex;\n",
              "  }\n",
              "\n",
              "  #altair-viz-b28b96ea177a4feba0cba7beb310b2ec.vega-embed details,\n",
              "  #altair-viz-b28b96ea177a4feba0cba7beb310b2ec.vega-embed details summary {\n",
              "    position: relative;\n",
              "  }\n",
              "</style>\n",
              "<div id=\"altair-viz-b28b96ea177a4feba0cba7beb310b2ec\"></div>\n",
              "<script type=\"text/javascript\">\n",
              "  var VEGA_DEBUG = (typeof VEGA_DEBUG == \"undefined\") ? {} : VEGA_DEBUG;\n",
              "  (function(spec, embedOpt){\n",
              "    let outputDiv = document.currentScript.previousElementSibling;\n",
              "    if (outputDiv.id !== \"altair-viz-b28b96ea177a4feba0cba7beb310b2ec\") {\n",
              "      outputDiv = document.getElementById(\"altair-viz-b28b96ea177a4feba0cba7beb310b2ec\");\n",
              "    }\n",
              "    const paths = {\n",
              "      \"vega\": \"https://cdn.jsdelivr.net/npm/vega@5?noext\",\n",
              "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm/vega-lib?noext\",\n",
              "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm/vega-lite@5.16.3?noext\",\n",
              "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm/vega-embed@6?noext\",\n",
              "    };\n",
              "\n",
              "    function maybeLoadScript(lib, version) {\n",
              "      var key = `${lib.replace(\"-\", \"\")}_version`;\n",
              "      return (VEGA_DEBUG[key] == version) ?\n",
              "        Promise.resolve(paths[lib]) :\n",
              "        new Promise(function(resolve, reject) {\n",
              "          var s = document.createElement('script');\n",
              "          document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
              "          s.async = true;\n",
              "          s.onload = () => {\n",
              "            VEGA_DEBUG[key] = version;\n",
              "            return resolve(paths[lib]);\n",
              "          };\n",
              "          s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
              "          s.src = paths[lib];\n",
              "        });\n",
              "    }\n",
              "\n",
              "    function showError(err) {\n",
              "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
              "      throw err;\n",
              "    }\n",
              "\n",
              "    function displayChart(vegaEmbed) {\n",
              "      vegaEmbed(outputDiv, spec, embedOpt)\n",
              "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
              "    }\n",
              "\n",
              "    if(typeof define === \"function\" && define.amd) {\n",
              "      requirejs.config({paths});\n",
              "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
              "    } else {\n",
              "      maybeLoadScript(\"vega\", \"5\")\n",
              "        .then(() => maybeLoadScript(\"vega-lite\", \"5.16.3\"))\n",
              "        .then(() => maybeLoadScript(\"vega-embed\", \"6\"))\n",
              "        .catch(showError)\n",
              "        .then(() => displayChart(vegaEmbed));\n",
              "    }\n",
              "  })({\"width\": 600, \"height\": 380, \"config\": {\"title\": {\"anchor\": \"start\", \"dy\": -15, \"fontSize\": 18, \"font\": \"Lato\", \"fontColor\": \"#000000\"}, \"axisX\": {\"domain\": true, \"domainColor\": \"#000000\", \"domainWidth\": 1, \"grid\": false, \"labelFontSize\": 12, \"labelFont\": \"Lato\", \"labelAngle\": 0, \"labelOverlap\": \"parity\", \"tickColor\": \"#000000\", \"tickSize\": 5, \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\", \"ticks\": false}, \"axisY\": {\"domain\": false, \"grid\": true, \"gridColor\": \"#DEDDDD\", \"gridWidth\": 1, \"labelFontSize\": 12, \"labelFont\": \"Lato\", \"labelPadding\": 8, \"ticks\": false, \"titleAlign\": \"left\", \"titleAnchor\": \"start\", \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\", \"titleAngle\": 0, \"titleY\": -15}, \"background\": \"#FFFFFF\", \"legend\": {\"labelFontSize\": 12, \"labelFont\": \"Lato\", \"symbolSize\": 100, \"symbolType\": \"square\", \"titleFontSize\": 12, \"titlePadding\": 10, \"titleFont\": \"Lato\", \"title\": \"\", \"orient\": \"top-left\", \"offset\": 0}, \"view\": {\"stroke\": \"transparent\"}, \"range\": {\"category\": [\"#E69F00\", \"#56B4E9\", \"#009E73\", \"#F0E442\", \"#0072B2\", \"#D55E00\", \"#CC79A7\", \"#000000\"], \"diverging\": [\"#cfe8f3\", \"#a2d4ec\", \"#73bfe2\", \"#46abdb\", \"#1696d2\", \"#12719e\"]}, \"area\": {\"fill\": \"#0072B2\"}, \"line\": {\"color\": \"#0072B2\", \"stroke\": \"#0072B2\", \"strokewidth\": 5}, \"trail\": {\"color\": \"#0072B2\", \"stroke\": \"#0072B2\", \"strokeWidth\": 0, \"size\": 1}, \"path\": {\"stroke\": \"#0072B2\", \"strokeWidth\": 0.5}, \"point\": {\"filled\": true}, \"text\": {\"font\": \"Lato\", \"color\": \"#0072B2\", \"fontSize\": 11, \"align\": \"right\", \"fontWeight\": 400, \"size\": 11}, \"bar\": {\"fill\": \"#0072B2\", \"stroke\": false}}, \"layer\": [{\"mark\": {\"type\": \"line\"}, \"encoding\": {\"color\": {\"field\": \"symbol\", \"legend\": null, \"type\": \"nominal\"}, \"tooltip\": [{\"field\": \"date\", \"type\": \"temporal\"}, {\"field\": \"price\", \"type\": \"quantitative\"}], \"x\": {\"axis\": {\"title\": \"date\"}, \"field\": \"date\", \"type\": \"temporal\"}, \"y\": {\"axis\": {\"title\": \"price\"}, \"field\": \"price\", \"type\": \"quantitative\"}}}, {\"mark\": {\"type\": \"circle\"}, \"encoding\": {\"color\": {\"field\": \"symbol\", \"legend\": null, \"type\": \"nominal\"}, \"text\": {\"field\": \"symbol\", \"type\": \"nominal\"}, \"x\": {\"aggregate\": \"max\", \"field\": \"date\", \"type\": \"temporal\"}, \"y\": {\"aggregate\": {\"argmax\": \"date\"}, \"field\": \"price\", \"type\": \"quantitative\"}}}, {\"mark\": {\"type\": \"text\", \"align\": \"left\", \"dx\": 4}, \"encoding\": {\"color\": {\"field\": \"symbol\", \"legend\": null, \"type\": \"nominal\"}, \"text\": {\"field\": \"symbol\", \"type\": \"nominal\"}, \"x\": {\"aggregate\": \"max\", \"field\": \"date\", \"type\": \"temporal\"}, \"y\": {\"aggregate\": {\"argmax\": \"date\"}, \"field\": \"price\", \"type\": \"quantitative\"}}}], \"data\": {\"name\": \"data-96e857a61c6b623bafe23440d582a500\"}, \"title\": {\"text\": \"The Rise of Google\", \"subtitle\": [\"Google went public in 2004\", \"and outperformed other tech stocks until 2010\"]}, \"$schema\": \"https://vega.github.io/schema/vega-lite/v5.16.3.json\", \"datasets\": {\"data-96e857a61c6b623bafe23440d582a500\": [{\"symbol\": \"MSFT\", \"date\": \"2000-01-01T00:00:00\", \"price\": 39.81}, {\"symbol\": \"MSFT\", \"date\": \"2000-02-01T00:00:00\", \"price\": 36.35}, {\"symbol\": \"MSFT\", \"date\": \"2000-03-01T00:00:00\", \"price\": 43.22}, {\"symbol\": \"MSFT\", \"date\": \"2000-04-01T00:00:00\", \"price\": 28.37}, {\"symbol\": \"MSFT\", \"date\": \"2000-05-01T00:00:00\", \"price\": 25.45}, {\"symbol\": \"MSFT\", \"date\": \"2000-06-01T00:00:00\", \"price\": 32.54}, {\"symbol\": \"MSFT\", \"date\": \"2000-07-01T00:00:00\", \"price\": 28.4}, {\"symbol\": \"MSFT\", \"date\": \"2000-08-01T00:00:00\", \"price\": 28.4}, {\"symbol\": \"MSFT\", \"date\": \"2000-09-01T00:00:00\", \"price\": 24.53}, {\"symbol\": \"MSFT\", \"date\": \"2000-10-01T00:00:00\", \"price\": 28.02}, {\"symbol\": \"MSFT\", \"date\": \"2000-11-01T00:00:00\", \"price\": 23.34}, {\"symbol\": \"MSFT\", \"date\": \"2000-12-01T00:00:00\", \"price\": 17.65}, {\"symbol\": \"MSFT\", \"date\": \"2001-01-01T00:00:00\", \"price\": 24.84}, {\"symbol\": \"MSFT\", \"date\": \"2001-02-01T00:00:00\", \"price\": 24.0}, {\"symbol\": \"MSFT\", \"date\": \"2001-03-01T00:00:00\", \"price\": 22.25}, {\"symbol\": \"MSFT\", \"date\": \"2001-04-01T00:00:00\", \"price\": 27.56}, {\"symbol\": \"MSFT\", \"date\": \"2001-05-01T00:00:00\", \"price\": 28.14}, {\"symbol\": \"MSFT\", \"date\": \"2001-06-01T00:00:00\", \"price\": 29.7}, {\"symbol\": \"MSFT\", \"date\": \"2001-07-01T00:00:00\", \"price\": 26.93}, {\"symbol\": \"MSFT\", \"date\": \"2001-08-01T00:00:00\", \"price\": 23.21}, {\"symbol\": \"MSFT\", \"date\": \"2001-09-01T00:00:00\", \"price\": 20.82}, {\"symbol\": \"MSFT\", \"date\": \"2001-10-01T00:00:00\", \"price\": 23.65}, {\"symbol\": \"MSFT\", \"date\": \"2001-11-01T00:00:00\", \"price\": 26.12}, {\"symbol\": \"MSFT\", \"date\": \"2001-12-01T00:00:00\", \"price\": 26.95}, {\"symbol\": \"MSFT\", \"date\": \"2002-01-01T00:00:00\", \"price\": 25.92}, {\"symbol\": \"MSFT\", \"date\": \"2002-02-01T00:00:00\", \"price\": 23.73}, {\"symbol\": \"MSFT\", \"date\": \"2002-03-01T00:00:00\", \"price\": 24.53}, {\"symbol\": \"MSFT\", \"date\": \"2002-04-01T00:00:00\", \"price\": 21.26}, {\"symbol\": \"MSFT\", \"date\": \"2002-05-01T00:00:00\", \"price\": 20.71}, {\"symbol\": \"MSFT\", \"date\": \"2002-06-01T00:00:00\", \"price\": 22.25}, {\"symbol\": \"MSFT\", \"date\": \"2002-07-01T00:00:00\", \"price\": 19.52}, {\"symbol\": \"MSFT\", \"date\": \"2002-08-01T00:00:00\", \"price\": 19.97}, {\"symbol\": \"MSFT\", \"date\": \"2002-09-01T00:00:00\", \"price\": 17.79}, {\"symbol\": \"MSFT\", \"date\": \"2002-10-01T00:00:00\", \"price\": 21.75}, {\"symbol\": \"MSFT\", \"date\": \"2002-11-01T00:00:00\", \"price\": 23.46}, {\"symbol\": \"MSFT\", \"date\": \"2002-12-01T00:00:00\", \"price\": 21.03}, {\"symbol\": \"MSFT\", \"date\": \"2003-01-01T00:00:00\", \"price\": 19.31}, {\"symbol\": \"MSFT\", \"date\": \"2003-02-01T00:00:00\", \"price\": 19.34}, {\"symbol\": \"MSFT\", \"date\": \"2003-03-01T00:00:00\", \"price\": 19.76}, {\"symbol\": \"MSFT\", \"date\": \"2003-04-01T00:00:00\", \"price\": 20.87}, {\"symbol\": \"MSFT\", \"date\": \"2003-05-01T00:00:00\", \"price\": 20.09}, {\"symbol\": \"MSFT\", \"date\": \"2003-06-01T00:00:00\", \"price\": 20.93}, {\"symbol\": \"MSFT\", \"date\": \"2003-07-01T00:00:00\", \"price\": 21.56}, {\"symbol\": \"MSFT\", \"date\": \"2003-08-01T00:00:00\", \"price\": 21.65}, {\"symbol\": \"MSFT\", \"date\": \"2003-09-01T00:00:00\", \"price\": 22.69}, {\"symbol\": \"MSFT\", \"date\": \"2003-10-01T00:00:00\", \"price\": 21.45}, {\"symbol\": \"MSFT\", \"date\": \"2003-11-01T00:00:00\", \"price\": 21.1}, {\"symbol\": \"MSFT\", \"date\": \"2003-12-01T00:00:00\", \"price\": 22.46}, {\"symbol\": \"MSFT\", \"date\": \"2004-01-01T00:00:00\", \"price\": 22.69}, {\"symbol\": \"MSFT\", \"date\": \"2004-02-01T00:00:00\", \"price\": 21.77}, {\"symbol\": \"MSFT\", \"date\": \"2004-03-01T00:00:00\", \"price\": 20.46}, {\"symbol\": \"MSFT\", \"date\": \"2004-04-01T00:00:00\", \"price\": 21.45}, {\"symbol\": \"MSFT\", \"date\": \"2004-05-01T00:00:00\", \"price\": 21.53}, {\"symbol\": \"MSFT\", \"date\": \"2004-06-01T00:00:00\", \"price\": 23.44}, {\"symbol\": \"MSFT\", \"date\": \"2004-07-01T00:00:00\", \"price\": 23.38}, {\"symbol\": \"MSFT\", \"date\": \"2004-08-01T00:00:00\", \"price\": 22.47}, {\"symbol\": \"MSFT\", \"date\": \"2004-09-01T00:00:00\", \"price\": 22.76}, {\"symbol\": \"MSFT\", \"date\": \"2004-10-01T00:00:00\", \"price\": 23.02}, {\"symbol\": \"MSFT\", \"date\": \"2004-11-01T00:00:00\", \"price\": 24.6}, {\"symbol\": \"MSFT\", \"date\": \"2004-12-01T00:00:00\", \"price\": 24.52}, {\"symbol\": \"MSFT\", \"date\": \"2005-01-01T00:00:00\", \"price\": 24.11}, {\"symbol\": \"MSFT\", \"date\": \"2005-02-01T00:00:00\", \"price\": 23.15}, {\"symbol\": \"MSFT\", \"date\": \"2005-03-01T00:00:00\", \"price\": 22.24}, {\"symbol\": \"MSFT\", \"date\": \"2005-04-01T00:00:00\", \"price\": 23.28}, {\"symbol\": \"MSFT\", \"date\": \"2005-05-01T00:00:00\", \"price\": 23.82}, {\"symbol\": \"MSFT\", \"date\": \"2005-06-01T00:00:00\", \"price\": 22.93}, {\"symbol\": \"MSFT\", \"date\": \"2005-07-01T00:00:00\", \"price\": 23.64}, {\"symbol\": \"MSFT\", \"date\": \"2005-08-01T00:00:00\", \"price\": 25.35}, {\"symbol\": \"MSFT\", \"date\": \"2005-09-01T00:00:00\", \"price\": 23.83}, {\"symbol\": \"MSFT\", \"date\": \"2005-10-01T00:00:00\", \"price\": 23.8}, {\"symbol\": \"MSFT\", \"date\": \"2005-11-01T00:00:00\", \"price\": 25.71}, {\"symbol\": \"MSFT\", \"date\": \"2005-12-01T00:00:00\", \"price\": 24.29}, {\"symbol\": \"MSFT\", \"date\": \"2006-01-01T00:00:00\", \"price\": 26.14}, {\"symbol\": \"MSFT\", \"date\": \"2006-02-01T00:00:00\", \"price\": 25.04}, {\"symbol\": \"MSFT\", \"date\": \"2006-03-01T00:00:00\", \"price\": 25.36}, {\"symbol\": \"MSFT\", \"date\": \"2006-04-01T00:00:00\", \"price\": 22.5}, {\"symbol\": \"MSFT\", \"date\": \"2006-05-01T00:00:00\", \"price\": 21.19}, {\"symbol\": \"MSFT\", \"date\": \"2006-06-01T00:00:00\", \"price\": 21.8}, {\"symbol\": \"MSFT\", \"date\": \"2006-07-01T00:00:00\", \"price\": 22.51}, {\"symbol\": \"MSFT\", \"date\": \"2006-08-01T00:00:00\", \"price\": 24.13}, {\"symbol\": \"MSFT\", \"date\": \"2006-09-01T00:00:00\", \"price\": 25.68}, {\"symbol\": \"MSFT\", \"date\": \"2006-10-01T00:00:00\", \"price\": 26.96}, {\"symbol\": \"MSFT\", \"date\": \"2006-11-01T00:00:00\", \"price\": 27.66}, {\"symbol\": \"MSFT\", \"date\": \"2006-12-01T00:00:00\", \"price\": 28.13}, {\"symbol\": \"MSFT\", \"date\": \"2007-01-01T00:00:00\", \"price\": 29.07}, {\"symbol\": \"MSFT\", \"date\": \"2007-02-01T00:00:00\", \"price\": 26.63}, {\"symbol\": \"MSFT\", \"date\": \"2007-03-01T00:00:00\", \"price\": 26.35}, {\"symbol\": \"MSFT\", \"date\": \"2007-04-01T00:00:00\", \"price\": 28.3}, {\"symbol\": \"MSFT\", \"date\": \"2007-05-01T00:00:00\", \"price\": 29.11}, {\"symbol\": \"MSFT\", \"date\": \"2007-06-01T00:00:00\", \"price\": 27.95}, {\"symbol\": \"MSFT\", \"date\": \"2007-07-01T00:00:00\", \"price\": 27.5}, {\"symbol\": \"MSFT\", \"date\": \"2007-08-01T00:00:00\", \"price\": 27.34}, {\"symbol\": \"MSFT\", \"date\": \"2007-09-01T00:00:00\", \"price\": 28.04}, {\"symbol\": \"MSFT\", \"date\": \"2007-10-01T00:00:00\", \"price\": 35.03}, {\"symbol\": \"MSFT\", \"date\": \"2007-11-01T00:00:00\", \"price\": 32.09}, {\"symbol\": \"MSFT\", \"date\": \"2007-12-01T00:00:00\", \"price\": 34.0}, {\"symbol\": \"MSFT\", \"date\": \"2008-01-01T00:00:00\", \"price\": 31.13}, {\"symbol\": \"MSFT\", \"date\": \"2008-02-01T00:00:00\", \"price\": 26.07}, {\"symbol\": \"MSFT\", \"date\": \"2008-03-01T00:00:00\", \"price\": 27.21}, {\"symbol\": \"MSFT\", \"date\": \"2008-04-01T00:00:00\", \"price\": 27.34}, {\"symbol\": \"MSFT\", \"date\": \"2008-05-01T00:00:00\", \"price\": 27.25}, {\"symbol\": \"MSFT\", \"date\": \"2008-06-01T00:00:00\", \"price\": 26.47}, {\"symbol\": \"MSFT\", \"date\": \"2008-07-01T00:00:00\", \"price\": 24.75}, {\"symbol\": \"MSFT\", \"date\": \"2008-08-01T00:00:00\", \"price\": 26.36}, {\"symbol\": \"MSFT\", \"date\": \"2008-09-01T00:00:00\", \"price\": 25.78}, {\"symbol\": \"MSFT\", \"date\": \"2008-10-01T00:00:00\", \"price\": 21.57}, {\"symbol\": \"MSFT\", \"date\": \"2008-11-01T00:00:00\", \"price\": 19.66}, {\"symbol\": \"MSFT\", \"date\": \"2008-12-01T00:00:00\", \"price\": 18.91}, {\"symbol\": \"MSFT\", \"date\": \"2009-01-01T00:00:00\", \"price\": 16.63}, {\"symbol\": \"MSFT\", \"date\": \"2009-02-01T00:00:00\", \"price\": 15.81}, {\"symbol\": \"MSFT\", \"date\": \"2009-03-01T00:00:00\", \"price\": 17.99}, {\"symbol\": \"MSFT\", \"date\": \"2009-04-01T00:00:00\", \"price\": 19.84}, {\"symbol\": \"MSFT\", \"date\": \"2009-05-01T00:00:00\", \"price\": 20.59}, {\"symbol\": \"MSFT\", \"date\": \"2009-06-01T00:00:00\", \"price\": 23.42}, {\"symbol\": \"MSFT\", \"date\": \"2009-07-01T00:00:00\", \"price\": 23.18}, {\"symbol\": \"MSFT\", \"date\": \"2009-08-01T00:00:00\", \"price\": 24.43}, {\"symbol\": \"MSFT\", \"date\": \"2009-09-01T00:00:00\", \"price\": 25.49}, {\"symbol\": \"MSFT\", \"date\": \"2009-10-01T00:00:00\", \"price\": 27.48}, {\"symbol\": \"MSFT\", \"date\": \"2009-11-01T00:00:00\", \"price\": 29.27}, {\"symbol\": \"MSFT\", \"date\": \"2009-12-01T00:00:00\", \"price\": 30.34}, {\"symbol\": \"MSFT\", \"date\": \"2010-01-01T00:00:00\", \"price\": 28.05}, {\"symbol\": \"MSFT\", \"date\": \"2010-02-01T00:00:00\", \"price\": 28.67}, {\"symbol\": \"MSFT\", \"date\": \"2010-03-01T00:00:00\", \"price\": 28.8}, {\"symbol\": \"AMZN\", \"date\": \"2000-01-01T00:00:00\", \"price\": 64.56}, {\"symbol\": \"AMZN\", \"date\": \"2000-02-01T00:00:00\", \"price\": 68.87}, {\"symbol\": \"AMZN\", \"date\": \"2000-03-01T00:00:00\", \"price\": 67.0}, {\"symbol\": \"AMZN\", \"date\": \"2000-04-01T00:00:00\", \"price\": 55.19}, {\"symbol\": \"AMZN\", \"date\": \"2000-05-01T00:00:00\", \"price\": 48.31}, {\"symbol\": \"AMZN\", \"date\": \"2000-06-01T00:00:00\", \"price\": 36.31}, {\"symbol\": \"AMZN\", \"date\": \"2000-07-01T00:00:00\", \"price\": 30.12}, {\"symbol\": \"AMZN\", \"date\": \"2000-08-01T00:00:00\", \"price\": 41.5}, {\"symbol\": \"AMZN\", \"date\": \"2000-09-01T00:00:00\", \"price\": 38.44}, {\"symbol\": \"AMZN\", \"date\": \"2000-10-01T00:00:00\", \"price\": 36.62}, {\"symbol\": \"AMZN\", \"date\": \"2000-11-01T00:00:00\", \"price\": 24.69}, {\"symbol\": \"AMZN\", \"date\": \"2000-12-01T00:00:00\", \"price\": 15.56}, {\"symbol\": \"AMZN\", \"date\": \"2001-01-01T00:00:00\", \"price\": 17.31}, {\"symbol\": \"AMZN\", \"date\": \"2001-02-01T00:00:00\", \"price\": 10.19}, {\"symbol\": \"AMZN\", \"date\": \"2001-03-01T00:00:00\", \"price\": 10.23}, {\"symbol\": \"AMZN\", \"date\": \"2001-04-01T00:00:00\", \"price\": 15.78}, {\"symbol\": \"AMZN\", \"date\": \"2001-05-01T00:00:00\", \"price\": 16.69}, {\"symbol\": \"AMZN\", \"date\": \"2001-06-01T00:00:00\", \"price\": 14.15}, {\"symbol\": \"AMZN\", \"date\": \"2001-07-01T00:00:00\", \"price\": 12.49}, {\"symbol\": \"AMZN\", \"date\": \"2001-08-01T00:00:00\", \"price\": 8.94}, {\"symbol\": \"AMZN\", \"date\": \"2001-09-01T00:00:00\", \"price\": 5.97}, {\"symbol\": \"AMZN\", \"date\": \"2001-10-01T00:00:00\", \"price\": 6.98}, {\"symbol\": \"AMZN\", \"date\": \"2001-11-01T00:00:00\", \"price\": 11.32}, {\"symbol\": \"AMZN\", \"date\": \"2001-12-01T00:00:00\", \"price\": 10.82}, {\"symbol\": \"AMZN\", \"date\": \"2002-01-01T00:00:00\", \"price\": 14.19}, {\"symbol\": \"AMZN\", \"date\": \"2002-02-01T00:00:00\", \"price\": 14.1}, {\"symbol\": \"AMZN\", \"date\": \"2002-03-01T00:00:00\", \"price\": 14.3}, {\"symbol\": \"AMZN\", \"date\": \"2002-04-01T00:00:00\", \"price\": 16.69}, {\"symbol\": \"AMZN\", \"date\": \"2002-05-01T00:00:00\", \"price\": 18.23}, {\"symbol\": \"AMZN\", \"date\": \"2002-06-01T00:00:00\", \"price\": 16.25}, {\"symbol\": \"AMZN\", \"date\": \"2002-07-01T00:00:00\", \"price\": 14.45}, {\"symbol\": \"AMZN\", \"date\": \"2002-08-01T00:00:00\", \"price\": 14.94}, {\"symbol\": \"AMZN\", \"date\": \"2002-09-01T00:00:00\", \"price\": 15.93}, {\"symbol\": \"AMZN\", \"date\": \"2002-10-01T00:00:00\", \"price\": 19.36}, {\"symbol\": \"AMZN\", \"date\": \"2002-11-01T00:00:00\", \"price\": 23.35}, {\"symbol\": \"AMZN\", \"date\": \"2002-12-01T00:00:00\", \"price\": 18.89}, {\"symbol\": \"AMZN\", \"date\": \"2003-01-01T00:00:00\", \"price\": 21.85}, {\"symbol\": \"AMZN\", \"date\": \"2003-02-01T00:00:00\", \"price\": 22.01}, {\"symbol\": \"AMZN\", \"date\": \"2003-03-01T00:00:00\", \"price\": 26.03}, {\"symbol\": \"AMZN\", \"date\": \"2003-04-01T00:00:00\", \"price\": 28.69}, {\"symbol\": \"AMZN\", \"date\": \"2003-05-01T00:00:00\", \"price\": 35.89}, {\"symbol\": \"AMZN\", \"date\": \"2003-06-01T00:00:00\", \"price\": 36.32}, {\"symbol\": \"AMZN\", \"date\": \"2003-07-01T00:00:00\", \"price\": 41.64}, {\"symbol\": \"AMZN\", \"date\": \"2003-08-01T00:00:00\", \"price\": 46.32}, {\"symbol\": \"AMZN\", \"date\": \"2003-09-01T00:00:00\", \"price\": 48.43}, {\"symbol\": \"AMZN\", \"date\": \"2003-10-01T00:00:00\", \"price\": 54.43}, {\"symbol\": \"AMZN\", \"date\": \"2003-11-01T00:00:00\", \"price\": 53.97}, {\"symbol\": \"AMZN\", \"date\": \"2003-12-01T00:00:00\", \"price\": 52.62}, {\"symbol\": \"AMZN\", \"date\": \"2004-01-01T00:00:00\", \"price\": 50.4}, {\"symbol\": \"AMZN\", \"date\": \"2004-02-01T00:00:00\", \"price\": 43.01}, {\"symbol\": \"AMZN\", \"date\": \"2004-03-01T00:00:00\", \"price\": 43.28}, {\"symbol\": \"AMZN\", \"date\": \"2004-04-01T00:00:00\", \"price\": 43.6}, {\"symbol\": \"AMZN\", \"date\": \"2004-05-01T00:00:00\", \"price\": 48.5}, {\"symbol\": \"AMZN\", \"date\": \"2004-06-01T00:00:00\", \"price\": 54.4}, {\"symbol\": \"AMZN\", \"date\": \"2004-07-01T00:00:00\", \"price\": 38.92}, {\"symbol\": \"AMZN\", \"date\": \"2004-08-01T00:00:00\", \"price\": 38.14}, {\"symbol\": \"AMZN\", \"date\": \"2004-09-01T00:00:00\", \"price\": 40.86}, {\"symbol\": \"AMZN\", \"date\": \"2004-10-01T00:00:00\", \"price\": 34.13}, {\"symbol\": \"AMZN\", \"date\": \"2004-11-01T00:00:00\", \"price\": 39.68}, {\"symbol\": \"AMZN\", \"date\": \"2004-12-01T00:00:00\", \"price\": 44.29}, {\"symbol\": \"AMZN\", \"date\": \"2005-01-01T00:00:00\", \"price\": 43.22}, {\"symbol\": \"AMZN\", \"date\": \"2005-02-01T00:00:00\", \"price\": 35.18}, {\"symbol\": \"AMZN\", \"date\": \"2005-03-01T00:00:00\", \"price\": 34.27}, {\"symbol\": \"AMZN\", \"date\": \"2005-04-01T00:00:00\", \"price\": 32.36}, {\"symbol\": \"AMZN\", \"date\": \"2005-05-01T00:00:00\", \"price\": 35.51}, {\"symbol\": \"AMZN\", \"date\": \"2005-06-01T00:00:00\", \"price\": 33.09}, {\"symbol\": \"AMZN\", \"date\": \"2005-07-01T00:00:00\", \"price\": 45.15}, {\"symbol\": \"AMZN\", \"date\": \"2005-08-01T00:00:00\", \"price\": 42.7}, {\"symbol\": \"AMZN\", \"date\": \"2005-09-01T00:00:00\", \"price\": 45.3}, {\"symbol\": \"AMZN\", \"date\": \"2005-10-01T00:00:00\", \"price\": 39.86}, {\"symbol\": \"AMZN\", \"date\": \"2005-11-01T00:00:00\", \"price\": 48.46}, {\"symbol\": \"AMZN\", \"date\": \"2005-12-01T00:00:00\", \"price\": 47.15}, {\"symbol\": \"AMZN\", \"date\": \"2006-01-01T00:00:00\", \"price\": 44.82}, {\"symbol\": \"AMZN\", \"date\": \"2006-02-01T00:00:00\", \"price\": 37.44}, {\"symbol\": \"AMZN\", \"date\": \"2006-03-01T00:00:00\", \"price\": 36.53}, {\"symbol\": \"AMZN\", \"date\": \"2006-04-01T00:00:00\", \"price\": 35.21}, {\"symbol\": \"AMZN\", \"date\": \"2006-05-01T00:00:00\", \"price\": 34.61}, {\"symbol\": \"AMZN\", \"date\": \"2006-06-01T00:00:00\", \"price\": 38.68}, {\"symbol\": \"AMZN\", \"date\": \"2006-07-01T00:00:00\", \"price\": 26.89}, {\"symbol\": \"AMZN\", \"date\": \"2006-08-01T00:00:00\", \"price\": 30.83}, {\"symbol\": \"AMZN\", \"date\": \"2006-09-01T00:00:00\", \"price\": 32.12}, {\"symbol\": \"AMZN\", \"date\": \"2006-10-01T00:00:00\", \"price\": 38.09}, {\"symbol\": \"AMZN\", \"date\": \"2006-11-01T00:00:00\", \"price\": 40.34}, {\"symbol\": \"AMZN\", \"date\": \"2006-12-01T00:00:00\", \"price\": 39.46}, {\"symbol\": \"AMZN\", \"date\": \"2007-01-01T00:00:00\", \"price\": 37.67}, {\"symbol\": \"AMZN\", \"date\": \"2007-02-01T00:00:00\", \"price\": 39.14}, {\"symbol\": \"AMZN\", \"date\": \"2007-03-01T00:00:00\", \"price\": 39.79}, {\"symbol\": \"AMZN\", \"date\": \"2007-04-01T00:00:00\", \"price\": 61.33}, {\"symbol\": \"AMZN\", \"date\": \"2007-05-01T00:00:00\", \"price\": 69.14}, {\"symbol\": \"AMZN\", \"date\": \"2007-06-01T00:00:00\", \"price\": 68.41}, {\"symbol\": \"AMZN\", \"date\": \"2007-07-01T00:00:00\", \"price\": 78.54}, {\"symbol\": \"AMZN\", \"date\": \"2007-08-01T00:00:00\", \"price\": 79.91}, {\"symbol\": \"AMZN\", \"date\": \"2007-09-01T00:00:00\", \"price\": 93.15}, {\"symbol\": \"AMZN\", \"date\": \"2007-10-01T00:00:00\", \"price\": 89.15}, {\"symbol\": \"AMZN\", \"date\": \"2007-11-01T00:00:00\", \"price\": 90.56}, {\"symbol\": \"AMZN\", \"date\": \"2007-12-01T00:00:00\", \"price\": 92.64}, {\"symbol\": \"AMZN\", \"date\": \"2008-01-01T00:00:00\", \"price\": 77.7}, {\"symbol\": \"AMZN\", \"date\": \"2008-02-01T00:00:00\", \"price\": 64.47}, {\"symbol\": \"AMZN\", \"date\": \"2008-03-01T00:00:00\", \"price\": 71.3}, {\"symbol\": \"AMZN\", \"date\": \"2008-04-01T00:00:00\", \"price\": 78.63}, {\"symbol\": \"AMZN\", \"date\": \"2008-05-01T00:00:00\", \"price\": 81.62}, {\"symbol\": \"AMZN\", \"date\": \"2008-06-01T00:00:00\", \"price\": 73.33}, {\"symbol\": \"AMZN\", \"date\": \"2008-07-01T00:00:00\", \"price\": 76.34}, {\"symbol\": \"AMZN\", \"date\": \"2008-08-01T00:00:00\", \"price\": 80.81}, {\"symbol\": \"AMZN\", \"date\": \"2008-09-01T00:00:00\", \"price\": 72.76}, {\"symbol\": \"AMZN\", \"date\": \"2008-10-01T00:00:00\", \"price\": 57.24}, {\"symbol\": \"AMZN\", \"date\": \"2008-11-01T00:00:00\", \"price\": 42.7}, {\"symbol\": \"AMZN\", \"date\": \"2008-12-01T00:00:00\", \"price\": 51.28}, {\"symbol\": \"AMZN\", \"date\": \"2009-01-01T00:00:00\", \"price\": 58.82}, {\"symbol\": \"AMZN\", \"date\": \"2009-02-01T00:00:00\", \"price\": 64.79}, {\"symbol\": \"AMZN\", \"date\": \"2009-03-01T00:00:00\", \"price\": 73.44}, {\"symbol\": \"AMZN\", \"date\": \"2009-04-01T00:00:00\", \"price\": 80.52}, {\"symbol\": \"AMZN\", \"date\": \"2009-05-01T00:00:00\", \"price\": 77.99}, {\"symbol\": \"AMZN\", \"date\": \"2009-06-01T00:00:00\", \"price\": 83.66}, {\"symbol\": \"AMZN\", \"date\": \"2009-07-01T00:00:00\", \"price\": 85.76}, {\"symbol\": \"AMZN\", \"date\": \"2009-08-01T00:00:00\", \"price\": 81.19}, {\"symbol\": \"AMZN\", \"date\": \"2009-09-01T00:00:00\", \"price\": 93.36}, {\"symbol\": \"AMZN\", \"date\": \"2009-10-01T00:00:00\", \"price\": 118.81}, {\"symbol\": \"AMZN\", \"date\": \"2009-11-01T00:00:00\", \"price\": 135.91}, {\"symbol\": \"AMZN\", \"date\": \"2009-12-01T00:00:00\", \"price\": 134.52}, {\"symbol\": \"AMZN\", \"date\": \"2010-01-01T00:00:00\", \"price\": 125.41}, {\"symbol\": \"AMZN\", \"date\": \"2010-02-01T00:00:00\", \"price\": 118.4}, {\"symbol\": \"AMZN\", \"date\": \"2010-03-01T00:00:00\", \"price\": 128.82}, {\"symbol\": \"IBM\", \"date\": \"2000-01-01T00:00:00\", \"price\": 100.52}, {\"symbol\": \"IBM\", \"date\": \"2000-02-01T00:00:00\", \"price\": 92.11}, {\"symbol\": \"IBM\", \"date\": \"2000-03-01T00:00:00\", \"price\": 106.11}, {\"symbol\": \"IBM\", \"date\": \"2000-04-01T00:00:00\", \"price\": 99.95}, {\"symbol\": \"IBM\", \"date\": \"2000-05-01T00:00:00\", \"price\": 96.31}, {\"symbol\": \"IBM\", \"date\": \"2000-06-01T00:00:00\", \"price\": 98.33}, {\"symbol\": \"IBM\", \"date\": \"2000-07-01T00:00:00\", \"price\": 100.74}, {\"symbol\": \"IBM\", \"date\": \"2000-08-01T00:00:00\", \"price\": 118.62}, {\"symbol\": \"IBM\", \"date\": \"2000-09-01T00:00:00\", \"price\": 101.19}, {\"symbol\": \"IBM\", \"date\": \"2000-10-01T00:00:00\", \"price\": 88.5}, {\"symbol\": \"IBM\", \"date\": \"2000-11-01T00:00:00\", \"price\": 84.12}, {\"symbol\": \"IBM\", \"date\": \"2000-12-01T00:00:00\", \"price\": 76.47}, {\"symbol\": \"IBM\", \"date\": \"2001-01-01T00:00:00\", \"price\": 100.76}, {\"symbol\": \"IBM\", \"date\": \"2001-02-01T00:00:00\", \"price\": 89.98}, {\"symbol\": \"IBM\", \"date\": \"2001-03-01T00:00:00\", \"price\": 86.63}, {\"symbol\": \"IBM\", \"date\": \"2001-04-01T00:00:00\", \"price\": 103.7}, {\"symbol\": \"IBM\", \"date\": \"2001-05-01T00:00:00\", \"price\": 100.82}, {\"symbol\": \"IBM\", \"date\": \"2001-06-01T00:00:00\", \"price\": 102.35}, {\"symbol\": \"IBM\", \"date\": \"2001-07-01T00:00:00\", \"price\": 94.87}, {\"symbol\": \"IBM\", \"date\": \"2001-08-01T00:00:00\", \"price\": 90.25}, {\"symbol\": \"IBM\", \"date\": \"2001-09-01T00:00:00\", \"price\": 82.82}, {\"symbol\": \"IBM\", \"date\": \"2001-10-01T00:00:00\", \"price\": 97.58}, {\"symbol\": \"IBM\", \"date\": \"2001-11-01T00:00:00\", \"price\": 104.5}, {\"symbol\": \"IBM\", \"date\": \"2001-12-01T00:00:00\", \"price\": 109.36}, {\"symbol\": \"IBM\", \"date\": \"2002-01-01T00:00:00\", \"price\": 97.54}, {\"symbol\": \"IBM\", \"date\": \"2002-02-01T00:00:00\", \"price\": 88.82}, {\"symbol\": \"IBM\", \"date\": \"2002-03-01T00:00:00\", \"price\": 94.15}, {\"symbol\": \"IBM\", \"date\": \"2002-04-01T00:00:00\", \"price\": 75.82}, {\"symbol\": \"IBM\", \"date\": \"2002-05-01T00:00:00\", \"price\": 72.97}, {\"symbol\": \"IBM\", \"date\": \"2002-06-01T00:00:00\", \"price\": 65.31}, {\"symbol\": \"IBM\", \"date\": \"2002-07-01T00:00:00\", \"price\": 63.86}, {\"symbol\": \"IBM\", \"date\": \"2002-08-01T00:00:00\", \"price\": 68.52}, {\"symbol\": \"IBM\", \"date\": \"2002-09-01T00:00:00\", \"price\": 53.01}, {\"symbol\": \"IBM\", \"date\": \"2002-10-01T00:00:00\", \"price\": 71.76}, {\"symbol\": \"IBM\", \"date\": \"2002-11-01T00:00:00\", \"price\": 79.16}, {\"symbol\": \"IBM\", \"date\": \"2002-12-01T00:00:00\", \"price\": 70.58}, {\"symbol\": \"IBM\", \"date\": \"2003-01-01T00:00:00\", \"price\": 71.22}, {\"symbol\": \"IBM\", \"date\": \"2003-02-01T00:00:00\", \"price\": 71.13}, {\"symbol\": \"IBM\", \"date\": \"2003-03-01T00:00:00\", \"price\": 71.57}, {\"symbol\": \"IBM\", \"date\": \"2003-04-01T00:00:00\", \"price\": 77.47}, {\"symbol\": \"IBM\", \"date\": \"2003-05-01T00:00:00\", \"price\": 80.48}, {\"symbol\": \"IBM\", \"date\": \"2003-06-01T00:00:00\", \"price\": 75.42}, {\"symbol\": \"IBM\", \"date\": \"2003-07-01T00:00:00\", \"price\": 74.28}, {\"symbol\": \"IBM\", \"date\": \"2003-08-01T00:00:00\", \"price\": 75.12}, {\"symbol\": \"IBM\", \"date\": \"2003-09-01T00:00:00\", \"price\": 80.91}, {\"symbol\": \"IBM\", \"date\": \"2003-10-01T00:00:00\", \"price\": 81.96}, {\"symbol\": \"IBM\", \"date\": \"2003-11-01T00:00:00\", \"price\": 83.08}, {\"symbol\": \"IBM\", \"date\": \"2003-12-01T00:00:00\", \"price\": 85.05}, {\"symbol\": \"IBM\", \"date\": \"2004-01-01T00:00:00\", \"price\": 91.06}, {\"symbol\": \"IBM\", \"date\": \"2004-02-01T00:00:00\", \"price\": 88.7}, {\"symbol\": \"IBM\", \"date\": \"2004-03-01T00:00:00\", \"price\": 84.41}, {\"symbol\": \"IBM\", \"date\": \"2004-04-01T00:00:00\", \"price\": 81.04}, {\"symbol\": \"IBM\", \"date\": \"2004-05-01T00:00:00\", \"price\": 81.59}, {\"symbol\": \"IBM\", \"date\": \"2004-06-01T00:00:00\", \"price\": 81.19}, {\"symbol\": \"IBM\", \"date\": \"2004-07-01T00:00:00\", \"price\": 80.19}, {\"symbol\": \"IBM\", \"date\": \"2004-08-01T00:00:00\", \"price\": 78.17}, {\"symbol\": \"IBM\", \"date\": \"2004-09-01T00:00:00\", \"price\": 79.13}, {\"symbol\": \"IBM\", \"date\": \"2004-10-01T00:00:00\", \"price\": 82.84}, {\"symbol\": \"IBM\", \"date\": \"2004-11-01T00:00:00\", \"price\": 87.15}, {\"symbol\": \"IBM\", \"date\": \"2004-12-01T00:00:00\", \"price\": 91.16}, {\"symbol\": \"IBM\", \"date\": \"2005-01-01T00:00:00\", \"price\": 86.39}, {\"symbol\": \"IBM\", \"date\": \"2005-02-01T00:00:00\", \"price\": 85.78}, {\"symbol\": \"IBM\", \"date\": \"2005-03-01T00:00:00\", \"price\": 84.66}, {\"symbol\": \"IBM\", \"date\": \"2005-04-01T00:00:00\", \"price\": 70.77}, {\"symbol\": \"IBM\", \"date\": \"2005-05-01T00:00:00\", \"price\": 70.18}, {\"symbol\": \"IBM\", \"date\": \"2005-06-01T00:00:00\", \"price\": 68.93}, {\"symbol\": \"IBM\", \"date\": \"2005-07-01T00:00:00\", \"price\": 77.53}, {\"symbol\": \"IBM\", \"date\": \"2005-08-01T00:00:00\", \"price\": 75.07}, {\"symbol\": \"IBM\", \"date\": \"2005-09-01T00:00:00\", \"price\": 74.7}, {\"symbol\": \"IBM\", \"date\": \"2005-10-01T00:00:00\", \"price\": 76.25}, {\"symbol\": \"IBM\", \"date\": \"2005-11-01T00:00:00\", \"price\": 82.98}, {\"symbol\": \"IBM\", \"date\": \"2005-12-01T00:00:00\", \"price\": 76.73}, {\"symbol\": \"IBM\", \"date\": \"2006-01-01T00:00:00\", \"price\": 75.89}, {\"symbol\": \"IBM\", \"date\": \"2006-02-01T00:00:00\", \"price\": 75.09}, {\"symbol\": \"IBM\", \"date\": \"2006-03-01T00:00:00\", \"price\": 77.17}, {\"symbol\": \"IBM\", \"date\": \"2006-04-01T00:00:00\", \"price\": 77.05}, {\"symbol\": \"IBM\", \"date\": \"2006-05-01T00:00:00\", \"price\": 75.04}, {\"symbol\": \"IBM\", \"date\": \"2006-06-01T00:00:00\", \"price\": 72.15}, {\"symbol\": \"IBM\", \"date\": \"2006-07-01T00:00:00\", \"price\": 72.7}, {\"symbol\": \"IBM\", \"date\": \"2006-08-01T00:00:00\", \"price\": 76.35}, {\"symbol\": \"IBM\", \"date\": \"2006-09-01T00:00:00\", \"price\": 77.26}, {\"symbol\": \"IBM\", \"date\": \"2006-10-01T00:00:00\", \"price\": 87.06}, {\"symbol\": \"IBM\", \"date\": \"2006-11-01T00:00:00\", \"price\": 86.95}, {\"symbol\": \"IBM\", \"date\": \"2006-12-01T00:00:00\", \"price\": 91.9}, {\"symbol\": \"IBM\", \"date\": \"2007-01-01T00:00:00\", \"price\": 93.79}, {\"symbol\": \"IBM\", \"date\": \"2007-02-01T00:00:00\", \"price\": 88.18}, {\"symbol\": \"IBM\", \"date\": \"2007-03-01T00:00:00\", \"price\": 89.44}, {\"symbol\": \"IBM\", \"date\": \"2007-04-01T00:00:00\", \"price\": 96.98}, {\"symbol\": \"IBM\", \"date\": \"2007-05-01T00:00:00\", \"price\": 101.54}, {\"symbol\": \"IBM\", \"date\": \"2007-06-01T00:00:00\", \"price\": 100.25}, {\"symbol\": \"IBM\", \"date\": \"2007-07-01T00:00:00\", \"price\": 105.4}, {\"symbol\": \"IBM\", \"date\": \"2007-08-01T00:00:00\", \"price\": 111.54}, {\"symbol\": \"IBM\", \"date\": \"2007-09-01T00:00:00\", \"price\": 112.6}, {\"symbol\": \"IBM\", \"date\": \"2007-10-01T00:00:00\", \"price\": 111.0}, {\"symbol\": \"IBM\", \"date\": \"2007-11-01T00:00:00\", \"price\": 100.9}, {\"symbol\": \"IBM\", \"date\": \"2007-12-01T00:00:00\", \"price\": 103.7}, {\"symbol\": \"IBM\", \"date\": \"2008-01-01T00:00:00\", \"price\": 102.75}, {\"symbol\": \"IBM\", \"date\": \"2008-02-01T00:00:00\", \"price\": 109.64}, {\"symbol\": \"IBM\", \"date\": \"2008-03-01T00:00:00\", \"price\": 110.87}, {\"symbol\": \"IBM\", \"date\": \"2008-04-01T00:00:00\", \"price\": 116.23}, {\"symbol\": \"IBM\", \"date\": \"2008-05-01T00:00:00\", \"price\": 125.14}, {\"symbol\": \"IBM\", \"date\": \"2008-06-01T00:00:00\", \"price\": 114.6}, {\"symbol\": \"IBM\", \"date\": \"2008-07-01T00:00:00\", \"price\": 123.74}, {\"symbol\": \"IBM\", \"date\": \"2008-08-01T00:00:00\", \"price\": 118.16}, {\"symbol\": \"IBM\", \"date\": \"2008-09-01T00:00:00\", \"price\": 113.53}, {\"symbol\": \"IBM\", \"date\": \"2008-10-01T00:00:00\", \"price\": 90.24}, {\"symbol\": \"IBM\", \"date\": \"2008-11-01T00:00:00\", \"price\": 79.65}, {\"symbol\": \"IBM\", \"date\": \"2008-12-01T00:00:00\", \"price\": 82.15}, {\"symbol\": \"IBM\", \"date\": \"2009-01-01T00:00:00\", \"price\": 89.46}, {\"symbol\": \"IBM\", \"date\": \"2009-02-01T00:00:00\", \"price\": 90.32}, {\"symbol\": \"IBM\", \"date\": \"2009-03-01T00:00:00\", \"price\": 95.09}, {\"symbol\": \"IBM\", \"date\": \"2009-04-01T00:00:00\", \"price\": 101.29}, {\"symbol\": \"IBM\", \"date\": \"2009-05-01T00:00:00\", \"price\": 104.85}, {\"symbol\": \"IBM\", \"date\": \"2009-06-01T00:00:00\", \"price\": 103.01}, {\"symbol\": \"IBM\", \"date\": \"2009-07-01T00:00:00\", \"price\": 116.34}, {\"symbol\": \"IBM\", \"date\": \"2009-08-01T00:00:00\", \"price\": 117.0}, {\"symbol\": \"IBM\", \"date\": \"2009-09-01T00:00:00\", \"price\": 118.55}, {\"symbol\": \"IBM\", \"date\": \"2009-10-01T00:00:00\", \"price\": 119.54}, {\"symbol\": \"IBM\", \"date\": \"2009-11-01T00:00:00\", \"price\": 125.79}, {\"symbol\": \"IBM\", \"date\": \"2009-12-01T00:00:00\", \"price\": 130.32}, {\"symbol\": \"IBM\", \"date\": \"2010-01-01T00:00:00\", \"price\": 121.85}, {\"symbol\": \"IBM\", \"date\": \"2010-02-01T00:00:00\", \"price\": 127.16}, {\"symbol\": \"IBM\", \"date\": \"2010-03-01T00:00:00\", \"price\": 125.55}, {\"symbol\": \"GOOG\", \"date\": \"2004-08-01T00:00:00\", \"price\": 102.37}, {\"symbol\": \"GOOG\", \"date\": \"2004-09-01T00:00:00\", \"price\": 129.6}, {\"symbol\": \"GOOG\", \"date\": \"2004-10-01T00:00:00\", \"price\": 190.64}, {\"symbol\": \"GOOG\", \"date\": \"2004-11-01T00:00:00\", \"price\": 181.98}, {\"symbol\": \"GOOG\", \"date\": \"2004-12-01T00:00:00\", \"price\": 192.79}, {\"symbol\": \"GOOG\", \"date\": \"2005-01-01T00:00:00\", \"price\": 195.62}, {\"symbol\": \"GOOG\", \"date\": \"2005-02-01T00:00:00\", \"price\": 187.99}, {\"symbol\": \"GOOG\", \"date\": \"2005-03-01T00:00:00\", \"price\": 180.51}, {\"symbol\": \"GOOG\", \"date\": \"2005-04-01T00:00:00\", \"price\": 220.0}, {\"symbol\": \"GOOG\", \"date\": \"2005-05-01T00:00:00\", \"price\": 277.27}, {\"symbol\": \"GOOG\", \"date\": \"2005-06-01T00:00:00\", \"price\": 294.15}, {\"symbol\": \"GOOG\", \"date\": \"2005-07-01T00:00:00\", \"price\": 287.76}, {\"symbol\": \"GOOG\", \"date\": \"2005-08-01T00:00:00\", \"price\": 286.0}, {\"symbol\": \"GOOG\", \"date\": \"2005-09-01T00:00:00\", \"price\": 316.46}, {\"symbol\": \"GOOG\", \"date\": \"2005-10-01T00:00:00\", \"price\": 372.14}, {\"symbol\": \"GOOG\", \"date\": \"2005-11-01T00:00:00\", \"price\": 404.91}, {\"symbol\": \"GOOG\", \"date\": \"2005-12-01T00:00:00\", \"price\": 414.86}, {\"symbol\": \"GOOG\", \"date\": \"2006-01-01T00:00:00\", \"price\": 432.66}, {\"symbol\": \"GOOG\", \"date\": \"2006-02-01T00:00:00\", \"price\": 362.62}, {\"symbol\": \"GOOG\", \"date\": \"2006-03-01T00:00:00\", \"price\": 390.0}, {\"symbol\": \"GOOG\", \"date\": \"2006-04-01T00:00:00\", \"price\": 417.94}, {\"symbol\": \"GOOG\", \"date\": \"2006-05-01T00:00:00\", \"price\": 371.82}, {\"symbol\": \"GOOG\", \"date\": \"2006-06-01T00:00:00\", \"price\": 419.33}, {\"symbol\": \"GOOG\", \"date\": \"2006-07-01T00:00:00\", \"price\": 386.6}, {\"symbol\": \"GOOG\", \"date\": \"2006-08-01T00:00:00\", \"price\": 378.53}, {\"symbol\": \"GOOG\", \"date\": \"2006-09-01T00:00:00\", \"price\": 401.9}, {\"symbol\": \"GOOG\", \"date\": \"2006-10-01T00:00:00\", \"price\": 476.39}, {\"symbol\": \"GOOG\", \"date\": \"2006-11-01T00:00:00\", \"price\": 484.81}, {\"symbol\": \"GOOG\", \"date\": \"2006-12-01T00:00:00\", \"price\": 460.48}, {\"symbol\": \"GOOG\", \"date\": \"2007-01-01T00:00:00\", \"price\": 501.5}, {\"symbol\": \"GOOG\", \"date\": \"2007-02-01T00:00:00\", \"price\": 449.45}, {\"symbol\": \"GOOG\", \"date\": \"2007-03-01T00:00:00\", \"price\": 458.16}, {\"symbol\": \"GOOG\", \"date\": \"2007-04-01T00:00:00\", \"price\": 471.38}, {\"symbol\": \"GOOG\", \"date\": \"2007-05-01T00:00:00\", \"price\": 497.91}, {\"symbol\": \"GOOG\", \"date\": \"2007-06-01T00:00:00\", \"price\": 522.7}, {\"symbol\": \"GOOG\", \"date\": \"2007-07-01T00:00:00\", \"price\": 510.0}, {\"symbol\": \"GOOG\", \"date\": \"2007-08-01T00:00:00\", \"price\": 515.25}, {\"symbol\": \"GOOG\", \"date\": \"2007-09-01T00:00:00\", \"price\": 567.27}, {\"symbol\": \"GOOG\", \"date\": \"2007-10-01T00:00:00\", \"price\": 707.0}, {\"symbol\": \"GOOG\", \"date\": \"2007-11-01T00:00:00\", \"price\": 693.0}, {\"symbol\": \"GOOG\", \"date\": \"2007-12-01T00:00:00\", \"price\": 691.48}, {\"symbol\": \"GOOG\", \"date\": \"2008-01-01T00:00:00\", \"price\": 564.3}, {\"symbol\": \"GOOG\", \"date\": \"2008-02-01T00:00:00\", \"price\": 471.18}, {\"symbol\": \"GOOG\", \"date\": \"2008-03-01T00:00:00\", \"price\": 440.47}, {\"symbol\": \"GOOG\", \"date\": \"2008-04-01T00:00:00\", \"price\": 574.29}, {\"symbol\": \"GOOG\", \"date\": \"2008-05-01T00:00:00\", \"price\": 585.8}, {\"symbol\": \"GOOG\", \"date\": \"2008-06-01T00:00:00\", \"price\": 526.42}, {\"symbol\": \"GOOG\", \"date\": \"2008-07-01T00:00:00\", \"price\": 473.75}, {\"symbol\": \"GOOG\", \"date\": \"2008-08-01T00:00:00\", \"price\": 463.29}, {\"symbol\": \"GOOG\", \"date\": \"2008-09-01T00:00:00\", \"price\": 400.52}, {\"symbol\": \"GOOG\", \"date\": \"2008-10-01T00:00:00\", \"price\": 359.36}, {\"symbol\": \"GOOG\", \"date\": \"2008-11-01T00:00:00\", \"price\": 292.96}, {\"symbol\": \"GOOG\", \"date\": \"2008-12-01T00:00:00\", \"price\": 307.65}, {\"symbol\": \"GOOG\", \"date\": \"2009-01-01T00:00:00\", \"price\": 338.53}, {\"symbol\": \"GOOG\", \"date\": \"2009-02-01T00:00:00\", \"price\": 337.99}, {\"symbol\": \"GOOG\", \"date\": \"2009-03-01T00:00:00\", \"price\": 348.06}, {\"symbol\": \"GOOG\", \"date\": \"2009-04-01T00:00:00\", \"price\": 395.97}, {\"symbol\": \"GOOG\", \"date\": \"2009-05-01T00:00:00\", \"price\": 417.23}, {\"symbol\": \"GOOG\", \"date\": \"2009-06-01T00:00:00\", \"price\": 421.59}, {\"symbol\": \"GOOG\", \"date\": \"2009-07-01T00:00:00\", \"price\": 443.05}, {\"symbol\": \"GOOG\", \"date\": \"2009-08-01T00:00:00\", \"price\": 461.67}, {\"symbol\": \"GOOG\", \"date\": \"2009-09-01T00:00:00\", \"price\": 495.85}, {\"symbol\": \"GOOG\", \"date\": \"2009-10-01T00:00:00\", \"price\": 536.12}, {\"symbol\": \"GOOG\", \"date\": \"2009-11-01T00:00:00\", \"price\": 583.0}, {\"symbol\": \"GOOG\", \"date\": \"2009-12-01T00:00:00\", \"price\": 619.98}, {\"symbol\": \"GOOG\", \"date\": \"2010-01-01T00:00:00\", \"price\": 529.94}, {\"symbol\": \"GOOG\", \"date\": \"2010-02-01T00:00:00\", \"price\": 526.8}, {\"symbol\": \"GOOG\", \"date\": \"2010-03-01T00:00:00\", \"price\": 560.19}, {\"symbol\": \"AAPL\", \"date\": \"2000-01-01T00:00:00\", \"price\": 25.94}, {\"symbol\": \"AAPL\", \"date\": \"2000-02-01T00:00:00\", \"price\": 28.66}, {\"symbol\": \"AAPL\", \"date\": \"2000-03-01T00:00:00\", \"price\": 33.95}, {\"symbol\": \"AAPL\", \"date\": \"2000-04-01T00:00:00\", \"price\": 31.01}, {\"symbol\": \"AAPL\", \"date\": \"2000-05-01T00:00:00\", \"price\": 21.0}, {\"symbol\": \"AAPL\", \"date\": \"2000-06-01T00:00:00\", \"price\": 26.19}, {\"symbol\": \"AAPL\", \"date\": \"2000-07-01T00:00:00\", \"price\": 25.41}, {\"symbol\": \"AAPL\", \"date\": \"2000-08-01T00:00:00\", \"price\": 30.47}, {\"symbol\": \"AAPL\", \"date\": \"2000-09-01T00:00:00\", \"price\": 12.88}, {\"symbol\": \"AAPL\", \"date\": \"2000-10-01T00:00:00\", \"price\": 9.78}, {\"symbol\": \"AAPL\", \"date\": \"2000-11-01T00:00:00\", \"price\": 8.25}, {\"symbol\": \"AAPL\", \"date\": \"2000-12-01T00:00:00\", \"price\": 7.44}, {\"symbol\": \"AAPL\", \"date\": \"2001-01-01T00:00:00\", \"price\": 10.81}, {\"symbol\": \"AAPL\", \"date\": \"2001-02-01T00:00:00\", \"price\": 9.12}, {\"symbol\": \"AAPL\", \"date\": \"2001-03-01T00:00:00\", \"price\": 11.03}, {\"symbol\": \"AAPL\", \"date\": \"2001-04-01T00:00:00\", \"price\": 12.74}, {\"symbol\": \"AAPL\", \"date\": \"2001-05-01T00:00:00\", \"price\": 9.98}, {\"symbol\": \"AAPL\", \"date\": \"2001-06-01T00:00:00\", \"price\": 11.62}, {\"symbol\": \"AAPL\", \"date\": \"2001-07-01T00:00:00\", \"price\": 9.4}, {\"symbol\": \"AAPL\", \"date\": \"2001-08-01T00:00:00\", \"price\": 9.27}, {\"symbol\": \"AAPL\", \"date\": \"2001-09-01T00:00:00\", \"price\": 7.76}, {\"symbol\": \"AAPL\", \"date\": \"2001-10-01T00:00:00\", \"price\": 8.78}, {\"symbol\": \"AAPL\", \"date\": \"2001-11-01T00:00:00\", \"price\": 10.65}, {\"symbol\": \"AAPL\", \"date\": \"2001-12-01T00:00:00\", \"price\": 10.95}, {\"symbol\": \"AAPL\", \"date\": \"2002-01-01T00:00:00\", \"price\": 12.36}, {\"symbol\": \"AAPL\", \"date\": \"2002-02-01T00:00:00\", \"price\": 10.85}, {\"symbol\": \"AAPL\", \"date\": \"2002-03-01T00:00:00\", \"price\": 11.84}, {\"symbol\": \"AAPL\", \"date\": \"2002-04-01T00:00:00\", \"price\": 12.14}, {\"symbol\": \"AAPL\", \"date\": \"2002-05-01T00:00:00\", \"price\": 11.65}, {\"symbol\": \"AAPL\", \"date\": \"2002-06-01T00:00:00\", \"price\": 8.86}, {\"symbol\": \"AAPL\", \"date\": \"2002-07-01T00:00:00\", \"price\": 7.63}, {\"symbol\": \"AAPL\", \"date\": \"2002-08-01T00:00:00\", \"price\": 7.38}, {\"symbol\": \"AAPL\", \"date\": \"2002-09-01T00:00:00\", \"price\": 7.25}, {\"symbol\": \"AAPL\", \"date\": \"2002-10-01T00:00:00\", \"price\": 8.03}, {\"symbol\": \"AAPL\", \"date\": \"2002-11-01T00:00:00\", \"price\": 7.75}, {\"symbol\": \"AAPL\", \"date\": \"2002-12-01T00:00:00\", \"price\": 7.16}, {\"symbol\": \"AAPL\", \"date\": \"2003-01-01T00:00:00\", \"price\": 7.18}, {\"symbol\": \"AAPL\", \"date\": \"2003-02-01T00:00:00\", \"price\": 7.51}, {\"symbol\": \"AAPL\", \"date\": \"2003-03-01T00:00:00\", \"price\": 7.07}, {\"symbol\": \"AAPL\", \"date\": \"2003-04-01T00:00:00\", \"price\": 7.11}, {\"symbol\": \"AAPL\", \"date\": \"2003-05-01T00:00:00\", \"price\": 8.98}, {\"symbol\": \"AAPL\", \"date\": \"2003-06-01T00:00:00\", \"price\": 9.53}, {\"symbol\": \"AAPL\", \"date\": \"2003-07-01T00:00:00\", \"price\": 10.54}, {\"symbol\": \"AAPL\", \"date\": \"2003-08-01T00:00:00\", \"price\": 11.31}, {\"symbol\": \"AAPL\", \"date\": \"2003-09-01T00:00:00\", \"price\": 10.36}, {\"symbol\": \"AAPL\", \"date\": \"2003-10-01T00:00:00\", \"price\": 11.44}, {\"symbol\": \"AAPL\", \"date\": \"2003-11-01T00:00:00\", \"price\": 10.45}, {\"symbol\": \"AAPL\", \"date\": \"2003-12-01T00:00:00\", \"price\": 10.69}, {\"symbol\": \"AAPL\", \"date\": \"2004-01-01T00:00:00\", \"price\": 11.28}, {\"symbol\": \"AAPL\", \"date\": \"2004-02-01T00:00:00\", \"price\": 11.96}, {\"symbol\": \"AAPL\", \"date\": \"2004-03-01T00:00:00\", \"price\": 13.52}, {\"symbol\": \"AAPL\", \"date\": \"2004-04-01T00:00:00\", \"price\": 12.89}, {\"symbol\": \"AAPL\", \"date\": \"2004-05-01T00:00:00\", \"price\": 14.03}, {\"symbol\": \"AAPL\", \"date\": \"2004-06-01T00:00:00\", \"price\": 16.27}, {\"symbol\": \"AAPL\", \"date\": \"2004-07-01T00:00:00\", \"price\": 16.17}, {\"symbol\": \"AAPL\", \"date\": \"2004-08-01T00:00:00\", \"price\": 17.25}, {\"symbol\": \"AAPL\", \"date\": \"2004-09-01T00:00:00\", \"price\": 19.38}, {\"symbol\": \"AAPL\", \"date\": \"2004-10-01T00:00:00\", \"price\": 26.2}, {\"symbol\": \"AAPL\", \"date\": \"2004-11-01T00:00:00\", \"price\": 33.53}, {\"symbol\": \"AAPL\", \"date\": \"2004-12-01T00:00:00\", \"price\": 32.2}, {\"symbol\": \"AAPL\", \"date\": \"2005-01-01T00:00:00\", \"price\": 38.45}, {\"symbol\": \"AAPL\", \"date\": \"2005-02-01T00:00:00\", \"price\": 44.86}, {\"symbol\": \"AAPL\", \"date\": \"2005-03-01T00:00:00\", \"price\": 41.67}, {\"symbol\": \"AAPL\", \"date\": \"2005-04-01T00:00:00\", \"price\": 36.06}, {\"symbol\": \"AAPL\", \"date\": \"2005-05-01T00:00:00\", \"price\": 39.76}, {\"symbol\": \"AAPL\", \"date\": \"2005-06-01T00:00:00\", \"price\": 36.81}, {\"symbol\": \"AAPL\", \"date\": \"2005-07-01T00:00:00\", \"price\": 42.65}, {\"symbol\": \"AAPL\", \"date\": \"2005-08-01T00:00:00\", \"price\": 46.89}, {\"symbol\": \"AAPL\", \"date\": \"2005-09-01T00:00:00\", \"price\": 53.61}, {\"symbol\": \"AAPL\", \"date\": \"2005-10-01T00:00:00\", \"price\": 57.59}, {\"symbol\": \"AAPL\", \"date\": \"2005-11-01T00:00:00\", \"price\": 67.82}, {\"symbol\": \"AAPL\", \"date\": \"2005-12-01T00:00:00\", \"price\": 71.89}, {\"symbol\": \"AAPL\", \"date\": \"2006-01-01T00:00:00\", \"price\": 75.51}, {\"symbol\": \"AAPL\", \"date\": \"2006-02-01T00:00:00\", \"price\": 68.49}, {\"symbol\": \"AAPL\", \"date\": \"2006-03-01T00:00:00\", \"price\": 62.72}, {\"symbol\": \"AAPL\", \"date\": \"2006-04-01T00:00:00\", \"price\": 70.39}, {\"symbol\": \"AAPL\", \"date\": \"2006-05-01T00:00:00\", \"price\": 59.77}, {\"symbol\": \"AAPL\", \"date\": \"2006-06-01T00:00:00\", \"price\": 57.27}, {\"symbol\": \"AAPL\", \"date\": \"2006-07-01T00:00:00\", \"price\": 67.96}, {\"symbol\": \"AAPL\", \"date\": \"2006-08-01T00:00:00\", \"price\": 67.85}, {\"symbol\": \"AAPL\", \"date\": \"2006-09-01T00:00:00\", \"price\": 76.98}, {\"symbol\": \"AAPL\", \"date\": \"2006-10-01T00:00:00\", \"price\": 81.08}, {\"symbol\": \"AAPL\", \"date\": \"2006-11-01T00:00:00\", \"price\": 91.66}, {\"symbol\": \"AAPL\", \"date\": \"2006-12-01T00:00:00\", \"price\": 84.84}, {\"symbol\": \"AAPL\", \"date\": \"2007-01-01T00:00:00\", \"price\": 85.73}, {\"symbol\": \"AAPL\", \"date\": \"2007-02-01T00:00:00\", \"price\": 84.61}, {\"symbol\": \"AAPL\", \"date\": \"2007-03-01T00:00:00\", \"price\": 92.91}, {\"symbol\": \"AAPL\", \"date\": \"2007-04-01T00:00:00\", \"price\": 99.8}, {\"symbol\": \"AAPL\", \"date\": \"2007-05-01T00:00:00\", \"price\": 121.19}, {\"symbol\": \"AAPL\", \"date\": \"2007-06-01T00:00:00\", \"price\": 122.04}, {\"symbol\": \"AAPL\", \"date\": \"2007-07-01T00:00:00\", \"price\": 131.76}, {\"symbol\": \"AAPL\", \"date\": \"2007-08-01T00:00:00\", \"price\": 138.48}, {\"symbol\": \"AAPL\", \"date\": \"2007-09-01T00:00:00\", \"price\": 153.47}, {\"symbol\": \"AAPL\", \"date\": \"2007-10-01T00:00:00\", \"price\": 189.95}, {\"symbol\": \"AAPL\", \"date\": \"2007-11-01T00:00:00\", \"price\": 182.22}, {\"symbol\": \"AAPL\", \"date\": \"2007-12-01T00:00:00\", \"price\": 198.08}, {\"symbol\": \"AAPL\", \"date\": \"2008-01-01T00:00:00\", \"price\": 135.36}, {\"symbol\": \"AAPL\", \"date\": \"2008-02-01T00:00:00\", \"price\": 125.02}, {\"symbol\": \"AAPL\", \"date\": \"2008-03-01T00:00:00\", \"price\": 143.5}, {\"symbol\": \"AAPL\", \"date\": \"2008-04-01T00:00:00\", \"price\": 173.95}, {\"symbol\": \"AAPL\", \"date\": \"2008-05-01T00:00:00\", \"price\": 188.75}, {\"symbol\": \"AAPL\", \"date\": \"2008-06-01T00:00:00\", \"price\": 167.44}, {\"symbol\": \"AAPL\", \"date\": \"2008-07-01T00:00:00\", \"price\": 158.95}, {\"symbol\": \"AAPL\", \"date\": \"2008-08-01T00:00:00\", \"price\": 169.53}, {\"symbol\": \"AAPL\", \"date\": \"2008-09-01T00:00:00\", \"price\": 113.66}, {\"symbol\": \"AAPL\", \"date\": \"2008-10-01T00:00:00\", \"price\": 107.59}, {\"symbol\": \"AAPL\", \"date\": \"2008-11-01T00:00:00\", \"price\": 92.67}, {\"symbol\": \"AAPL\", \"date\": \"2008-12-01T00:00:00\", \"price\": 85.35}, {\"symbol\": \"AAPL\", \"date\": \"2009-01-01T00:00:00\", \"price\": 90.13}, {\"symbol\": \"AAPL\", \"date\": \"2009-02-01T00:00:00\", \"price\": 89.31}, {\"symbol\": \"AAPL\", \"date\": \"2009-03-01T00:00:00\", \"price\": 105.12}, {\"symbol\": \"AAPL\", \"date\": \"2009-04-01T00:00:00\", \"price\": 125.83}, {\"symbol\": \"AAPL\", \"date\": \"2009-05-01T00:00:00\", \"price\": 135.81}, {\"symbol\": \"AAPL\", \"date\": \"2009-06-01T00:00:00\", \"price\": 142.43}, {\"symbol\": \"AAPL\", \"date\": \"2009-07-01T00:00:00\", \"price\": 163.39}, {\"symbol\": \"AAPL\", \"date\": \"2009-08-01T00:00:00\", \"price\": 168.21}, {\"symbol\": \"AAPL\", \"date\": \"2009-09-01T00:00:00\", \"price\": 185.35}, {\"symbol\": \"AAPL\", \"date\": \"2009-10-01T00:00:00\", \"price\": 188.5}, {\"symbol\": \"AAPL\", \"date\": \"2009-11-01T00:00:00\", \"price\": 199.91}, {\"symbol\": \"AAPL\", \"date\": \"2009-12-01T00:00:00\", \"price\": 210.73}, {\"symbol\": \"AAPL\", \"date\": \"2010-01-01T00:00:00\", \"price\": 192.06}, {\"symbol\": \"AAPL\", \"date\": \"2010-02-01T00:00:00\", \"price\": 204.62}, {\"symbol\": \"AAPL\", \"date\": \"2010-03-01T00:00:00\", \"price\": 223.02}]}}, {\"mode\": \"vega-lite\"});\n",
              "</script>"
            ]
          }
        }
      ],
      "source": [
        "chart = alt.Chart(stocks).encode(color=alt.Color(\"symbol\", legend=None))\n",
        "line = chart.mark_line().encode(\n",
        "    x=alt.X(\"date:T\", axis=alt.Axis(title=\"date\")),\n",
        "    y=alt.Y(\"price:Q\", axis=alt.Axis(title=\"price\")),\n",
        "    tooltip=[\"date\", \"price\"],\n",
        ")\n",
        "label = chart.encode(\n",
        "    x=alt.X(\"date:T\", aggregate=\"max\"),\n",
        "    y=alt.Y(\"price:Q\", aggregate={\"argmax\": \"date\"}),\n",
        "    text=\"symbol\",\n",
        ")\n",
        "text = label.mark_text(align=\"left\", dx=4)\n",
        "circle = label.mark_circle()\n",
        "(\n",
        "    (line + circle + text).configure_axisX(labelAngle=0, ticks=False)\n",
        "    # .configure_axisY(titleAngle=0, titleAlign=\"center\", titleX=-10, titleY=-10)\n",
        ").properties(\n",
        "    width=600,\n",
        "    title=alt.TitleParams(\n",
        "        \"The Rise of Google\",\n",
        "        subtitle=[\n",
        "            \"Google went public in 2004\",\n",
        "            \"and outperformed other tech stocks until 2010\",\n",
        "        ],\n",
        "    ),\n",
        ")"
      ],
      "id": "cell-19"
    },
    {
      "cell_type": "markdown",
      "metadata": {},
      "source": [
        "I could go on for hours, tweaking this and that. For example, the labels\n",
        "in the last chart overlap. Vega has the [label\n",
        "transform](https://vega.github.io/vega/docs/transforms/label/) method to\n",
        "deal with that, but that implementation still needs to cascade down to\n",
        "Vega-Lite and Altair. Someday, I will package all this as a proper\n",
        "theme, re-using\n",
        "[feedzai’s](https://github.com/feedzai/feedzai-altair-theme) code."
      ],
      "id": "4cc83b33-acd0-4bb2-98bc-c432559308db"
    }
  ],
  "nbformat": 4,
  "nbformat_minor": 5,
  "metadata": {
    "kernelspec": {
      "name": "python3",
      "display_name": "Python 3",
      "language": "python"
    },
    "language_info": {
      "name": "python",
      "codemirror_mode": {
        "name": "ipython",
        "version": "3"
      },
      "file_extension": ".py",
      "mimetype": "text/x-python",
      "nbconvert_exporter": "python",
      "pygments_lexer": "ipython3",
      "version": "3.11.7"
    }
  }
}